from typing import Literal


Network = Literal[42161, 8453, 1, 137]


Release = Literal[
    "arbitrum.sulu",
    "base.sulu",
    "ethereum.sulu",
    "ethereum.encore",
    "ethereum.phoenix",
    "polygon.sulu",
    "testnet.sulu",
]