from ..releases import RELEASES
from ..assets import define_asset_list
from ..networks import NETWORK_BY_SLUG
from ..price_feeds import RateAsset


TESTNET, POLYGON = [RELEASES[r] for r in ["testnet", "polygon"]]


ASSETS = define_asset_list(
    NETWORK_BY_SLUG["polygon"],
    [
        {
            "decimals": 18,
            "id": "0x00e5646f60AC6Fb446f621d146B6E1886f002905",
            "name": "Rai Reflex Index (PoS)",
            "releases": [],
            "symbol": "RAI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0297e37f1873D2DAb4487Aa67cD56B58E2F27875",
            "name": "Balancer Polygon Base Pool",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "B-POLYBASE",
            "staking": [
                {
                    "token": "0x068Ff98072d3eB848D012e3390703BB507729ed6",
                    type: "gauge",
                }
            ],
            "pool_id": "0x0297e37f1873d2dab4487aa67cd56b58e2f27875000100000000000000000002",
            "pool_factory": "0x8E9aa87E45e92bad84D5F8DD1bff34Fb92637dE9",
            "pool_type": "weighted",
            "underlyings": [
                "0x0d500B1d8E8eF31E21C99d1Db9A6444d3ADf1270",
                "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
                "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
                "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x30ee2560675f8A523cD07B109FcB472a54b08314",
            },
        },
        {
            "decimals": 18,
            "id": "0x068Ff98072d3eB848D012e3390703BB507729ed6",
            "name": "Balancer B-POLYBASE RewardGauge Deposit",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "B-POLYBASE-gauge",
            "pool": "0x0297e37f1873D2DAb4487Aa67cD56B58E2F27875",
            "pool_type": "weighted",
            "gauge_factory": "0x3b8cA519122CdD8efb272b0D3085453404B25bD0",
            "underlyings": [
                "0x0d500B1d8E8eF31E21C99d1Db9A6444d3ADf1270",
                "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
                "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
                "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0xBd19713E7fE01d3958afbB4fB5b3802a0d53605c",
            },
        },
        {
            "decimals": 18,
            "id": "0x3d468AB2329F296e1b9d8476Bb54Dd77D8c2320f",
            "name": "20WETH-80BAL",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "staking": [],
            "symbol": "20WETH-80BAL",
            "pool_id": "0x3d468ab2329f296e1b9d8476bb54dd77d8c2320f000200000000000000000426",
            "pool_factory": "0x8E9aa87E45e92bad84D5F8DD1bff34Fb92637dE9",
            "pool_type": "weighted",
            "underlyings": [
                "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
                "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x30ee2560675f8A523cD07B109FcB472a54b08314",
            },
        },
        {
            "decimals": 18,
            "id": "0x03b54A6e9a984069379fae1a4fC4dBAE93B3bCCD",
            "name": "Wrapped liquid staked Ether 2.0 (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "wstETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x10f964234cae09cB6a9854B56FF7D4F38Cda5E6a",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xf59036CAEBeA7dC4b86638DFA2E3C97dA9FcCd40",
            "name": "Aave Polygon wstETH",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolwstETH",
            "type": "aave-v3",
            "underlying": "0x03b54A6e9a984069379fae1a4fC4dBAE93B3bCCD",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x10f964234cae09cB6a9854B56FF7D4F38Cda5E6a",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x03cD191F589d12b0582a99808cf19851E468E6B5",
            "name": "Balancer Polygon Tricrypto",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "BPTC",
            "staking": [
                {
                    "token": "0x0F09F70Ed59202c77aC667f574A5f79bC65CeA48",
                    type: "gauge",
                }
            ],
            "pool_id": "0x03cd191f589d12b0582a99808cf19851e468e6b500010000000000000000000a",
            "pool_factory": "0x8E9aa87E45e92bad84D5F8DD1bff34Fb92637dE9",
            "pool_type": "weighted",
            "underlyings": [
                "0x1BFD67037B42Cf73acF2047067bd4F2C47D9BfD6",
                "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
                "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x30ee2560675f8A523cD07B109FcB472a54b08314",
            },
        },
        {
            "decimals": 18,
            "id": "0x0F09F70Ed59202c77aC667f574A5f79bC65CeA48",
            "name": "Balancer BPTC RewardGauge Deposit",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "BPTC-gauge",
            "pool": "0x03cD191F589d12b0582a99808cf19851E468E6B5",
            "pool_type": "weighted",
            "gauge_factory": "0x3b8cA519122CdD8efb272b0D3085453404B25bD0",
            "underlyings": [
                "0x1BFD67037B42Cf73acF2047067bd4F2C47D9BfD6",
                "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
                "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0xBd19713E7fE01d3958afbB4fB5b3802a0d53605c",
            },
        },
        {
            "decimals": 18,
            "id": "0x36128D5436d2d70cab39C9AF9CcE146C38554ff0",
            "name": "Balancer Polygon DeFi Index",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "B-POLYDEFI",
            "staking": [
                {
                    "token": "0xe32AF68E3e23dd01441f598B1D967A0bF7c6B407",
                    type: "gauge",
                }
            ],
            "pool_id": "0x36128d5436d2d70cab39c9af9cce146c38554ff0000100000000000000000008",
            "pool_factory": "0x8E9aa87E45e92bad84D5F8DD1bff34Fb92637dE9",
            "pool_type": "weighted",
            "underlyings": [
                "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
                "0x53E0bca35eC356BD5ddDFebbD1Fc0fD03FaBad39",
                "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
                "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
                "0xD6DF932A45C0f255f85145f286eA0b292B21C90B",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x30ee2560675f8A523cD07B109FcB472a54b08314",
            },
        },
        {
            "decimals": 18,
            "id": "0xe32AF68E3e23dd01441f598B1D967A0bF7c6B407",
            "name": "Balancer B-POLYDEFI RewardGauge Deposit",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "B-POLYDEFI-gauge",
            "pool": "0x36128D5436d2d70cab39C9AF9CcE146C38554ff0",
            "pool_type": "weighted",
            "gauge_factory": "0x3b8cA519122CdD8efb272b0D3085453404B25bD0",
            "underlyings": [
                "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
                "0x53E0bca35eC356BD5ddDFebbD1Fc0fD03FaBad39",
                "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
                "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
                "0xD6DF932A45C0f255f85145f286eA0b292B21C90B",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0xBd19713E7fE01d3958afbB4fB5b3802a0d53605c",
            },
        },
        {
            "decimals": 18,
            "id": "0x3A58a54C066FdC0f2D55FC9C89F0415C92eBf3C4",
            "name": "Staked MATIC (PoS)",
            "symbol": "stMATIC",
            "type": "primitive",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x97371dF4492605486e23Da797fA68e55Fc38a13f",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xEA1132120ddcDDA2F119e99Fa7A27a0d036F7Ac9",
            "name": "Aave Polygon STMATIC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolSTMATIC",
            "type": "aave-v3",
            "underlying": "0x3A58a54C066FdC0f2D55FC9C89F0415C92eBf3C4",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x97371dF4492605486e23Da797fA68e55Fc38a13f",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x080b5BF8f360F624628E0fb961F4e67c9e3c7CF1",
            "name": "Aave GHST",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amGHST",
            "type": "aave-v2",
            "underlying": "0x385Eeac5cB85A38A9a07A70c73e0a3271CfB54A7",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xe638249AF9642CdA55A92245525268482eE4C67b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x8Eb270e296023E9D92081fdF967dDd7878724424",
            "name": "Aave Polygon GHST",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolGHST",
            "type": "aave-v3",
            "underlying": "0x385Eeac5cB85A38A9a07A70c73e0a3271CfB54A7",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xe638249AF9642CdA55A92245525268482eE4C67b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x0b3F868E0BE5597D5DB7fEB59E1CADBb0fdDa50a",
            "name": "SushiToken (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "SUSHI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x17414Eb5159A082e8d41D243C1601c2944401431",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x0Ca2e42e8c21954af73Bc9af1213E4e81D6a669A",
            "name": "Aave LINK",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amLINK",
            "type": "aave-v2",
            "underlying": "0x53E0bca35eC356BD5ddDFebbD1Fc0fD03FaBad39",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xb77fa460604b9C6435A235D057F7D319AC83cb53",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x191c10Aa4AF7C30e871E70C95dB0E4eb77237530",
            "name": "Aave Polygon LINK",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolLINK",
            "type": "aave-v3",
            "underlying": "0x53E0bca35eC356BD5ddDFebbD1Fc0fD03FaBad39",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xb77fa460604b9C6435A235D057F7D319AC83cb53",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x0d500B1d8E8eF31E21C99d1Db9A6444d3ADf1270",
            "name": "Wrapped Polygon Ecosystem Token",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "WPOL",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xAB594600376Ec9fD91F8e885dADF0CE036862dE0",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x104592a158490a9228070E0A8e5343B499e125D0",
            "name": "Frax (PoS)",
            "releases": [],
            "symbol": "FRAX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x172370d5Cd63279eFa6d502DAB29171933a610AF",
            "name": "CRV (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "CRV",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x1CF68C76803c9A415bE301f50E82e44c64B7F1D4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x18ec0A6E18E5bc3784fDd3a3634b31245ab704F6",
            "name": "Monerium EUR emoney",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "EURe",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x73366Fe0AA0Ded304479862808e02506FE556a98",
                "rate_asset": RateAsset.USD,
                "pegged_to": "EUR",
                "non_standard": True,
            },
        },
        {
            "decimals": 6,
            "id": "0x1a13F4Ca1d028320A707D99520AbFefca3998b7F",
            "name": "Aave USDC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amUSDC",
            "type": "aave-v2",
            "underlying": "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xfE4A8cc5b5B2366C1B58Bea3858e81843581b2F7",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x625E7708f30cA75bfd92586e17077590C60eb4cD",
            "name": "Aave Polygon USDC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolUSDC",
            "type": "aave-v3",
            "underlying": "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xfE4A8cc5b5B2366C1B58Bea3858e81843581b2F7",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x1a3acf6D19267E2d3e7f898f42803e90C9219062",
            "name": "Frax Share",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "FXS",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x6C0fe985D3cAcbCdE428b84fc9431792694d0f51",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 8,
            "id": "0x1BFD67037B42Cf73acF2047067bd4F2C47D9BfD6",
            "name": "(PoS) Wrapped BTC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "WBTC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xA338e0492B2F944E9F8C0653D3AD1484f2657a37",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x1C954E8fe737F99f68Fa1CCda3e51ebDB291948C",
            "name": "Kyber Network Crystal v2 (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "KNC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x10e5f3DFc81B3e5Ef4e648C4454D04e79E1E41E2",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x1d2a0E5EC8E5bBDCA5CB219e649B565d8e5c3360",
            "name": "Aave AAVE",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amAAVE",
            "type": "aave-v2",
            "underlying": "0xD6DF932A45C0f255f85145f286eA0b292B21C90B",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xbE23a3AA13038CfC28aFd0ECe4FdE379fE7fBfc4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xf329e36C7bF6E5E86ce2150875a84Ce77f477375",
            "name": "Aave Polygon AAVE",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolAAVE",
            "type": "aave-v3",
            "underlying": "0xD6DF932A45C0f255f85145f286eA0b292B21C90B",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xbE23a3AA13038CfC28aFd0ECe4FdE379fE7fBfc4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x1FcbE5937B0cc2adf69772D228fA4205aCF4D9b2",
            "name": "Badger (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "BADGER",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x82C9d4E88862f194C2bd874a106a90dDD0D35AAB",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x21eC9431B5B55c5339Eb1AE7582763087F98FAc2",
            "name": "Aave SUSHI",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amSUSHI",
            "type": "aave-v2",
            "underlying": "0x0b3F868E0BE5597D5DB7fEB59E1CADBb0fdDa50a",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x17414Eb5159A082e8d41D243C1601c2944401431",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xc45A479877e1e9Dfe9FcD4056c699575a1045dAA",
            "name": "Aave Polygon SUSHI",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolSUSHI",
            "type": "aave-v3",
            "underlying": "0x0b3F868E0BE5597D5DB7fEB59E1CADBb0fdDa50a",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x17414Eb5159A082e8d41D243C1601c2944401431",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x24834BBEc7E39ef42f4a75EAF8E5B6486d3F0e57",
            "name": "Wrapped LUNA Token (PoS)",
            "releases": [],
            "symbol": "LUNA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
            "name": "USD Coin (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "USDC.e",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xfE4A8cc5b5B2366C1B58Bea3858e81843581b2F7",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x27F8D03b3a2196956ED754baDc28D73be8830A6e",
            "name": "Aave DAI",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amDAI",
            "type": "aave-v2",
            "underlying": "0x8f3Cf7ad23Cd3CaDbD9735AFf958023239c6A063",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x4746DeC9e833A82EC7C2C1356372CcF2cfcD2F3D",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x82E64f49Ed5EC1bC6e43DAD4FC8Af9bb3A2312EE",
            "name": "Aave Polygon DAI",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolDAI",
            "type": "aave-v3",
            "underlying": "0x8f3Cf7ad23Cd3CaDbD9735AFf958023239c6A063",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x4746DeC9e833A82EC7C2C1356372CcF2cfcD2F3D",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x28424507fefb6f7f8E9D3860F56504E4e5f5f390",
            "name": "Aave WETH",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amWETH",
            "type": "aave-v2",
            "underlying": "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xF9680D99D6C9589e2a93a78A04A279e509205945",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xe50fA9b3c56FfB159cB0FCA61F5c9D750e8128c8",
            "name": "Aave Polygon WETH",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolWETH",
            "type": "aave-v3",
            "underlying": "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xF9680D99D6C9589e2a93a78A04A279e509205945",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xE5417Af564e4bFDA1c483642db72007871397896",
            "name": "Gains Network",
            "releases": [POLYGON["sulu"]],
            "symbol": "GNS",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x9cb43aa3D036Cb035a694Ba0AAa91f8875B16cE1",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x2b88aD57897A8b496595925F43048301C37615Da",
            "name": "PickleToken (PoS)",
            "releases": [],
            "symbol": "PICKLE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3066818837c5e6eD6601bd5a91B0762877A6B731",
            "name": "UMA Voting Token v1 (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "UMA",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x33D9B1BAaDcF4b26ab6F8E83e9cb8a611B2B3956",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x308ba429a913d952275090Fc35dEA9C36A511B5A",
            "name": "Wrapped Tezos (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "WXTZ",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x691e26AB58ff05800E028b0876A41B720b26FC65",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x385Eeac5cB85A38A9a07A70c73e0a3271CfB54A7",
            "name": "Aavegotchi GHST Token (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "GHST",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xe638249AF9642CdA55A92245525268482eE4C67b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x3962F4A0A0051DccE0be73A7e09cEf5756736712",
            "name": "Livepeer Token (PoS)",
            "releases": [],
            "symbol": "LPT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3AE490db48d74B1bC626400135d4616377D0109f",
            "name": "AlphaToken (PoS)",
            "releases": [],
            "symbol": "ALPHA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3BA4c387f786bFEE076A58914F5Bd38d668B42c3",
            "name": "BNB (PoS)",
            "releases": [],
            "symbol": "BNB",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3Cef98bb43d732E2F285eE605a8158cDE967D219",
            "name": "Basic Attention Token (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "BAT",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x2346Ce62bd732c62618944E51cbFa09D985d86D2",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x3c499c542cEF5E3811e1192ce70d8cC03d5c3359",
            "name": "USD Coin",
            "releases": [POLYGON["sulu"]],
            "symbol": "USDC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xfE4A8cc5b5B2366C1B58Bea3858e81843581b2F7",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x3Df8f92b7E798820ddcCA2EBEA7BAbda2c90c4aD",
            "name": "Aave CRV",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amCRV",
            "type": "aave-v2",
            "underlying": "0x172370d5Cd63279eFa6d502DAB29171933a610AF",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x1CF68C76803c9A415bE301f50E82e44c64B7F1D4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x513c7E3a9c69cA3e22550eF58AC1C0088e918FFf",
            "name": "Aave Polygon CRV",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolCRV",
            "type": "aave-v3",
            "underlying": "0x172370d5Cd63279eFa6d502DAB29171933a610AF",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x1CF68C76803c9A415bE301f50E82e44c64B7F1D4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x3e121107F6F22DA4911079845a470757aF4e1A1b",
            "name": "Frax Share (PoS)",
            "releases": [],
            "symbol": "FXS",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x41b3966B4FF7b427969ddf5da3627d6AEAE9a48E",
            "name": "Nexo (PoS)",
            "releases": [],
            "symbol": "NEXO",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4257EA7637c355F81616050CbB6a9b709fd72683",
            "name": "Convex Token (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "CVX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5ec151834040B4D453A1eA46aA634C1773b36084",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x45c32fA6DF82ead1e2EF74d17b76547EDdFaFF89",
            "name": "Frax",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "FRAX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x00DBeB1e45485d53DF7C2F0dF1Aa0b6Dc30311d3",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x50B728D8D964fd00C2d0AAD81718b71311feF68a",
            "name": "Synthetix Network Token (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "SNX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xbF90A5D9B6EE9019028dbFc2a9E50056d5252894",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x53E0bca35eC356BD5ddDFebbD1Fc0fD03FaBad39",
            "name": "ChainLink Token",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "LINK",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xb77fa460604b9C6435A235D057F7D319AC83cb53",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x5559Edb74751A0edE9DeA4DC23aeE72cCA6bE3D5",
            "name": "0x Protocol Token (PoS)",
            "releases": [],
            "symbol": "ZRX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x5c2ed810328349100A66B82b78a1791B101C9D61",
            "name": "Aave WBTC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amWBTC",
            "type": "aave-v2",
            "underlying": "0x1BFD67037B42Cf73acF2047067bd4F2C47D9BfD6",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xA338e0492B2F944E9F8C0653D3AD1484f2657a37",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0x078f358208685046a11C85e8ad32895DED33A249",
            "name": "Aave Polygon WBTC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolWBTC",
            "type": "aave-v3",
            "underlying": "0x1BFD67037B42Cf73acF2047067bd4F2C47D9BfD6",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xA338e0492B2F944E9F8C0653D3AD1484f2657a37",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x5fe2B58c013d7601147DcdD68C143A77499f5531",
            "name": "Graph Token (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "GRT",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3FabBfb300B1e2D7c9B84512fe9D30aeDF24C410",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x60D55F02A771d515e077c9C2403a1ef324885CeC",
            "name": "Aave USDT",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amUSDT",
            "type": "aave-v2",
            "underlying": "0xc2132D05D31c914a87C6611C10748AEb04B58e8F",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x0A6513e40db6EB1b165753AD52E80663aeA50545",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x6ab707Aca953eDAeFBc4fD23bA73294241490620",
            "name": "Aave Polygon USDT",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolUSDT",
            "type": "aave-v3",
            "underlying": "0xc2132D05D31c914a87C6611C10748AEb04B58e8F",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x0A6513e40db6EB1b165753AD52E80663aeA50545",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x6811079E3c63ED96Eb005384d7E7ec8810E3D521",
            "name": "SushiBar (PoS)",
            "releases": [],
            "symbol": "xSUSHI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6f7C932e7684666C9fd1d44527765433e01fF61d",
            "name": "MAKER (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "MKR",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x807b59d12520830D1864286FA0271c27baa94197",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
            "name": "Wrapped Ether",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "WETH",
            "type": "primitive",
            "price_feed": {
                "type": "WETH",
            },
        },
        {
            "decimals": 18,
            "id": "0x7eC26842F195c852Fa843bB9f6D8B583a274a157",
            "name": "Enjin Coin (PoS)",
            "releases": [],
            "symbol": "ENJ",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x81fB82aAcB4aBE262fc57F06fD4c1d2De347D7B1",
            "name": "Aave DPI",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amDPI",
            "type": "aave-v2",
            "underlying": "0x85955046DF4668e1DD369D2DE9f3AEB98DD2A369",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xC70aAF9092De3a4E5000956E672cDf5E996B4610",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x724dc807b04555b71ed48a6896b6F41593b8C637",
            "name": "Aave Polygon DPI",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolDPI",
            "type": "aave-v3",
            "underlying": "0x85955046DF4668e1DD369D2DE9f3AEB98DD2A369",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xC70aAF9092De3a4E5000956E672cDf5E996B4610",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x831753DD7087CaC61aB5644b308642cc1c33Dc13",
            "name": "Quickswap",
            "releases": [],
            "symbol": "QUICK",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8505b9d2254A7Ae468c0E9dd10Ccea3A837aef5c",
            "name": "(PoS) Compound",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "COMP",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x2A8758b7257102461BC958279054e372C2b1bDE6",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x85955046DF4668e1DD369D2DE9f3AEB98DD2A369",
            "name": "DefiPulse Index (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "DPI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xC70aAF9092De3a4E5000956E672cDf5E996B4610",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x8dF3aad3a84da6b69A4DA8aeC3eA40d9091B2Ac4",
            "name": "Aave WMATIC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amWMATIC",
            "type": "aave-v2",
            "underlying": "0x0d500B1d8E8eF31E21C99d1Db9A6444d3ADf1270",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xAB594600376Ec9fD91F8e885dADF0CE036862dE0",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x6d80113e533a2C0fe82EaBD35f1875DcEA89Ea97",
            "name": "Aave Polygon WMATIC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolWMATIC",
            "type": "aave-v3",
            "underlying": "0x0d500B1d8E8eF31E21C99d1Db9A6444d3ADf1270",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xAB594600376Ec9fD91F8e885dADF0CE036862dE0",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x8f3Cf7ad23Cd3CaDbD9735AFf958023239c6A063",
            "name": "(PoS) Dai Stablecoin",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "DAI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x4746DeC9e833A82EC7C2C1356372CcF2cfcD2F3D",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x918C749A09fA539E1Dc8019F875fab9EB1EBc6A3",
            "name": "FTT (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "FTT",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x817A7D43f0277Ca480AE03Ec76Fc63A2EC7114bA",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x95c300e7740D2A88a44124B424bFC1cB2F9c3b89",
            "name": "Alchemix (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "ALCX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5DB6e61B6159B20F068dc15A47dF2E5931b14f29",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
            "name": "Balancer (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "BAL",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x03CD157746c61F44597dD54C6f6702105258C722",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x9c2C5fd7b07E95EE044DDeba0E97a665F142394f",
            "name": "1Inch (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "1INCH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x443C5116CdF663Eb387e72C688D276e702135C87",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xA041544fe2BE56CCe31Ebb69102B965E06aacE80",
            "name": "BarnBridge Governance Token (PoS)",
            "releases": [],
            "symbol": "BOND",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA1c57f48F0Deb89f569dFbE6E2B7f46D33606fD4",
            "name": "(PoS) Decentraland MANA",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "MANA",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xA1CbF3Fe43BC3501e3Fc4b573e822c70e76A7512",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xa9f37D84c856fDa3812ad0519Dad44FA0a3Fe207",
            "name": "Enzyme (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "MLN",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xB89D583B72aBF9C3a7e6e093251C2fCad3365312",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xb33EaAd8d922B1083446DC23f610c2567fB5180f",
            "name": "Uniswap (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "UNI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x162d8c5bF15eB6BEe003a1ffc4049C92114bc931",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xBbba073C31bF03b8ACf7c28EF0738DeCF3695683",
            "name": "SAND",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "SAND",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3D49406EDd4D52Fb7FFd25485f32E073b529C924",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0xc2132D05D31c914a87C6611C10748AEb04B58e8F",
            "name": "(PoS) Tether USD",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "USDT",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x0A6513e40db6EB1b165753AD52E80663aeA50545",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xc26D47d5c33aC71AC5CF9F776D63Ba292a4F7842",
            "name": "Bancor Network Token (PoS)",
            "releases": [],
            "symbol": "BNT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xc4195D4060DaEac44058Ed668AA5EfEc50D77ff6",
            "name": "Aave BAL",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "amBAL",
            "type": "aave-v2",
            "underlying": "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x03CD157746c61F44597dD54C6f6702105258C722",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x8ffDf2DE812095b1D19CB146E4c004587C0A0692",
            "name": "Aave Polygon BAL",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolBAL",
            "type": "aave-v3",
            "underlying": "0x9a71012B13CA4d3D0Cdc72A177DF3ef03b0E76A3",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x03CD157746c61F44597dD54C6f6702105258C722",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xD6DF932A45C0f255f85145f286eA0b292B21C90B",
            "name": "Aave (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "AAVE",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xbE23a3AA13038CfC28aFd0ECe4FdE379fE7fBfc4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 4,
            "id": "0xD85d1e945766Fea5Eda9103F918Bd915FbCa63E6",
            "name": "Celsius (PoS)",
            "releases": [],
            "symbol": "CEL",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xDA537104D6A5edd53c6fBba9A898708E465260b6",
            "name": "(PoS) yearn.finance",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "YFI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x9896A1eA7A00F5f32Ab131eBbeE07487B0af31D0",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xdAb529f40E671A1D4bF91361c21bf9f0C9712ab7",
            "name": "(PoS) Binance USD",
            "releases": [],
            "symbol": "BUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xe1708AbDE4847B4929b70547E5197F1Ba1db2250",
            "name": "Tokemak (PoS)",
            "releases": [],
            "symbol": "TOKE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xe4Bf2864ebeC7B7fDf6Eeca9BaCAe7cDfDAffe78",
            "name": "DODO bird (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "DODO",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x59161117086a4C7A9beDA16C66e40Bdaa1C5a8B6",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x5FFD62D3C3eE2E81C00A7b9079FB248e7dF024A8",
            "name": "Gnosis Token (PoS)",
            "releases": [],
            "symbol": "GNO",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x553d3D295e0f695B9228246232eDF400ed3560B5",
            "name": "Paxos Gold (PoS)",
            "releases": [POLYGON["sulu"]],
            "symbol": "PAXG",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x0f6914d8e7e1214CDb3A4C6fbf729b75C69DF608",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x7BDF330f423Ea880FF95fC41A280fD5eCFD3D09f",
            "name": "Euro Tether (PoS)",
            "releases": [],
            "symbol": "EURT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2e1AD108fF1D8C782fcBbB89AAd783aC49586756",
            "name": "TrueUSD (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "TUSD",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x7C5D415B64312D38c56B54358449d0a4058339d2",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x6F3B3286fd86d8b47EC737CEB3D0D354cc657B3e",
            "name": "Paxos Standard (PoS)",
            "releases": [],
            "symbol": "PAX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            "name": "Curve.fi amDAI/amUSDC/amUSDT",
            "pool": "0x445FE580eF8d70FF569aB36e80c647af338db351",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "staking": [
                {
                    "token": "0x20759F567BB3EcDB55c817c9a1d13076aB215EdC",
                    type: "gauge",
                }
            ],
            "symbol": "am3CRV",
            "template": "aave",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x27F8D03b3a2196956ED754baDc28D73be8830A6e",
                "0x1a13F4Ca1d028320A707D99520AbFefca3998b7F",
                "0x60D55F02A771d515e077c9C2403a1ef324885CeC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0x20759F567BB3EcDB55c817c9a1d13076aB215EdC",
            "lp": "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            "name": "Curve.fi am3CRV Gauge Deposit",
            "pool": "0x445FE580eF8d70FF569aB36e80c647af338db351",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "am3CRV-gauge",
            "template": "aave",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x27F8D03b3a2196956ED754baDc28D73be8830A6e",
                "0x1a13F4Ca1d028320A707D99520AbFefca3998b7F",
                "0x60D55F02A771d515e077c9C2403a1ef324885CeC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0x5e5A23b52Cb48F5E70271Be83079cA5bC9c9e9ac",
            "name": "Curve.fi Factory USD Metapool: Curve FRAX3CRV Pool",
            "pool": "0x5e5A23b52Cb48F5E70271Be83079cA5bC9c9e9ac",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "staking": [
                {
                    "token": "0x78DA40dbFA5c3CC65319e8d658d3c9BaD3322f26",
                    type: "gauge",
                }
            ],
            "symbol": "FRAX3CRV-f3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x45c32fA6DF82ead1e2EF74d17b76547EDdFaFF89",
                "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0x78DA40dbFA5c3CC65319e8d658d3c9BaD3322f26",
            "lp": "0x5e5A23b52Cb48F5E70271Be83079cA5bC9c9e9ac",
            "name": "Curve.fi FRAX3CRV-f3CRV-f Gauge Deposit",
            "pool": "0x5e5A23b52Cb48F5E70271Be83079cA5bC9c9e9ac",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "FRAX3CRV-f3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x45c32fA6DF82ead1e2EF74d17b76547EDdFaFF89",
                "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0x447646e84498552e62eCF097Cc305eaBFFF09308",
            "name": "Curve.fi Factory USD Metapool: MAI+3Pool",
            "pool": "0x447646e84498552e62eCF097Cc305eaBFFF09308",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "staking": [
                {
                    "token": "0x93DB264Ee9c42092DC963517885be167B5BF62DB",
                    type: "gauge",
                }
            ],
            "symbol": "MAI+3Pool3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xa3Fa99A148fA48D14Ed51d610c367C61876997F1",
                "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0x93DB264Ee9c42092DC963517885be167B5BF62DB",
            "lp": "0x447646e84498552e62eCF097Cc305eaBFFF09308",
            "name": "Curve.fi MAI+3Pool3CRV-f Gauge Deposit",
            "pool": "0x447646e84498552e62eCF097Cc305eaBFFF09308",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "MAI+3Pool3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xa3Fa99A148fA48D14Ed51d610c367C61876997F1",
                "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0xAdf577B69eEaC9Df325536cf1aF106372f2Da263",
            "name": "Curve.fi Factory USD Metapool: curve.fi TUSD/am3CRV Pool",
            "pool": "0xAdf577B69eEaC9Df325536cf1aF106372f2Da263",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "staking": [
                {
                    "token": "0xdA690c2EA49a058a9966C69f46a05Bfc225939f4",
                    type: "gauge",
                }
            ],
            "symbol": "TUSDam3CRV3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x2e1AD108fF1D8C782fcBbB89AAd783aC49586756",
                "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0xdA690c2EA49a058a9966C69f46a05Bfc225939f4",
            "lp": "0xAdf577B69eEaC9Df325536cf1aF106372f2Da263",
            "name": "Curve.fi TUSDam3CRV3CRV-f Gauge Deposit",
            "pool": "0xAdf577B69eEaC9Df325536cf1aF106372f2Da263",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "TUSDam3CRV3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x2e1AD108fF1D8C782fcBbB89AAd783aC49586756",
                "0xE7a24EF0C5e95Ffb0f6684b813A78F2a3AD7D171",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0xc537439f4397a0f625Cb323F90BF87397dA92fCF",
                "ipa": "0x51e75b5E0eef2d40B4D70C5dAa2666E1eA30F0Bd",
            },
        },
        {
            "decimals": 18,
            "id": "0xa3Fa99A148fA48D14Ed51d610c367C61876997F1",
            "name": "miMATIC",
            "releases": [],
            "symbol": "miMATIC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xeBe517846d0F36eCEd99C735cbF6131e1fEB775D",
            "name": "Aave Polygon MIMATIC",
            "releases": [],
            "symbol": "aPolMIMATIC",
            "type": "aave-v3",
            "underlying": "0xa3Fa99A148fA48D14Ed51d610c367C61876997F1",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8a999F5A3546F8243205b2c0eCb0627cC10003ab",
            "name": "IdleDAI [Best yield]",
            "releases": [],
            "symbol": "idleDAIYield",
            "type": "idle",
            "underlying": "0x8f3Cf7ad23Cd3CaDbD9735AFf958023239c6A063",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xfa68FB4628DFF1028CFEc22b4162FCcd0d45efb6",
            "name": "Liquid Staking Matic (PoS)",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "MaticX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5d37E4b374E6907de8Fc7fb33EE3b0af403C7403",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x80cA0d8C38d2e2BcbaB66aA1648Bd1C7160500FE",
            "name": "Aave Polygon MATICX",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "aPolMATICX",
            "type": "aave-v3",
            "underlying": "0xfa68FB4628DFF1028CFEc22b4162FCcd0d45efb6",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5d37E4b374E6907de8Fc7fb33EE3b0af403C7403",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xfdA25D931258Df948ffecb66b5518299Df6527C4",
            "name": "IdleWETH [Best yield]",
            "releases": [],
            "symbol": "idleWETHYield",
            "type": "idle",
            "underlying": "0x7ceB23fD6bC0adD59E62ac25578270cFf1b9f619",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1ee6470CD75D5686d0b2b90C0305Fa46fb0C89A1",
            "name": "IdleUSDC [Best yield]",
            "releases": [],
            "symbol": "idleUSDCYield",
            "type": "idle",
            "underlying": "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0xF25212E676D1F7F89Cd72fFEe66158f541246445",
            "name": "Compound USDC",
            "releases": [POLYGON["sulu"], TESTNET["sulu"]],
            "symbol": "cUSDCv3",
            "type": "compound-v3",
            "underlying": "0x2791Bca1f2de4661ED88A30C99A7a9449Aa84174",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xfE4A8cc5b5B2366C1B58Bea3858e81843581b2F7",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "id": "0x4954AbbaA3637f19C7594aa248bF5A2b5f98F093",
            "name": "Balancer DUSD-USDC-BPT Gauge Deposit",
            "releases": [TESTNET["sulu"]],
            "symbol": "DUSD-USDC-BPT-gauge",
            "type": "primitive",
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "id": "0x6a8742D7F417431AE4218e94678D91f2aCE24a66",
            "name": "UI Space Y Stock",
            "symbol": "UISTEST",
            "decimals": 0,
            "releases": [POLYGON["sulu"]],
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x73366Fe0AA0Ded304479862808e02506FE556a98",
                "rate_asset": RateAsset.USD,
                "pegged_to": "EUR",
                "non_standard": True,
            },
        },
        {
            "id": "0xDD52Fb974E8b486Da82e69d56DA8C6f8Bf35B0e0",
            "name": "UI Real Estate",
            "symbol": "UIRETEST",
            "decimals": 0,
            "releases": [POLYGON["sulu"]],
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x73366Fe0AA0Ded304479862808e02506FE556a98",
                "rate_asset": RateAsset.USD,
                "pegged_to": "EUR",
                "non_standard": True,
            },
        },
    ],
)
