from ..assets_lib.ethereum import ASSETS
from ..networks import NETWORK_BY_SLUG


DEPLOYMENT = {
    "address": "0xC3DC853dD716bd5754f421ef94fdCbac3902ab32",
    "assets": ASSETS,
    "external_contracts": {
        "aaveUIIncentiveDataProvider": "0x5a40cDe2b76Da2beD545efB3ae15708eE56aAF9c",
        "aaveV2IncentivesController": "0xd784927Ff2f95ba542BfC824c8a8a98F3495f6b5",
        "aaveV2LendingPoolProvider": "0xB53C1a33016B2DC2fF3653530bfF1848a515c8c5",
        "aaveV3LendingPoolProvider": "0x2f39d218133AFaB8F2B819B1066c7E434Ad94E9e",
        "aaveV3ProtocolDataProvider": "0x41393e5e337606dc3821075Af65AeE84D7688CBD",
        "aaveV3RewardsController": "0x8164Cc65827dcFe994AB23944CBC90e0aa80bFcb",
        "aliceOrderManager": "0x841473a19279E54a850E9083A3A57dE9e6244d2E",
        "arrakisV2Helper": "0x89E4bE1F999E3a58D16096FBe405Fc2a1d7F07D6",
        "arrakisV2Resolver": "0x535C5fDf31477f799366DF6E4899a12A801cC7b8",
        "balancerGaugeController": "0xC128468b7Ce63eA702C1f104D55A2566b13D3ABD",
        "balancerHelpers": "0x5aDDCCa35b7A0D07C74063c48700C8590E87864E",
        "balancerMinter": "0x239e55F427D44C3cc793f49bFB507ebe76638a2b",
        "balancerProtocolFeesCollector": "0xce88686553686DA562CE7Cea497CE749DA109f9F",
        "balancerVault": "0xBA12222222228d8Ba445958a75a0704d566BF2C8",
        "chainlinkFeedsRegistry": "0x47Fb2585D2C56Fe188D0E6ec628a38b74fCeeeDf",
        "compoundComptroller": "0x3d9819210A31b4961b30EF54bE2aeD79B9c9Cd3B",
        "compoundV3Rewards": "0x1B0e765F6224C21223AeA2af16c1C46E38885a40",
        "curveChildLiquidityGaugeFactory": "0x0000000000000000000000000000000000000000",
        "curveMinter": "0xd061D61a4d941c39E5453435B6345Dc261C2fcE0",
        "curveRegistry": "0x0000000022D53366457F9d5E68Ec105046FC4383",
        "cvxCrvStaking": "0x3Fe65692bfCD0e6CF84cB1E7d24108E434A7587e",
        "gmxV2ChainlinkPriceFeed": "0x0000000000000000000000000000000000000000",
        "gmxV2DataStore": "0x0000000000000000000000000000000000000000",
        "gmxV2ExchangeRouter": "0x0000000000000000000000000000000000000000",
        "gmxV2Reader": "0x0000000000000000000000000000000000000000",
        "gmxV2ReferralStorage": "0x0000000000000000000000000000000000000000",
        "kilnStaking": "0x0816DF553a89c4bFF7eBfD778A9706a989Dd3Ce3",
        "lidoWithdrawalsQueue": "0x889edC2eDab5f40e902b864aD4d7AdE8E412F9B1",
        "liquityCollSurplusPool": "0x3D32e8b97Ed5881324241Cf03b2DA5E2EBcE5521",
        "liquityHintHelpers": "0xE84251b93D9524E0d2e621Ba7dc7cb3579F997C0",
        "liquitySortedTroves": "0x8FdD3fbFEb32b28fb73555518f8b361bCeA741A6",
        "liquityTroveManager": "0xA39739EF8b0231DbFA0DcdA07d7e29faAbCf4bb2",
        "makerMCDPotAddress": "0x197E90f9FAD81970bA7976f33CbD77088E5D7cf7",
        "morphoBlue": "0xBBBBBbbBBb9cC5e90e3b3Af64bdAF62C37EEFFCb",
        "multicall": "0xcA11bde05977b3631167028862bE2a173976CA11",
        "paraswapV5AugustusSwapper": "0xDEF171Fe48CF0115B1d80b88dc8eAB59176FEe57",
        "paraswapV5TokenTransferProxy": "0x216B4B4Ba9F3e719726886d34a177484278Bfcae",
        "pendlePtLpOracle": "0x66a1096C6366b2529274dF4f5D8247827fe4CEA8",
        "staderStakingPoolManager": "0xcf5EA1b38380f6aF39068375516Daf40Ed70D299",
        "staderUserWithdrawManager": "0x9F0491B32DBce587c50c4C43AB303b06478193A7",
        "stakeWiseV3KeeperRewards": "0x6B5815467da09DaA7DC83Db21c9239d98Bb487b5",
        "theGraphDelegationStakingProxy": "0xF55041E37E12cD407ad00CE2910B8269B01263b9",
        "theGraphEpochManagerProxy": "0x64F990Bf16552A693dCB043BB7bf3866c5E05DdB",
        "uniswapV3NonFungiblePositionManager": "0xC36442b4a4522E871399CD717aBDD847Ab11FE88",
        "voteLockedConvexToken": "0x72a19342e8F1838460eBFCCEf09F6585e32db86E",
        "votiumVoteProxy": "0xde1E6A7ED0ad3F61D531a8a78E83CcDdbd6E0c49",
        "zeroExExchangeProxy": "0x95E6F48254609A6ee006F7D493c8e5fB97094ceF",
        "zeroExV4Exchange": "0xDef1C0ded9bec7F1a1670819833240f027b25EfF",
        "zeroLendAaveV3UIIncentiveDataProvider": "0x0A1198DDb5247a283F76077Bb1E45e5858ee100b",
        "zeroLendLRTBTCAaveV3LendingPoolProvider": "0x17878AFdD5772F4Ec93c265Ac7Ad8E2b29abB857",
        "zeroLendLRTBTCAaveV3ProtocolDataProvider": "0x31063F7CA8ef4089Db0dEdf8D6e35690B468A611",
        "zeroLendLRTBTCAaveV3RewardsController": "0x938e23c10C501CE5D42Bc516eCFDf5AbD9C51d2b",
        "zeroLendRWAStablecoinsAaveV3LendingPoolProvider": "0xE3C3c5eAd58FC2BEd4E577E38985B8F7F1DDfF00",
        "zeroLendRWAStablecoinsAaveV3ProtocolDataProvider": "0x298ECDcb0369Aef75cBbdA3e46a224Cfe622E287",
        "zeroLendRWAStablecoinsAaveV3RewardsController": "0xbc2FDC58E3E06D265B46E32771442b7f5098725b",
    },
    "inception": 11636493,
    "kind": "live",
    "known_address_lists": {
        "no_slippage_adapters": 1,
        "adapters": 2,
        "fees": 3,
        "policies": 4,
        "kiln_staking_contracts": 400,
        "non_standard_price_feed_assets": 650,
        "a_tokens": 463,
        "zero_lend_rwa_stablecoins_a_tokens": 737,
        "zero_lend_lrt_btc_a_tokens": 738,
        "deposit_wrapper_allowed_exchanges": 553,
    },
    "known_uint_lists": {
        "allowed_morpho_blue_vaults": 3,
    },
    "label": "Ethereum",
    "named_tokens": {
        "aave": "0x7Fc66500c84A76Ad7e9c93437bFc5Ac33E2DDaE9",
        "bal": "0xba100000625a3754423978a60c9317c58a424e3D",
        "ceth": "0x4Ddc2D193948926D02f9B1fE9e1daa0718270ED5",
        "comp": "0xc00e94Cb662C3520282E6f5717214004A7f26888",
        "crv": "0xD533a949740bb3306d119CC777fa900bA034cd52",
        "cvx": "0x4e3FBD56CD56c3e72c1403e103b45Db9da5B9D2B",
        "dai": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
        "diva": "0xBFAbdE619ed5C4311811cF422562709710DB587d",
        "ethx": "0xA35b1B31Ce002FBF2058D22F30f95D405200A15b",
        "grt": "0xc944E90C64B2c07662A292be6244BDf05Cda44a7",
        "idle": "0x875773784Af8135eA0ef43b5a374AaD105c5D39e",
        "lusd": "0x5f98805A4E8be255a32880FDeC7F6728C6568bA0",
        "mln": "0xec67005c4E498Ec7f55E092bd1d35cbC47C91892",
        "mpl": "0x33349B282065b0284d756F0577FB39c158F935e6",
        "paxg": "0x45804880De22913dAFE09f4980848ECE6EcbAf78",
        "ptkn_mln": "0x4C0d9e35AD2C952bCd58A6d255C9Dc2784AC6f08",
        "sthoundeth": "0xDFe66B14D37C77F4E9b180cEb433d1b164f0281D",
        "stkaave": "0x4da27a545c0c5B758a6BA100e3a049001de870f5",
        "steth": "0xae7ab96520DE3A18E5e111B5EaAb095312D7fE84",
        "stusd": "0x0022228a2cc5E7eF0274A7Baa600d44da5aB5776",
        "sweth": "0xf951E335afb289353dc249e82926178EaC7DEd78",
        "uni": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
        "usda": "0x0000206329b97DB379d5E1Bf586BbDB969C63274",
        "usdc": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
        "usdt": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
        "weth": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
    },
    "network": NETWORK_BY_SLUG["ethereum"],
    "releases": {
        "sulu": {
            "address": "0x4f1C53F096533C04d8157EFB6Bca3eb22ddC6360",
            "contracts": {
                "AaveDebtPositionLib": "0xb3402eb0d45c63594699DF3E5caC9116Ccfc5eF3",
                "AaveDebtPositionParser": "0xf6d47bdEe7760067557B047cE4AdCba819d7D5A8",
                "AavePriceFeed": "0xE9cFe0f99b8a01Fd80F110Da4d8F08f6bF3DD6A6",
                "AaveV2Adapter": "0xECe6B376af7C9273cebaf6528565c47Ea2Cb8a4C",
                "AaveV2ATokenListOwner": "0x26Cd328f2bdFe13A99b7e2FC19BbdCB4d8B54D69",
                "AaveV3Adapter": "0x9cfb64D91Ce4eB821fF8EdC1C2fdA2E89E256707",
                "AaveV3ATokenListOwner": "0xCFe249a7AE4619980eeA1A2d83a26a5E7281EbB0",
                "AaveV3DebtPositionLib": "0x61a063484d5c124B23740aa27688e2b0CCb562d5",
                "AaveV3DebtPositionParser": "0x81C2a0AC95549FF0F0Fa2d8c3136cc8D4b2439E3",
                "AaveV3FlashLoanAssetManagerFactory": "0xD6e8B30214eF909421EB1d20E5B281777810004A",
                "AaveV3FlashLoanAssetManagerLib": "0x8Aa6F11fEF40Eb24c2f77de538F40aC8a9Ec9f0d",
                "AddressListRegistry": "0x4eb4c7Babfb5d54ab4857265B482Fb6512d22DFF",
                "AlicePositionLib": "0xE57c868F97E8c1DEAF24DC72b89D886EBFa24D9f",
                "AlicePositionParser": "0xFF60eB4b559d63bEbA1738281B63704266C6dAc0",
                "AllowedAdapterIncomingAssetsPolicy": "0x2f0E55830a173d845A886FD574F01a039A07Fc37",
                "AllowedAdaptersPerManagerPolicy": "0xA4507d51c5270Ff91229b76300FF90774384d144",
                "AllowedAdaptersPolicy": "0x720ef97bF835699FCF07591952cD2B132D63a6C0",
                "AllowedAssetsForRedemptionPolicy": "0x823ca839DA344DA59D517b84ce3baB9FFc9f54eE",
                "AllowedDepositRecipientsPolicy": "0xA66BAAa0cCb6468C5A2cB61f5D672C7bA0440Ee1",
                "AllowedExternalPositionTypesPerManagerPolicy": "0x47fB78995D945D501f6f9bAd343d7Ce7d3dB54AB",
                "AllowedExternalPositionTypesPolicy": "0x9e076e7d35a3b881Ab9e3DA958431630FdFa756F",
                "AllowedRedeemersForSpecificAssetsPolicy": "0xEd4AA74490843E7ad64B445eF18CecE8A0562433",
                "AllowedSharesTransferRecipientsPolicy": "0xebE37e43bC6b3AacfE318d6906fc80C4a2a7505A",
                "ArbitraryLoanPositionLib": "0x73CB96137cb5455E77275A6aB3411d0d52d545A9",
                "ArbitraryLoanPositionParser": "0xE959C0eeF487f7eE098aD10998d9dfCF4fa1d1aF",
                "ArbitraryLoanTotalNominalDeltaOracleModule": "0x7F2A48122BBd3ffba33Ed9D1f5cFAbEdE7Caab34",
                "ArrakisV2Adapter": "0xC6e54fb0f526D3516224a5E09BD435323800ad94",
                "ArrakisV2PriceFeed": "0xffF8D5C955D9d71f3A09E166521e12e28d3042c7",
                "AssetValueCalculator": "0xFa3D84D841C55bb9175b0a6f215E2300c40CC5Ab",
                "BalancerV2GaugeTokenPriceFeed": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
                "BalancerV2LiquidityAdapter": "0xAB5dA4aa08B56c7e5A9D5d8A5fF19cF09a88c305",
                "BalancerV2StablePoolPriceFeed": "0x438254D66e2bC576819A76A0ecB11FE41195D39F",
                "BalancerV2WeightedPoolPriceFeed": "0x083B8F465BbA2BB274E48387e3f9C56323341286",
                "ChainlinkLikeWstethPriceFeed": "0x92829C41115311cA43D5c9f722f0E9e7b9fcd30a",
                "ChainlinkLikeYnEthPriceFeed": "0xa8f6033cE40FaB29C228f32Ef44d38cB3043c5Bc",
                "CompoundAdapter": "0x6ce8095a692afF6698c3Aa8593BE3976B6b8743D",
                "CompoundDebtPositionLib": "0xc8e0c169dAE4cdfD2F51E7494D2B5459F9314ee9",
                "CompoundDebtPositionParser": "0x8BFbd013020c4D26D043183eff600ea3b36B4afb",
                "CompoundPriceFeed": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
                "CompoundV3TokenListOwner": "0xa9E085B1CA8ECd1dd5BF4c1B5feD3BE84C341Fd4",
                "CompoundV3Adapter": "0xFaA9B9Cc98503F51A54F6038DfdD0E43AA0Ac98e",
                "ComptrollerLib": "0x03F7f3B8Da875881206655D8099B9DACf721f1EF",
                "ConvertedQuoteAggregatorFactory": "0x8F1E6f61323Bf64A47fFbfCa99e9e2Bd4f982c07",
                "ConvexVotingPositionLib": "0x12Fa6805a1ff2d21318Dcbcf677712Bde8a033E1",
                "ConvexVotingPositionParser": "0x4619b0394f09Ef964407deDCe4ca19AD012BCa20",
                "CumulativeSlippageTolerancePolicy": "0x3A49D5aEC385Ac1bDe99F305316b945C5Ee71312",
                "CurveExchangeAdapter": "0xC9c14a99cCF467EA1ff2e19584A5FaBA3671B8de",
                "CurveLiquidityAaveAdapter": "0x83E249d603459D2A926EE85d8ba8d0AeABe101F2",
                "CurveLiquidityAdapter": "0xEa0a896ddE31CFcB53A96ac767119B69D7B4f633",
                "CurveLiquiditySethAdapter": "0x87Db8e815f9BDE3b5b686e3E892FAF0E86481c44",
                "CurveLiquidityStethAdapter": "0x1453E5a5C029cdd91f584c603818baf2ab4CE663",
                "CurvePriceFeed": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "DepositWrapper": "0x65BbAD6545B7ac9C30Fb0f07e64e25106Bf05eEc",
                "DisallowedAdapterIncomingAssetsPolicy": "0x5E216f370e3555FEb9A0575A57AdA732A9e50386",
                "Dispatcher": "0xC3DC853dD716bd5754f421ef94fdCbac3902ab32",
                "EntranceRateBurnFee": "0xCDEc5BBECC6d2C004D5378A63a3c484c2643eD9d",
                "EntranceRateDirectFee": "0xFb8DF7D5e320020Cd8047226b81cf6d68F3E3C19",
                "ERC4626Adapter": "0x64Fa106DD89F21d6e687EEbE9384637F7d54f707",
                "ERC4626PriceFeed": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
                "EtherFiEthPriceFeed": "0x31103dB5639AD1d5351B83409fDf7E575e26774b",
                "ExitRateBurnFee": "0x06b13918E988D1314dA1a9dA4C0cdE5fe994364a",
                "ExitRateDirectFee": "0x3a09d11C20AA1aD38C77B4f426901d3427f73fBE",
                "ExternalPositionFactory": "0x0AAcb782205dde9eFf4862ACe9849DcE1ca3409f",
                "ExternalPositionManager": "0x1e3dA40f999Cf47091F869EbAc477d84b0827Cf4",
                "FeeManager": "0xAf0DFFAC1CE85c3fCe4c2BF50073251F615EefC4",
                "FiduPriceFeed": "0x478335491E1fB798c64a9E95CA43d3D967F42486",
                "FundDataProviderRouter": "0x781ec8517a75172EA007d7458ea1811fC9F99C30",
                "FundDeployer": "0x4f1C53F096533C04d8157EFB6Bca3eb22ddC6360",
                "FundValueCalculator": "0x490e64E0690b4aa481Fb02255aED3d052Bad7BF1",
                "FundValueCalculatorRouter": "0x7c728cd0CfA92401E01A4849a01b57EE53F5b2b9",
                "GasRelayPaymasterFactory": "0x846bbe1925047023651de7EC289f329c24ded3a8",
                "GasRelayPaymasterLib": "0x2F1D153DD821258Caa15656BDe910e146e5F2f77",
                "GatedRedemptionQueueSharesWrapperFactory": "0x73b9C40530311b49B526f230D01Bdf5725B3290d",
                "GatedRedemptionQueueSharesWrapperLib": "0xE971375e3E8af54232F9B7c88cCE143EDf95C272",
                "GenericAdapter": "0x0000000000000000000000000000000000000000",
                "GlobalConfigLib": "0x6682E70860d48a039F52DaCCdA917250349a3fB3",
                "GlobalConfigProxy": "0x5611dF74A77EfD198De5Fc7f83A482DcFE0c7A7A",
                "GMXV2LeverageTradingPositionLib": "0x0000000000000000000000000000000000000000",
                "GMXV2LeverageTradingPositionParser": "0x0000000000000000000000000000000000000000",
                "IntegrationManager": "0x31329024f1a3E4a4B3336E0b1DfA74CC3FEc633e",
                "KilnStakingPositionLib": "0x266c98eF7C16c791a27Dc60E8877e8e3954090A2",
                "KilnStakingPositionParser": "0xFa9a7f8f30c9BC741BE5959af8Cd48636A6aecC2",
                "LidoWithdrawalsPositionLib": "0xa511ecEa62F360E983829e408Fc753ADcADcdEAE",
                "LidoWithdrawalsPositionParser": "0x501083bE98eBb2d75bE75459aCcc5C5922C07F28",
                "LiquityDebtPositionLib": "0x016b63941Df5fD92B49F861559d8B7792629419F",
                "LiquityDebtPositionParser": "0x55e41333D949F13C73aE99689d7137574D927d4B",
                "ManagementFee": "0xFaF2c3DB614E9d38fE05EDc634848BE7Ff0542B9",
                "ManualValueOracleFactory": "0x0edbb060A8f00F5967eECFC87c8559fA65501A3D",
                "MapleLiquidityPositionLib": "0xB35623A479383b87da32fdDe8dBe83FaC5f6bf3D",
                "MapleLiquidityPositionParser": "0x31915278772A2bC68cBFb7Effe1209677b0Aad10",
                "MinAssetBalancesPostRedemptionPolicy": "0x58C0a2A546b3903fA68a53e34EE0C8A02AABFAD0",
                "MinMaxInvestmentPolicy": "0xebdadFC929c357d12281118828AeA556db5be30C",
                "MinSharesSupplyFee": "0xbC9dA8eddE80ffb1294852d23EE1b385Ea2d4929",
                "MorphoBluePositionLib": "0xd84123F688601133d478949277BE8065f48Ff810",
                "MorphoBluePositionParser": "0xfDf34798B21774523Be370490b8730807d4f9167",
                "NoDepegOnRedeemSharesForSpecificAssetsPolicy": "0x96ef0f7c10505460fA39C57a037a5EC2520b8B25",
                "NotionalV2PositionLib": "0x73436d870dA10281Aa3872b1eC48451e077900DE",
                "NotionalV2PositionParser": "0x59053fC5ee387321ea4aB415d1160e49E4f5B166",
                "OneInchV5Adapter": "0x6C62b8F7b2fd1c60fFD3Afc1A2B15d4318745677",
                "OnlyRemoveDustExternalPositionPolicy": "0x966eC191ED9e026Cb6f7e22BB2A284bad6A2838d",
                "OnlyUntrackDustOrPricelessAssetsPolicy": "0x747bEAEe139FbA4a89fA71bEBB5F21231530292B",
                "ParaSwapV5Adapter": "0x871a7f0eF4917a1534E651d1fDe3763A52A23ECe",
                "PeggedDerivativesPriceFeed": "0x86533352BDd201c89f184f7ebbFeBea3E31c8Bb3",
                "PerformanceFee": "0xfeDC73464Dfd156d30F6524654a5d56E766DA0c3",
                "PendleV2Adapter": "0xe77Ba2e88Aae1543839eC6Ee0A0f847391205610",
                "PendleV2PositionLib": "0x85C474A1dbf7fDc22C592382aD554Bb42CebcE0b",
                "PendleV2PositionParser": "0x559AF4E5765D60003E4895d23080C501CBB9ED3C",
                "PendleMarketsRegistry": "0x31391adF6402fDd4eb4b57801A612b0987a0B0f2",
                "PolicyManager": "0xADF5A8DB090627b153Ef0c5726ccfdc1c7aED7bd",
                "PoolTogetherV4Adapter": "0x0000000000000000000000000000000000000000",
                "PoolTogetherV4PriceFeed": "0x0000000000000000000000000000000000000000",
                "ProtocolFeeReserveLib": "0xA0ed89af63367Ddc8e1dd6b992F20D1214cCB51C",
                "ProtocolFeeReserveProxy": "0xB7460593BD222E24a2bF4393aa6416bD373995E0",
                "ProtocolFeeTracker": "0xe97980f1D43C4CD4F1EeF0277a2DeA7ddBc2Cd13",
                "SharePriceThrottledAssetManagerFactory": "0x0883BA10F44217B97bDE11900e197738a7dF911B",
                "SharePriceThrottledAssetManagerLib": "0xFdE8c198BeF60D026332a671F64c34D65C60C935",
                "SharesSplitterFactory": "0xfc8ed755c52782fA1A4bA9193B566E775701E511",
                "SingleAssetRedemptionQueueFactory": "0xfE84D5209054254389C9D6a754B821f3a297D56a",
                "SingleAssetRedemptionQueueLib": "0x0012B7C26b8C081a29A61cD52526cF6305367968",
                "SolvV2BondBuyerPositionLib": "0x0E7D828f9F9A3Ce152D39f21F2e2D0fF89448b6b",
                "SolvV2BondBuyerPositionParser": "0xA2Ed786215d6F4DA95338ee7abB84f28134dc19c",
                "SolvV2BondIssuerPositionLib": "0x31c30bAcb054f5dB7f5bC96850b488440AbB8991",
                "SolvV2BondIssuerPositionParser": "0xC4B599043a5479398eb8Af387b1E36D9A924F8C2",
                "StaderSDPriceFeed": "0x9938B14A25a4910531d5cBdf3c41510b19aaF016",
                "StaderStakingAdapter": "0x7F1B68d5Ed183CdA6788A66520506eAF3544001C",
                "StaderWithdrawalsPositionLib": "0x5Cf43F5f8c1648Db23948e3814d0099c408201a4",
                "StaderWithdrawalsPositionParser": "0xaeFE3260dCBCfaA2A4b927A6494057837E6dD902",
                "StakeWiseV3StakingPositionLib": "0xeF268Eb475a096AdB95712b05b095aCc1Fc2d3aE",
                "StakeWiseV3StakingPositionParser": "0x642348Ee0c28C2943082f950F3A35dB07Bd4bbDF",
                "SwellStakingAdapter": "0x50bAe03333Dd8495263c9049091a8925063b068E",
                "SynthetixAdapter": "0x4bAF8282571FEbdfd8768b475551EC14e144Edb3",
                "TermFinanceV1LendingPositionLib": "0x2817AB33b56ec310621592BfDbE1fAd6470D19a0",
                "TermFinanceV1LendingPositionParser": "0xa95C7Bab91692df52255b8Ad50C5eD2bcC9064aD",
                "TheGraphDelegationPositionLib": "0x6fFf66d55698A601e91989c44349Da8a2A9A7848",
                "TheGraphDelegationPositionParser": "0x2226D7687109d6B6A0882f8EEF2b4A4c90dc677E",
                "ThreeOneThirdAdapter": "0x5a1c0E89133C4Cd844A8B345370565f1368A79A8",
                "TransferAssetsAdapter": "0xe0309Fa2412B811a0BD40A73297093707259217f",
                "UintListRegistry": "0x6FfD6fC068E7b365AF18dA4fdC39D3289159407B",
                "UniswapV2ExchangeAdapter": "0x8c36435A653041BFd65515CC82502663C1ce6F0e",
                "UniswapV2LiquidityAdapter": "0xF78130AfedA6d9Df3394b34d36239aeC7FAe48d9",
                "UniswapV2PoolPriceFeed": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
                "UniswapV3Adapter": "0xeD6A08E05cB4260388dc7CC60Bc5fEFcCfab2793",
                "UniswapV3LiquidityPositionLib": "0x20A2D4765bE139475C34DB7B7d856DCF25092C26",
                "UniswapV3LiquidityPositionParser": "0x23805FED4b73a7b77c28f2823733736951C49d6C",
                "UnpermissionedActionsWrapper": "0xCFAB4FCBFE059d5C1840D9dc285a9BFA0F96A118",
                "UsdEthSimulatedAggregator": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
                "ValueInterpreter": "0xD7B0610dB501b15Bfb9B7DDad8b3869de262a327",
                "VaultLib": "0x891dee0483eBAA922E274ddD2eBBaA2D33468A38",
                "WstethPriceFeed": "0x50Da4957032c8fC5F94eC8D5EC8bFcE84f9C9311",
                "YearnVaultV2Adapter": "0x7eA777F9F6ecBf4d03Dc5323d3F057B0730Fc34a",
                "YearnVaultV2PriceFeed": "0x3982e1CC26b99310747Df54f445063745C54A324",
                "ZeroExV2Adapter": "0xace8e944cDa48439E8eeDa4027115CFb6d942854",
                "ZeroExV4Adapter": "0xe073406C5306043Eda44F09C67654A7729277a47",
                "ZeroExV4AdapterPmm2Kyc": "0x1376a75316B6Ec7BfFaA0660f34D852A2c0e307B",
                "ZeroLendLRTBTCAaveV3Adapter": "0xbc91Fe394d7d372fbae757dbffd32B44A29b3F6E",
                "ZeroLendLRTBTCAaveV3ATokenListOwner": "0x7AFfC39D73CB7d22a7FD099a16441D9eb96eF31B",
                "ZeroLendLRTBTCAaveV3DebtPositionLib": "0x0958DCa5eF97F1aB0b931bA6395Ef40625c26C9E",
                "ZeroLendLRTBTCAaveV3DebtPositionParser": "0xC4701ABc4E1Ae1ac028f98C0fa9395603bd079E1",
                "ZeroLendRWAStablecoinsAaveV3Adapter": "0x8525B3b6179690B74d7F067F131f780a3Ef1562C",
                "ZeroLendRWAStablecoinsAaveV3ATokenListOwner": "0x55C3498Ee0D5c79b034554f301d8a799bAE7D278",
                "ZeroLendRWAStablecoinsAaveV3DebtPositionLib": "0x81936cd39aa737Feed06Ee6E7EF8aC49c63B99c6",
                "ZeroLendRWAStablecoinsAaveV3DebtPositionParser": "0x05D10E09B4FbcA7e1Dac9bF1FdA804Acc19Ec4c7",
            },
            "inception": 14132862,
            "network": NETWORK_BY_SLUG["ethereum"],
            "slug": "ethereum.sulu",
            "status": "live",
            "version": "sulu",
        },
        "encore": {
            "address": "0x7e6d3b1161DF9c9c7527F68d651B297d2Fdb820B",
            "contracts": {
                "AaveAdapter": "0x32d0CB26C2964749bd5D10Ba93695e52b4B57eA3",
                "AavePriceFeed": "0x4e49a272dC42E26C8772de366aaa93d1AC816794",
                "AdapterBlacklist": "0xA2A031B137452986B0E8fA32c9430D29b9b0494F",
                "AdapterWhitelist": "0x306f571110C5441a8481d3CD7E8B16A7E2E967E3",
                "AggregatedDerivativePriceFeed": "0x2E45f9B3fd5871cCaf4eB415dFCcbDD126F57C4f",
                "AlphaHomoraV1Adapter": "0x63765Ae5Df9bB8AF9D8bc976E595b79907CF341c",
                "AlphaHomoraV1PriceFeed": "0x1a8b4f6D469Ee775d5982C4d4AAb46677c2C92d4",
                "AssetBlacklist": "0xdC1e40174ad831e505E8191881A66e90c3681E33",
                "AssetValueCalculator": "0xa85cbA5B7a1139848C5b8C6dfFc3E4107bF8f018",
                "AssetWhitelist": "0xA3b7B872407452E38dFfACa8dA2dB3eD6D756Ad1",
                "BuySharesCallerWhitelist": "0xBc91dcc90cCdd0B51e3C623528cb886358C60105",
                "ChainlinkPriceFeed": "0x1fad8faf11E027f8630F394599830dBeb97004EE",
                "CompoundAdapter": "0xb7bfd3582582A82Ef2A2f0Df0adf705f35A07D4B",
                "CompoundPriceFeed": "0x6d7F71Cc3109D4132Ad6124D84e72E353b979880",
                "ComptrollerLib": "0x1A7CBEDf13E25818dC377d2B1277E03e5d496300",
                "CurveExchangeAdapter": "0x1990D8Bc382D38fA21EE3B570e9d1E6272152165",
                "CurveLiquidityAaveAdapter": "0x78bA80C8517A4f3146FD76A3642Fa57B77F331eb",
                "CurveLiquidityEursAdapter": "0x893b4FA60eFBABFC35a54795E2ea9Eb97344f64D",
                "CurveLiquiditySethAdapter": "0xeE91E3bB4752F358DDAaC6ab825536698b239546",
                "CurveLiquidityStethAdapter": "0x6367bb496390dDf0ef508Db2992F53DBf376b1f4",
                "CurvePriceFeed": "0xc106f1B01017c854a9cd2D88Db733408236DD809",
                "Dispatcher": "0xC3DC853dD716bd5754f421ef94fdCbac3902ab32",
                "EntranceRateBurnFee": "0x27F74B89B29508091014487253d8D9b88aa0264A",
                "EntranceRateDirectFee": "0x30a398Eb63B62bF2865F90e37752c8300Ef22F05",
                "FeeManager": "0x5D0A363E9a17fb839e2843ffa93C808CdafCCb67",
                "FundActionsWrapper": "0xbc9a63cad5a825bD5854Abca4f3D42d6aCF9Bffa",
                "FundDataProviderRouter": "0x781ec8517a75172EA007d7458ea1811fC9F99C30",
                "FundDeployer": "0x7e6d3b1161DF9c9c7527F68d651B297d2Fdb820B",
                "FundValueCalculator": "0x21560C8c72BEBe1a240d442813F2C35B05cAc5EC",
                "FundValueCalculatorRouter": "0x7c728cd0CfA92401E01A4849a01b57EE53F5b2b9",
                "GuaranteedRedemption": "0x08d4225f0995D770C4C8ea85380602B3499164a9",
                "IdleAdapter": "0x649B6cc835C8fE3D3b94b6a9c155f791bF500DFE",
                "IdlePriceFeed": "0x13c2263e534BD27149d96b8Cb9961ea1beB560Ef",
                "IntegrationManager": "0x965ca477106476B4600562a2eBe13536581883A6",
                "InvestorWhitelist": "0x775f8D5d016C4D8a1427982148ec2170282c7784",
                "KyberAdapter": "0x4ff16EfF3b6D2175A513EF4c5b95f5f4D2F05179",
                "LidoStethPriceFeed": "0x11D8d414724281BD702838BA16C8F15F7C473e9a",
                "ManagementFee": "0x45F1b268CC6412B454Dae20F8971fc4A36aF0D29",
                "MaxConcentration": "0xDee63B253432a443A09bF8461f20256d184319de",
                "MinMaxInvestment": "0x016a7287F0fDbDcE5f903334f574b2238Be3fA25",
                "ParaSwapV4Adapter": "0x8eA6Ca02274E1b05b70c11058213ADC667258C3D",
                "PerformanceFee": "0x3c3f9143A15042B69eB314Cac211688A4E71a087",
                "PolicyManager": "0x0Bd9f0465d21d4c300c7B8d781A013bdc87A31E8",
                "StakehoundEthPriceFeed": "0xd3C515EAD7Bcc7451cd920e066C4a1849B827dfD",
                "SynthetixAdapter": "0x07698C3fA26a62EC6320872bF2950bA160A2dd7C",
                "SynthetixPriceFeed": "0x4158F02ac2fF0f0E7959A768D06619B685aBF0C8",
                "TrackedAssetsAdapter": "0xeA05F4a383adCE7F1E9cC1b6029B51d7260E53aa",
                "UniswapV2Adapter": "0x8481150a0f36c98EE859e6C7B46d61FDD836768f",
                "UniswapV2PoolPriceFeed": "0x37FFB1842eF012d83A6FFdc92A6353044Ae0e3e8",
                "ValueInterpreter": "0x10a5624840Ac07287f756777DF1DEC34d2C2d654",
                "VaultLib": "0x1b3694907Ed7459c7B0116e7c6a4B7788288577F",
                "WdgldPriceFeed": "0x76b548553d4E729c81e8ae8Ab826795bd88BA9E7",
                "YearnVaultV2Adapter": "0xDA27D95Bd940cAc017f9484175E5512D3e4B0662",
                "YearnVaultV2PriceFeed": "0x7B768DD670B6f0d4AFC270cb413A8F7ca1889BD7",
                "ZeroExV2Adapter": "0x9b6cD2195d3c275875cB469A59dd437995712550",
            },
            "inception": 12387778,
            "network": NETWORK_BY_SLUG["ethereum"],
            "slug": "ethereum.encore",
            "status": "deprecated",
            "version": "encore",
        },
        "phoenix": {
            "address": "0x9134C9975244b46692Ad9A7Da36DBa8734Ec6DA3",
            "contracts": {
                "AaveAdapter": "0x14c6b99AfFC61e9b0753146F3437A223d0c58279",
                "AavePriceFeed": "0x3996D53013f562FD6D5B777Ab0Ee681802698e0D",
                "AdapterBlacklist": "0x9f471f573414d9cAcFe3A0127aD12F195504de7B",
                "AdapterWhitelist": "0xb4dF8b4f3eC62619E8D2aed5df360aa393BB8745",
                "AggregatedDerivativePriceFeed": "0xCFb6F4C08856986d13839B1907b5c645EE95388F",
                "AlphaHomoraV1Adapter": "0xed6Bdfa2725da6687bC89Bcb0BDB1e5dEAe15838",
                "AlphaHomoraV1PriceFeed": "0x5f2E2E7FfbcAeE69d570D531A00228322632231E",
                "AssetBlacklist": "0x2A7CD39427831045e7050723006697fD0801B184",
                "AssetValueCalculator": "0x929186c01e51D00209cf520BaC0651DCA4b6Fad1",
                "AssetWhitelist": "0x664F6C88CA8d5888b11B97450A5623003b8981B9",
                "BuySharesCallerWhitelist": "0x21fc97450c65dAfe14255A06Cf9c5C88483bA309",
                "ChaiAdapter": "0xB3646e9B6dF463a2dC36de67FFD28cbAb3f8A5cC",
                "ChaiPriceFeed": "0x8bA6f2D9C81Db32665df6a926227dD00cacA7d9B",
                "ChainlinkPriceFeed": "0xfB3A9655F5feA18caC92021E83550F829ae6F7F7",
                "CompoundAdapter": "0xD050DC9E75f24Ae653d282D0cFb772871729e710",
                "CompoundPriceFeed": "0xC80bD25cd46e49277CcB56E751704A6316Af30aD",
                "ComptrollerLib": "0x94F262802806BE3646612D0705802710dD5B58dF",
                "CurveExchangeAdapter": "0x402A81aD2972a017B4564453E69afaE2b006A7E2",
                "CurveLiquidityAaveAdapter": "0xF6F7cc9464Cb15e0A5B116D738dCa88434bbA00A",
                "CurveLiquiditySethAdapter": "0xbD81a0eF03F4eD89F73a30eb33137787BF92e177",
                "CurveLiquidityStethAdapter": "0x3Bb38E67033e24E604e53964A99D914f8B216521",
                "CurvePriceFeed": "0x884D909EA86EC61128a4cFE1B455d5B440cdE9C8",
                "Dispatcher": "0xC3DC853dD716bd5754f421ef94fdCbac3902ab32",
                "EntranceRateBurnFee": "0xA831a43f99af957bc27D03963958Fd710DC1f50E",
                "EntranceRateDirectFee": "0x42bc95f119Fb08b9FC72262D255016fa5546caa4",
                "FeeManager": "0xEcDbcdB8Dbf0AC54f47E41D3DD0C7DaE07828aAa",
                "FundActionsWrapper": "0x38c9f2870003d47f704e317C10f93Ca1ddAE67C1",
                "FundDataProviderRouter": "0x781ec8517a75172EA007d7458ea1811fC9F99C30",
                "FundDeployer": "0x9134C9975244b46692Ad9A7Da36DBa8734Ec6DA3",
                "FundValueCalculator": "0xc60642c271cd1102e922027aF81e4ed4736D48C7",
                "FundValueCalculatorRouter": "0x7c728cd0CfA92401E01A4849a01b57EE53F5b2b9",
                "GuaranteedRedemption": "0xda9d4Ee6C846E0b504979ea3d607c2e98574A09C",
                "IdleAdapter": "0x2f7918d9A98c199173fb8ca989B408B4Fb1EA441",
                "IdlePriceFeed": "0x08eCd9e1378DC0262df826C07D3D64c728a46829",
                "IntegrationManager": "0xFc3f356217120318Bd46c879b3A55C3135473752",
                "InvestorWhitelist": "0x3C8a4DaCe64B238C8307E3AF563fCf76Cf870d57",
                "KyberAdapter": "0x963E9C15a26d74085ABfC8B48280b650426F998e",
                "LidoStethPriceFeed": "0x4F3Da46BF999C6b3005C1465672009fBF99e7b9f",
                "ManagementFee": "0x889f2FCB6c12d836cB8f7567A1bdfa512FE9f647",
                "MaxConcentration": "0x6b9a7604faB14721B51A89Cd1CcEF639Da8664eE",
                "MinMaxInvestment": "0xDCCae078656f20B0851Dd35683315be56AEEe8f3",
                "ParaSwapV4Adapter": "0x1C1B94812Faf3dE496a2634B36C1FbC6e5c222e7",
                "PerformanceFee": "0x70478df01108Cb2fCB23463814e648363CE17720",
                "PolicyManager": "0x4c2c07b15b0b32Bad989d9DeFaeC775e2aA8A7AD",
                "StakehoundEthPriceFeed": "0xE2B19FA2D662F4eEA51D394b71Ce7281214840C5",
                "SynthetixAdapter": "0xBF3411973F09c32E8c4e67d1345DdDC5F9c7535a",
                "SynthetixPriceFeed": "0x2180341339010C237FF8e3dd1fF24063FB18C4D0",
                "TrackedAssetsAdapter": "0xde4A42052db0FB0E8935C9F3015b8cd56A3dDF43",
                "UniswapV2Adapter": "0x972318a0f4935c3153a2AA4c81274DfF621B360b",
                "UniswapV2PoolPriceFeed": "0x9177A3354EE50bffBcC42C4c6baC27ed63979097",
                "ValueInterpreter": "0x6618bF56E1C7b6c8310Bfe4096013bEd8F191628",
                "VaultLib": "0xAC3fe07F51C51153E181bE892e4e37326EEA13Da",
                "WdgldPriceFeed": "0x45919dcDECcA3C7a0D29f959E6b78a605a17A3A2",
                "ZeroExV2Adapter": "0x4205073e7AD2F9896F827DBCe496dd2306DB602e",
            },
            "inception": 11636497,
            "network": NETWORK_BY_SLUG["ethereum"],
            "slug": "ethereum.phoenix",
            "status": "deprecated",
            "version": "phoenix",
        },
    },
    "slug": "ethereum",
    "subgraphs": {
        "assets": {
            "slug": "asset-universe",
            "id": "4ZW3mDNgpDVy68RipQLJxvRw1FReJTfvA7nbB52J4Gjg",
        },
        "balances": {
            "slug": "vault-balances",
            "id": "HwR7jTExHWNvQetTxRYEMQ5hywHyUkierAYvnGS7pBUS",
        },
        "core": {
            "slug": "enzyme-core",
            "id": "9DLBBLep5UyU16kUQRvxBCMqko4q9XzuE4XsMMpARhKK",
            "dev_version": "version/latest",
        },
        "shares": {
            "slug": "vault-shares",
            "id": "6p2L2gQ4Hw4Dh2kxZFDJbcqtbv44vrJbrBEh3EjS7qVo",
        },
        "vaults": {
            "slug": "vault-lineage",
            "id": "5FdivFcUPmVSqCFkv3jqJh3QYjHjh1ztzd7GHiCAMP1h",
        },
    },
}
