from typing import Literal


Protocol = Literal[
    "AAVE",
    "AAVE_V3",
    "AURA",
    "ALICE",
    "BALANCER",
    "COMPOUND_V2",
    "COMPOUND_V3",
    "CONVEX",
    "CURVE",
    "KILN",
    "LIQUITY",
    "MAPLE",
    "MORPHO",
    "ONE_INCH_V5",
    "SPARK",
    "THE_GRAPH",
    "UNISWAP",
    "UNISWAP_V2",
    "VAULTCRAFT",
    "YEARN_VAULT_V2",
]
