from ..releases import RELEASES
from ..assets import define_asset_list
from ..networks import NETWORK_BY_SLUG
from ..price_feeds import RateAsset


SULU, ENCORE, PHOENIX = [RELEASES["ethereum"][r] for r in ["sulu", "encore", "phoenix"]]


ASSETS = define_asset_list(
    NETWORK_BY_SLUG["ethereum"],
    [
        {
            "decimals": 18,
            "id": "0x0000000000085d4780B73119b644AE5ecd22b376",
            "name": "TrueUSD",
            "releases": [],
            "symbol": "TUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0000000000095413afC295d19EDeb1Ad7B71c952",
            "name": "Tokenlon",
            "releases": [],
            "symbol": "LON",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0000206329b97DB379d5E1Bf586BbDB969C63274",
            "name": "USDA",
            "releases": [SULU],
            "symbol": "USDA",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8fFfFfd4AfB6115b954Bd326cbe7B4BA576818f6",
                "rate_asset": RateAsset.USD,
                "pegged_to": "USDC",
                "non_standard": True,
            },
        },
        {
            "symbol": "stUSD",
            "name": "Staked USDA",
            "id": "0x0022228a2cc5E7eF0274A7Baa600d44da5aB5776",
            "type": "erc-4626",
            "protocol": "angle",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x0000206329b97DB379d5E1Bf586BbDB969C63274",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
                "non_standard": True,
            },
        },
        {
            "decimals": 18,
            "id": "0x004375Dff511095CC5A197A54140a24eFEF3A416",
            "name": "Uniswap WBTC/USDC Pool",
            "releases": [SULU, ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x0202Be363B8a4820f3F4DE7FaF5224fF05943AB1",
            "name": "UniLend Finance Token",
            "releases": [ENCORE],
            "symbol": "UFT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x0258F474786DdFd37ABCE6df6BBb1Dd5dfC4434a",
            "name": "Orion Protocol",
            "releases": [],
            "symbol": "ORN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x028171bCA77440897B824Ca71D1c56caC55b68A3",
            "name": "Aave DAI",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aDAI",
            "type": "aave-v2",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xAed0c38402a5d19df6E4c03F4E2DceD6e29c1ee9",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x018008bfb33d285247A21d44E50697654f754e63",
            "name": "Aave Ethereum DAI",
            "releases": [SULU],
            "symbol": "aEthDAI",
            "type": "aave-v3",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xAed0c38402a5d19df6E4c03F4E2DceD6e29c1ee9",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x02d341CcB60fAaf662bC0554d13778015d1b285C",
            "name": "Curve.fi aDAI/aSUSD",
            "pool": "0xEB16Ae0052ed37f479f7fe63849198Df1765a733",
            "releases": [SULU],
            "staking": [
                {"token": "0x462253b8F74B72304c145DB0e4Eebd326B22ca39", "type": "gauge"}
            ],
            "symbol": "saCRV",
            "template": "aave",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x028171bCA77440897B824Ca71D1c56caC55b68A3",
                "0x6C5024Cd4F8A59110119C56f8933403A539555EB",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x030bA81f1c18d280636F32af80b9AAd02Cf0854e",
            "name": "Aave WETH",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aWETH",
            "type": "aave-v2",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5f4eC3Df9cbd43714FE2740f5E3616155c5b8419",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x4d5F47FA6A74757f35C14fD3a6Ef8E3C9BC514E8",
            "name": "Aave Ethereum WETH",
            "releases": [SULU],
            "symbol": "aEthWETH",
            "type": "aave-v3",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5f4eC3Df9cbd43714FE2740f5E3616155c5b8419",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "id": "0x1c0E06a0b1A4c160c17545FF2A951bfcA57C0002",
            "name": "Aave Ethereum ETHx",
            "symbol": "aEthETHx",
            "decimals": 18,
            "releases": [SULU],
            "type": "aave-v3",
            "underlying": "0xA35b1B31Ce002FBF2058D22F30f95D405200A15b",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK_LIKE_ETHX",
                "aggregator": "0x75c4Dc3201015C78a60dBe673FC7247549527C1b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x0316EB71485b0Ab14103307bf65a021042c6d380",
            "name": "Huobi BTC",
            "releases": [],
            "symbol": "HBTC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0352557B007A4Aae1511C114409b932F06F9E2f4",
            "name": "Synth sRUNE",
            "releases": [],
            "symbol": "sRUNE",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0391D2021f89DC339F60Fff84546EA23E337750f",
            "name": "BarnBridge Governance Token",
            "releases": [],
            "symbol": "BOND",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x03ab458634910AaD20eF5f1C8ee96F1D6ac54919",
            "name": "Rai Reflex Index",
            "releases": [ENCORE],
            "symbol": "RAI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x04Fa0d235C4abf4BcF4787aF4CF447DE572eF828",
            "name": "UMA Voting Token v1",
            "releases": [],
            "symbol": "UMA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 2,
            "id": "0x056Fd409E1d7A124BD7017459dFEa2F387b6d5Cd",
            "name": "Gemini dollar",
            "releases": [],
            "symbol": "GUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x05ff47AFADa98a98982113758878F9A8B9FddA0a",
            "name": "Balancer weETH/rETH StablePool",
            "releases": [SULU],
            "symbol": "weETH/rETH",
            "staking": [
                {"token": "0xC859BF9d7B8C557bBd229565124c2C09269F3aEF", "type": "gauge"}
            ],
            "pool_id": "0x05ff47afada98a98982113758878f9a8b9fdda0a000000000000000000000645",
            "pool_factory": "0xDB8d758BCb971e482B2C45f7F8a7740283A1bd3A",
            "pool_type": "composable-stable-v5",
            "underlyings": [
                "0x05ff47AFADa98a98982113758878F9A8B9FddA0a",
                "0xae78736Cd615f374D3085123A210448E74Fc6393",
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_STABLE_POOL",
                "address": "0x438254D66e2bC576819A76A0ecB11FE41195D39F",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x06325440D014e39736583c165C2963BA99fAf14E",
            "name": "Curve.fi ETH/stETH",
            "pool": "0xDC24316b9AE028F1497c275EB9192a3Ea0f67022",
            "releases": [SULU],
            "staking": [
                {"token": "0x182B723a58739a9c974cFDB385ceaDb237453c28", "type": "gauge"}
            ],
            "symbol": "steCRV",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xae7ab96520DE3A18E5e111B5EaAb095312D7fE84",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x06AF07097C9Eeb7fD685c692751D5C66dB49c215",
            "name": "Chai",
            "releases": [],
            "symbol": "CHAI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x075b1bb99792c9E1041bA13afEf80C91a1e70fB3",
            "name": "Curve.fi renBTC/wBTC/sBTC",
            "pool": "0x7fC77b5c7614E1533320Ea6DDc2Eb61fa00A9714",
            "releases": [SULU],
            "staking": [],
            "symbol": "crvRenWSBTC",
            "template": "base",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xEB4C2781e4ebA804CE9a9803C67d0893436bB27D",
                "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
                "0xfE18be6b3Bd88A2D2A7f928d00292E7a9963CfC6",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            },
        },
        {
            "decimals": 18,
            "id": "0x090185f2135308BaD17527004364eBcC2D37e5F6",
            "name": "Spell Token",
            "releases": [SULU, ENCORE],
            "symbol": "SPELL",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8c110B94C5f1d347fAcF5E1E938AB2db60E3c9a8",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x09a3EcAFa817268f77BE1283176B946C4ff2E608",
            "name": "Wrapped MIR Token",
            "releases": [],
            "symbol": "MIR",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0Ae055097C6d159879521C384F1D2123D1f195e6",
            "name": "STAKE",
            "releases": [],
            "symbol": "STAKE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0bc529c00C6401aEF6D220BE8C6Ea1667F6Ad93e",
            "name": "yearn.finance",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "YFI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x7c5d4F8345e66f68099581Db340cd65B078C41f4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x0d438F3b5175Bebc262bF23753C1E53d03432bDE",
            "name": "Wrapped NXM",
            "releases": [ENCORE, PHOENIX],
            "symbol": "wNXM",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0d4a11d5EEaaC28EC3F61d100daF4d40471f1852",
            "name": "Uniswap ETH/USDT Pool",
            "releases": [SULU, ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x0D8775F648430679A709E98d2b0Cb6250d2887EF",
            "name": "Basic Attention Token",
            "releases": [],
            "symbol": "BAT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0F5D2fB29fb7d3CFeE444a200298f468908cC942",
            "name": "Decentraland MANA",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "MANA",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x82A44D92D6c329826dc557c5E1Be6ebeC5D5FeB9",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x0F83287FF768D1c1e17a42F44d644D7F22e8ee1d",
            "name": "Synth sCHF",
            "releases": [],
            "symbol": "sCHF",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0fEd38108bdb8e62ef7b5680E8E0726E2F29e0De",
            "name": "Synth iREN",
            "releases": [],
            "symbol": "iREN",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x111111111117dC0aa78b770fA6A738034120C302",
            "name": "1INCH Token",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "1INCH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x72AFAECF99C9d9C8215fF44C77B94B99C28741e8",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x11b1f53204d03E5529F09EB3091939e4Fd8c9CF3",
            "name": "Uniswap MANA/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x0F5D2fB29fb7d3CFeE444a200298f468908cC942",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 8,
            "id": "0x123151402076fc819B7564510989e475c9cD93CA",
            "name": "wrapped-DGLD",
            "releases": [ENCORE, PHOENIX],
            "symbol": "wDGLD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1273aD5D8f3596A7a39EfDb5a4b8f82E8F003fc3",
            "name": "Uniswap HEGIC/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x584bC13c7D411c00c01A62e8019472dE68768430",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1494CA1F11D487c2bBe4543E90080AeBa4BA3C2b",
            "name": "DefiPulse Index",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "DPI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x029849bbc0b1d93b85a8b6190e979fd38F5760E2",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x14d10003807AC60d07BB0ba82cAeaC8d2087c157",
            "name": "Synth iDEFI",
            "releases": [],
            "symbol": "iDEFI",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x158079Ee67Fce2f58472A96584A73C7Ab9AC95c1",
            "name": "Compound Augur",
            "releases": [],
            "symbol": "cREP",
            "type": "compound-v2",
            "underlying": "0x1985365e9f78359a9B6AD760e32412f4a445E862",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x15ab0333985FD1E289adF4fBBe19261454776642",
            "name": "Uniswap ETH/MLN Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xec67005c4E498Ec7f55E092bd1d35cbC47C91892",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x1715AC0743102BF5Cd58EfBB6Cf2dC2685d967b6",
            "name": "Synth sDOT",
            "releases": [],
            "symbol": "sDOT",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x176C674Ee533C6139B0dc8b458D72A93dCB3e705",
            "name": "Synth iAAVE",
            "releases": [],
            "symbol": "iAAVE",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1776e1F26f98b1A5dF9cD347953a26dd3Cb46671",
            "name": "Numeraire",
            "releases": [],
            "symbol": "NMR",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x182B723a58739a9c974cFDB385ceaDb237453c28",
            "lp": "0x06325440D014e39736583c165C2963BA99fAf14E",
            "name": "Curve.fi steCRV Gauge Deposit",
            "pool": "0xDC24316b9AE028F1497c275EB9192a3Ea0f67022",
            "releases": [SULU],
            "symbol": "steCRV-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xae7ab96520DE3A18E5e111B5EaAb095312D7fE84",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x1936836409757bB5878028057484BE3FAf2d798e",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: LUSDFRAXBP Convex Deposit",
            "releases": [],
            "symbol": "stkcvxLUSDFRAXBP3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x194eBd173F6cDacE046C53eACcE9B953F28411d1",
            "name": "Curve.fi EURS/sEUR",
            "pool": "0x0Ce6a5fF5217e38315f87032CF90686C96627CAA",
            "releases": [],
            "staking": [
                {"token": "0x90Bb609649E0451E5aD952683D64BD2d1f245840", "type": "gauge"}
            ],
            "symbol": "eursCRV",
            "template": "base",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xdB25f211AB05b1c97D595516F45794528a807ad8",
                "0xD71eCFF9342A5Ced620049e616c5035F1dB98620",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1985365e9f78359a9B6AD760e32412f4a445E862",
            "name": "Reputation",
            "releases": [],
            "symbol": "REP",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1982b2F5814301d4e9a8b0201555376e62F82428",
            "name": "Aave STETH",
            "releases": [SULU],
            "symbol": "aSTETH",
            "type": "aave-v2",
            "underlying": "0xae7ab96520DE3A18E5e111B5EaAb095312D7fE84",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x86392dC19c0b719886221c78AB11eb8Cf5c52812",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x19D3364A399d251E894aC732651be8B0E4e85001",
            "name": "DAI yVault 0.3.0",
            "releases": [ENCORE],
            "symbol": "yvDAI",
            "type": "yearn-vault-v2",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1c48f86ae57291F7686349F12601910BD8D470bb",
            "name": "USDK",
            "releases": [],
            "symbol": "USDK",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1F573D6Fb3F13d689FF844B4cE37794d79a7FF1C",
            "name": "Bancor Network Token",
            "releases": [],
            "symbol": "BNT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "name": "Uniswap",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xD6aA3D25116d8dA79Ea0246c4826EB951872e02e",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x201d31c4B2bF5A8a305ffEC76050B1c6D61A8Dc5",
            "name": "Enzyme Staked: Curve.fi cDAI/cUSDC/USDT Convex Deposit",
            "releases": [],
            "symbol": "stkcvxcDAI+cUSDC+USDT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x8236a87084f8B84306f72007F36F2618A5634494",
            "name": "Lombard Staked Bitcoin",
            "releases": [SULU],
            "symbol": "LBTC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xdeb288F737066589598e9214E782fa5A8eD689e8",
                "rate_asset": RateAsset.ETH,
                "pegged_to": "BTC",
                "non_standard": True,
            },
        },
        {
            "decimals": 18,
            "id": "0x221657776846890989a759BA2973e427DfF5C9bB",
            "name": "Reputation",
            "releases": [],
            "symbol": "REPv2",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "maWBTC",
            "name": "Morpho-Aave Wrapped BTC Supply Vault",
            "id": "0xd508F85F1511aAeC63434E26aeB6d10bE0188dC7",
            "type": "erc-4626",
            "protocol": "morpho",
            "underlying": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "releases": [],
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "maWETH",
            "name": "Morpho-Aave Wrapped Ether Supply Vault",
            "id": "0x490BBbc2485e99989Ba39b34802faFa58e26ABa4",
            "type": "erc-4626",
            "protocol": "morpho",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "releases": [],
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "maDAI",
            "name": "Morpho-Aave Dai Stablecoin Supply Vault",
            "id": "0x36F8d0D0573ae92326827C4a82Fe4CE4C244cAb6",
            "type": "erc-4626",
            "protocol": "morpho",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "releases": [],
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "maUSDC",
            "name": "Morpho-Aave USD Coin Supply Vault",
            "id": "0xA5269A8e31B93Ff27B887B56720A25F844db0529",
            "type": "erc-4626",
            "protocol": "morpho",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "releases": [],
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "maUSDT",
            "name": "Morpho-Aave Tether USD Supply Vault",
            "id": "0xAFe7131a57E44f832cb2dE78ade38CaD644aaC2f",
            "type": "erc-4626",
            "protocol": "morpho",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "releases": [],
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "maCRV",
            "name": "Morpho-Aave Curve DAO Token Supply Vault",
            "id": "0x9dc7094530cB1bcf5442c3b9389ee386738A190c",
            "type": "erc-4626",
            "protocol": "morpho",
            "underlying": "0xD533a949740bb3306d119CC777fa900bA034cd52",
            "releases": [],
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "ma3WETH",
            "name": "AaveV3-ETH Optimizer Supply Vault WETH",
            "id": "0x39Dd7790e75C6F663731f7E1FdC0f35007D3879b",
            "type": "erc-4626",
            "protocol": "morpho",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "releases": [],
            "decimals": 18,
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "symbol": "sDAI",
            "name": "Savings Dai",
            "id": "0x83F20F44975D03b1b09e64809B757c47f942BEeA",
            "type": "erc-4626",
            "protocol": "spark",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "decimals": 18,
            "id": "0x22602469d704BfFb0936c7A7cfcD18f7aA269375",
            "name": "Synth sETC",
            "releases": [],
            "symbol": "sETC",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "name": "Wrapped BTC",
            "releases": [SULU, ENCORE],
            "symbol": "WBTC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xdeb288F737066589598e9214E782fa5A8eD689e8",  # TODO: update when Price Feed utils available, so we can create WBTC/USD, and WBTC/ETH price feeds
                "rate_asset": RateAsset.ETH,
                "pegged_to": "BTC",
            },
        },
        {
            "decimals": 18,
            "id": "0x228BF405f392192239aCE4CB73d3861334a5B332",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: Liquity Convex Deposit",
            "releases": [],
            "symbol": "stkcvxLUSD3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x23348160D7f5aca21195dF2b70f28Fce2B0be9fC",
            "name": "Synth sFTSE",
            "releases": [],
            "symbol": "sFTSE",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x23bFf8ca20AAc06EFDf23cEe3B8ae296A30Dfd27",
            "name": "Uniswap wNXM/ETH Pool",
            "releases": [ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x0d438F3b5175Bebc262bF23753C1E53d03432bDE",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x25212Df29073FfFA7A67399AcEfC2dd75a831A1A",
            "name": "Curve EURS Pool yVault 0.3.5",
            "releases": [],
            "symbol": "yvCurve-EURS",
            "type": "yearn-vault-v2",
            "underlying": "0x194eBd173F6cDacE046C53eACcE9B953F28411d1",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x253ED65fff980AEE7E94a0dC57BE304426048b35",
            "name": "Balancer weETH/ezETH/rswETH Gauge Deposit",
            "releases": [SULU],
            "symbol": "weETH/ezETH/rswETH-gauge",
            "pool": "0x848a5564158d84b8A8fb68ab5D004Fae11619A54",
            "pool_type": "composable-stable-v5",
            "gauge_factory": "0xf1665E19bc105BE4EDD3739F88315cC699cc5b65",
            "underlyings": [
                "0x848a5564158d84b8A8fb68ab5D004Fae11619A54",
                "0xbf5495Efe5DB9ce00f80364C8B423567e58d2110",
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
                "0xFAe103DC9cf190eD75350761e95403b7b8aFa6c0",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0x261EfCdD24CeA98652B9700800a13DfBca4103fF",
            "name": "Synth sXAU",
            "releases": [],
            "symbol": "sXAU",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x26aAd2da94C59524ac0D93F6D6Cbf9071d7086f2",
            "name": "Uniswap 1INCH/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x111111111117dC0aa78b770fA6A738034120C302",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x27269b3e45A4D3E79A3D6BFeE0C8fB13d0D711A6",
            "name": "Synth iXRP",
            "releases": [],
            "symbol": "iXRP",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x278cfB6f06B1EFc09d34fC7127d6060C61d629Db",
            "name": "weeTH/rswETH",
            "pool": "0x278cfB6f06B1EFc09d34fC7127d6060C61d629Db",
            "releases": [SULU],
            "staking": [
                {"token": "0x0Bfb387B87e8Bf173a10A7DCf786B0b7875F6771", "type": "gauge"}
            ],
            "symbol": "weeTH/rswE",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
                "0xFAe103DC9cf190eD75350761e95403b7b8aFa6c0",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x272F97b7a56a387aE942350bBC7Df5700f8a4576",
            "name": "Aave BAL",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aBAL",
            "type": "aave-v2",
            "underlying": "0xba100000625a3754423978a60c9317c58a424e3D",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xC1438AA3823A6Ba0C159CfA8D98dF5A994bA120b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x2516E7B3F76294e03C42AA4c5b5b4DCE9C436fB8",
            "name": "Aave Ethereum BAL",
            "releases": [SULU],
            "symbol": "aEthBAL",
            "type": "aave-v3",
            "underlying": "0xba100000625a3754423978a60c9317c58a424e3D",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xC1438AA3823A6Ba0C159CfA8D98dF5A994bA120b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x28fAc5334C9f7262b3A3Fe707e250E01053e07b5",
            "name": "IdleUSDT v4 [Risk adjusted]",
            "releases": [ENCORE],
            "symbol": "idleUSDTSafe",
            "type": "idle",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2bb274d3166D3ab2780E12eb835f7540f07DbBE2",
            "name": "Enzyme Staked: Curve.fi renBTC/wBTC/sBTC Convex Deposit",
            "releases": [],
            "symbol": "stkcvxcrvRenWSBTC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2d7aC061fc3db53c39fe1607fB8cec1B2C162B01",
            "name": "Synth iLINK",
            "releases": [],
            "symbol": "iLINK",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2e59005c5c0f0a4D77CcA82653d48b46322EE5Cd",
            "name": "Synth sXTZ",
            "releases": [],
            "symbol": "sXTZ",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2e9d63788249371f1DFC918a52f8d799F4a38C94",
            "name": "Tokemak",
            "releases": [],
            "symbol": "TOKE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2fDbAdf3C4D5A8666Bc06645B8358ab803996E28",
            "name": "Uniswap YFI/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x0bc529c00C6401aEF6D220BE8C6Ea1667F6Ad93e",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x3041CbD36888bECc7bbCBc0045E3B1f144466f5f",
            "name": "Uniswap USDC/USDT Pool",
            "releases": [SULU, ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
                "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x30635297E450b930f8693297eBa160D9e6c8eBcf",
            "name": "Synth sUNI",
            "releases": [],
            "symbol": "sUNI",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x30D20208d987713f46DFD34EF128Bb16C404D10f",
            "name": "Stader",
            "releases": [SULU],
            "symbol": "SD",
            "type": "stader",
            "price_feed": {
                "type": "DERIVATIVE_STADER_SD",
                "address": "0x9938B14A25a4910531d5cBdf3c41510b19aaF016",
                "non_standard": True,
            },
        },
        {
            "decimals": 18,
            "id": "0x3155BA85D5F96b2d030a4966AF206230e46849cb",
            "name": "THORChain ETH.RUNE",
            "releases": [],
            "symbol": "RUNE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x317241aF62ff54FcBfCb1Da1aFa57A42d15b43D8",
            "name": "Enzyme Staked: Curve.fi USDN/3Crv Convex Deposit",
            "releases": [],
            "symbol": "stkcvxusdn3CRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            "name": "Curve.fi FRAX/USDC",
            "pool": "0xDcEF968d416a41Cdac0ED8702fAC8128A64241A2",
            "releases": [SULU],
            "staking": [
                {
                    "token": "0xCFc25170633581Bf896CB6CDeE170e3E3Aa59503",
                    "type": "gauge",
                },
            ],
            "symbol": "crvFRAX",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x853d955aCEf822Db058eb8505911ED77F175b99e",
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x320623b8E4fF03373931769A31Fc52A4E78B5d70",
            "name": "Reserve Rights",
            "releases": [],
            "symbol": "RSR",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x321C2fE4446C7c963dc41Dd58879AF648838f98D",
            "name": "Cryptex",
            "releases": [],
            "symbol": "CTX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x336213e1DDFC69f4701Fc3F86F4ef4A160c1159d",
            "name": "Synth iCEX",
            "releases": [],
            "symbol": "iCEX",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3391bc034f2935eF0E1e41619445F998b2680D35",
            "name": "IdleUSDC v4 [Risk adjusted]",
            "releases": [ENCORE],
            "symbol": "idleUSDCSafe",
            "type": "idle",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x33baeDa08b8afACc4d3d07cf31d49FC1F1f3E893",
            "name": "Curve.fi Factory USD Metapool: TUSDFRAXBP",
            "pool": "0x33baeDa08b8afACc4d3d07cf31d49FC1F1f3E893",
            "releases": [],
            "staking": [
                {"token": "0xf865FDd6a5F307F398a94Dc40687995Cfaa77BC9", "type": "gauge"}
            ],
            "symbol": "TUSDFRAXBP3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x0000000000085d4780B73119b644AE5ecd22b376",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3472A5A71965499acd81997a54BBA8D852C6E53d",
            "name": "Badger",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "BADGER",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x58921Ac140522867bf50b9E009599Da0CA4A2379",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x359FD5d6417aE3D8D6497d9B2e7A890798262BA4",
            "lp": "0xEcd5e75AFb02eFa118AF914515D6521aaBd189F1",
            "name": "Curve.fi TUSD3CRV-f Gauge Deposit",
            "pool": "0xEcd5e75AFb02eFa118AF914515D6521aaBd189F1",
            "releases": [],
            "symbol": "TUSD3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x0000000000085d4780B73119b644AE5ecd22b376",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x35A18000230DA775CAc24873d00Ff85BccdeD550",
            "name": "Compound Uniswap",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "cUNI",
            "type": "compound-v2",
            "underlying": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "id": "0x35D8949372D46B7a3D5A56006AE77B215fc69bC0",
            "name": "USD0 Liquid Bond",
            "symbol": "USD0++",
            "decimals": 18,
            "releases": [SULU],
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xFC9e30Cf89f8A00dba3D34edf8b65BCDAdeCC1cB",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x35f6B052C598d933D69A4EEC4D04c73A191fE6c2",
            "name": "Aave SNX",
            "releases": [],
            "symbol": "aSNX",
            "type": "aave-v2",
            "underlying": "0xC011a73ee8576Fb46F5E1c5751cA3B9Fe0af2a6F",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x35fA164735182de50811E8e2E824cFb9B6118ac2",
            "name": "ether.fi ETH",
            "releases": [SULU],
            "symbol": "eETH",
            "type": "primitive",
            "price_feed": {
                "type": "DERIVATIVE_ETHERFI",
                "address": "0x31103dB5639AD1d5351B83409fDf7E575e26774b",
            },
        },
        {
            "decimals": 18,
            "id": "0x36A00FF9072570eF4B9292117850B8FE08d96cce",
            "name": "Synth iUNI",
            "releases": [],
            "symbol": "iUNI",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x36a2422a863D5B950882190Ff5433E513413343a",
            "name": "Synth sBCH",
            "releases": [],
            "symbol": "sBCH",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x383D426509424CFcf4ba0873Dea4CA871FE7bDD9",
            "name": "Enzyme Staked: Curve.fi DAI/USDC/USDT Convex Deposit",
            "releases": [],
            "symbol": "stkcvx3Crv",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3845badAde8e6dFF049820680d1F14bD3903a5d0",
            "name": "SAND",
            "releases": [SULU, ENCORE],
            "symbol": "SAND",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x35E3f7E558C04cE7eEE1629258EcbbA03B36Ec56",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x389Fc079a15354E9cbcE8258433CC0F85B755A42",
            "lp": "0x497CE58F34605B9944E6b15EcafE6b001206fd25",
            "name": "Curve.fi LUSDFRAXBP3CRV-f Gauge Deposit",
            "pool": "0x497CE58F34605B9944E6b15EcafE6b001206fd25",
            "releases": [SULU],
            "symbol": "LUSDFRAXBP3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x5f98805A4E8be255a32880FDeC7F6728C6568bA0",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 8,
            "id": "0x39AA39c021dfbaE8faC545936693aC917d5E7563",
            "name": "Compound USD Coin",
            "releases": [SULU, ENCORE],
            "symbol": "cUSDC",
            "type": "compound-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0x39C6b3e42d6A679d7D776778Fe880BC9487C2EDA",
            "name": "Aave KNC",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aKNC",
            "type": "aave-v2",
            "underlying": "0xdd974D5C2e2928deA5F71b9825b8b646686BD200",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x656c0544eF4C98A6a98491833A89204Abb045d6b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x39CAF13a104FF567f71fd2A4c68C026FDB6E740B",
            "name": "Curve Aave Pool yVault 0.3.5",
            "releases": [SULU, ENCORE],
            "symbol": "yvCurve-Aave",
            "type": "yearn-vault-v2",
            "underlying": "0xFd2a8fA60Abd58Efe3EeE34dd494cD491dC14900",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0x3a7404993393d9bA95E6ff8dFF92A70828a7Daeb",
            "name": "Enzyme Staked: Curve.fi GUSD/3Crv Convex Deposit",
            "releases": [],
            "symbol": "stkcvxgusd3CRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0x3B27F92C0e212C671EA351827EDF93DB27cc0c65",
            "name": "USDT yVault 0.4.3",
            "releases": [SULU],
            "symbol": "yvUSDT",
            "type": "yearn-vault-v2",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0x3C0FFFF15EA30C35d7A85B85c0782D6c94e1d238",
            "lp": "0xA3D87FffcE63B53E0d54fAa1cc983B7eB0b74A9c",
            "name": "Curve.fi ETH/sETH Gauge Deposit",
            "pool": "0xc5424B857f758E906013F3555Dad202e4bdB4567",
            "releases": [SULU],
            "symbol": "eCRV-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0x5e74C9036fb86BD7eCdcb084a0673EFc32eA31cb",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x3dA1313aE46132A397D90d95B1424A9A7e3e0fCE",
            "name": "Uniswap ETH/CRV Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xD533a949740bb3306d119CC777fa900bA034cd52",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x3e4E4bEbe4a8be22b7D82021AEFAcceC58cAc7D5",
            "name": "Enzyme Staked: Curve.fi hBTC/wBTC Convex Deposit",
            "releases": [],
            "symbol": "stkcvxhCRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0x3Ed3B47Dd13EC9a98b44e6204A523E766B225811",
            "name": "Aave USDT",
            "releases": [SULU, ENCORE],
            "symbol": "aUSDT",
            "type": "aave-v2",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3E7d1eAB13ad0104d2750B8863b489D65364e32D",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x23878914EFE38d27C4D67Ab83ed1b93A74D4086a",
            "name": "Aave Ethereum USDT",
            "releases": [SULU],
            "symbol": "aEthUSDT",
            "type": "aave-v3",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3E7d1eAB13ad0104d2750B8863b489D65364e32D",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x3F382DbD960E3a9bbCeaE22651E88158d2791550",
            "name": "Aavegotchi GHST Token",
            "releases": [],
            "symbol": "GHST",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3F7700027e0Bf1494B7dB2ad2B707638713de7AE",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: alUSDFRAXBP Convex Deposit",
            "releases": [],
            "symbol": "stkcvxalUSDFRAXB3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3fd4Cf9303c4BC9E13772618828712C8EaC7Dd2F",
            "name": "Uniswap BNT/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x1F573D6Fb3F13d689FF844B4cE37794d79a7FF1C",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3fE7940616e5Bc47b0775a0dccf6237893353bB4",
            "name": "IdleDAI v4 [Best yield]",
            "releases": [ENCORE, PHOENIX],
            "symbol": "idleDAIYield",
            "type": "idle",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x401c40CfE70BcDAf4678868c48bcBDC949978464",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: sUSDFRAXBP Convex Deposit",
            "releases": [],
            "symbol": "stkcvxSUSDFRAXBP3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x408e41876cCCDC0F92210600ef50372656052a38",
            "name": "Republic Token",
            "releases": [],
            "symbol": "REN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x40D16FC0246aD3160Ccc09B8D0D3A2cD28aE6C2f",
            "name": "Gho Token",
            "releases": [SULU],
            "symbol": "GHO",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3f12643D3f6f874d39C2a4c9f2Cd6f2DbAC877FC",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x419882f8f4A1A358Af4eF531fD13AA83FBd7F9C9",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: TrueUSD Convex Deposit",
            "releases": [],
            "symbol": "stkcvxTUSD3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x43AE24960e5534731Fc831386c07755A2dc33D47",
            "name": "Uniswap SNX/ETH Pool",
            "releases": [SULU],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC011a73ee8576Fb46F5E1c5751cA3B9Fe0af2a6F",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0x43b4FdFD4Ff969587185cDB6f0BD875c5Fc83f8c",
            "name": "Curve.fi Factory USD Metapool: Alchemix USD",
            "pool": "0x43b4FdFD4Ff969587185cDB6f0BD875c5Fc83f8c",
            "releases": [SULU],
            "staking": [
                {"token": "0x9582C4ADACB3BCE56Fea3e590F05c3ca2fb9C477", "type": "gauge"}
            ],
            "symbol": "alUSD3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xBC6DA0FE9aD5f3b0d58160288917AA56653660E9",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x448A0a42f55142971bb3ea45E64528D3e4114f9e",
            "name": "Uniswap ETH/stETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xDFe66B14D37C77F4E9b180cEb433d1b164f0281D",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4575f41308EC1483f3d399aa9a2826d74Da13Deb",
            "name": "Orchid",
            "releases": [],
            "symbol": "OXT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x462253b8F74B72304c145DB0e4Eebd326B22ca39",
            "lp": "0x02d341CcB60fAaf662bC0554d13778015d1b285C",
            "name": "Curve.fi saCRV Gauge Deposit",
            "pool": "0xEB16Ae0052ed37f479f7fe63849198Df1765a733",
            "releases": [SULU],
            "symbol": "saCRV-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x028171bCA77440897B824Ca71D1c56caC55b68A3",
                "0x6C5024Cd4F8A59110119C56f8933403A539555EB",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x4688a8b1F292FDaB17E9a90c8Bc379dC1DBd8713",
            "name": "Cover Protocol Governance Token",
            "releases": [],
            "symbol": "COVER",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x46a97629C9C1F58De6EC18C7F536e7E6d6A6ecDe",
            "name": "Synth iDOT",
            "releases": [],
            "symbol": "iDOT",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4807862AA8b2bF68830e4C8dc86D0e9A998e085a",
            "name": "Curve.fi Factory USD Metapool: Binance USD",
            "pool": "0x4807862AA8b2bF68830e4C8dc86D0e9A998e085a",
            "releases": [],
            "staking": [
                {"token": "0xd4B22fEdcA85E684919955061fDf353b9d38389b", "type": "gauge"}
            ],
            "symbol": "BUSD3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x491604c0FDF08347Dd1fa4Ee062a822A5DD06B5D",
            "name": "Cartesi Token",
            "releases": [],
            "symbol": "CTSI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x497CE58F34605B9944E6b15EcafE6b001206fd25",
            "name": "Curve.fi Factory USD Metapool: LUSDFRAXBP",
            "pool": "0x497CE58F34605B9944E6b15EcafE6b001206fd25",
            "releases": [SULU],
            "staking": [
                {"token": "0x389Fc079a15354E9cbcE8258433CC0F85B755A42", "type": "gauge"}
            ],
            "symbol": "LUSDFRAXBP3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x5f98805A4E8be255a32880FDeC7F6728C6568bA0",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x49849C98ae39Fff122806C06791Fa73784FB3675",
            "name": "Curve.fi renBTC/wBTC",
            "pool": "0x93054188d876f558f4a66B2EF1d97d16eDf0895B",
            "releases": [SULU],
            "staking": [],
            "symbol": "crvRenWBTC",
            "template": "base",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xEB4C2781e4ebA804CE9a9803C67d0893436bB27D",
                "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            },
        },
        {
            "decimals": 18,
            "id": "0x4AdF728E2Df4945082cDD6053869f51278fae196",
            "name": "Synth iXMR",
            "releases": [],
            "symbol": "iXMR",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x4B0181102A0112A2ef11AbEE5563bb4a3176c9d7",
            "name": "Compound Sushi Token",
            "releases": [SULU, ENCORE],
            "symbol": "cSUSHI",
            "type": "compound-v2",
            "underlying": "0x6B3595068778DD592e39A122f4f5a5cF09C90fE2",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 8,
            "id": "0x4C19596f5aAfF459fA38B0f7eD92F11AE6543784",
            "name": "TrueFi",
            "releases": [],
            "symbol": "TRU",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4d224452801ACEd8B2F0aebE155379bb5D594381",
            "name": "ApeCoin",
            "releases": [SULU],
            "symbol": "APE",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xc7de7f4d4C9c991fF62a07D18b3E31e349833A18",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x4da27a545c0c5B758a6BA100e3a049001de870f5",
            "name": "Staked Aave",
            "releases": [SULU],
            "symbol": "stkAAVE",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x6Df09E975c830ECae5bd4eD9d90f3A95a4f88012",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0x4Ddc2D193948926D02f9B1fE9e1daa0718270ED5",
            "name": "Compound Ether",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "cETH",
            "type": "compound-v2",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4E15361FD6b4BB609Fa63C81A2be19d873717870",
            "name": "Fantom Token",
            "releases": [ENCORE],
            "symbol": "FTM",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4e3FBD56CD56c3e72c1403e103b45Db9da5B9D2B",
            "name": "Convex Token",
            "releases": [SULU, ENCORE],
            "symbol": "CVX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xd962fC30A72A84cE50161031391756Bf2876Af5D",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x4e43151b78b5fbb16298C1161fcbF7531d5F8D93",
            "name": "Curve.fi Factory USD Metapool: GUSDFRAXBP",
            "pool": "0x4e43151b78b5fbb16298C1161fcbF7531d5F8D93",
            "releases": [SULU],
            "staking": [
                {"token": "0xda7F9DD286577cC338047B040c289463743a474e", "type": "gauge"}
            ],
            "symbol": "GUSDFRAXBP3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x056Fd409E1d7A124BD7017459dFEa2F387b6d5Cd",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x4f3E8F405CF5aFC05D68142F3783bDfE13811522",
            "name": "Curve.fi USDN/3Crv",
            "pool": "0x0f9cb53Ebe405d49A0bbdBD291A65Ff571bC83e1",
            "releases": [SULU],
            "staking": [],
            "symbol": "usdn3CRV",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x674C6Ad92Fd080e4004b2312b45f796a192D27a0",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x4F9254C83EB525f9FCf346490bbb3ed28a81C667",
            "name": "CelerToken",
            "releases": [ENCORE],
            "symbol": "CELR",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
            "name": "BUSD",
            "releases": [ENCORE, PHOENIX],
            "symbol": "BUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4fE83213D56308330EC302a8BD641f1d0113A4Cc",
            "name": "NuCypher",
            "releases": [],
            "symbol": "NU",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x50D1c9771902476076eCFc8B2A83Ad6b9355a4c9",
            "name": "FTX Token (FTT ",
            "releases": [],
            "symbol": "FTT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x514910771AF9Ca656af840dff83E8264EcF986CA",
            "name": "ChainLink Token",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "LINK",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xDC530D9457755926550b59e8ECcdaE7624181557",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x5165d24277cD063F5ac44Efd447B27025e888f37",
            "name": "Aave YFI",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aYFI",
            "type": "aave-v2",
            "underlying": "0x0bc529c00C6401aEF6D220BE8C6Ea1667F6Ad93e",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x7c5d4F8345e66f68099581Db340cd65B078C41f4",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x524847C615639e76fE7D0FE0B16be8c4eAC9CF3c",
            "name": "Uniswap BUSD/USDC Pool",
            "releases": [ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5274891bEC421B39D23760c04A6755eCB444797C",
            "name": "IdleUSDC v4 [Best yield]",
            "releases": [ENCORE],
            "symbol": "idleUSDCYield",
            "type": "idle",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5299d6F7472DCc137D7f3C4BcfBBB514BaBF341A",
            "name": "Synth sXMR",
            "releases": [],
            "symbol": "sXMR",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x56d811088235F11C8920698a204A5010a788f4b3",
            "name": "bZx Protocol Token",
            "releases": [],
            "symbol": "BZRX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
            "name": "Synth sUSD",
            "releases": [SULU, ENCORE],
            "symbol": "sUSD",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8e0b7e6062272B5eF4524250bFFF8e5Bd3497757",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x584bC13c7D411c00c01A62e8019472dE68768430",
            "name": "Hegic",
            "releases": [],
            "symbol": "HEGIC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x592244301CeA952d6daB2fdC1fE6bd9E53917306",
            "name": "Synth iYFI",
            "releases": [],
            "symbol": "iYFI",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5a6A4D54456819380173272A5E8E9B9904BdF41B",
            "name": "Curve.fi Factory USD Metapool: Magic Internet Money 3Pool",
            "pool": "0x5a6A4D54456819380173272A5E8E9B9904BdF41B",
            "releases": [SULU],
            "staking": [
                {"token": "0xd8b712d29381748dB89c36BCa0138d7c75866ddF", "type": "gauge"}
            ],
            "symbol": "MIM-3LP3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x99D8a9C45b2ecA8864373A26D1459e3Dff1e17F3",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x5A7E3c07604EB515C16b36cd51906a65f021F609",
            "name": "Synth sNFLX",
            "releases": [],
            "symbol": "sNFLX",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
            "name": "Lido DAO Token",
            "releases": [SULU, ENCORE],
            "symbol": "LDO",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x4e844125952D32AcdF339BE976c98E22F6F318dB",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x5B5CFE992AdAC0C9D48E05854B2d91C73a003858",
            "name": "Curve.fi HUSD/3Crv",
            "pool": "0x3eF6A01A0f81D6046290f3e2A8c5b843e738E604",
            "releases": [],
            "staking": [],
            "symbol": "husd3CRV",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xdF574c24545E5FfEcb9a659c229253D4111d87e1",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5c147e74D63B1D31AA3Fd78Eb229B65161983B2b",
            "name": "Wrapped Flow",
            "releases": [],
            "symbol": "WFLOW",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5C960a3DCC01BE8a0f49c02A8ceBCAcf5D07fABe",
            "name": "IdleRAI [Best yield]",
            "releases": [ENCORE],
            "symbol": "idleRAIYield",
            "type": "idle",
            "underlying": "0x03ab458634910AaD20eF5f1C8ee96F1D6ac54919",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x5d3a536E4D6DbD6114cc1Ead35777bAB948E3643",
            "name": "Compound Dai",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "cDAI",
            "type": "compound-v2",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5e74C9036fb86BD7eCdcb084a0673EFc32eA31cb",
            "name": "Synth sETH",
            "releases": [],
            "symbol": "sETH",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0x5f18C75AbDAe578b483E5F43f12a39cF75b973a9",
            "name": "USDC yVault 0.3.0",
            "releases": [ENCORE],
            "symbol": "yvUSDC",
            "type": "yearn-vault-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5f98805A4E8be255a32880FDeC7F6728C6568bA0",
            "name": "LUSD Stablecoin",
            "releases": [SULU],
            "symbol": "LUSD",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3D7aE7E594f2f2091Ad8798313450130d0Aba3a0",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x3Fe6a295459FAe07DF8A0ceCC36F37160FE86AA9",
            "name": "Aave Ethereum LUSD",
            "releases": [SULU],
            "symbol": "aEthLUSD",
            "type": "aave-v3",
            "underlying": "0x5f98805A4E8be255a32880FDeC7F6728C6568bA0",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3D7aE7E594f2f2091Ad8798313450130d0Aba3a0",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 9,
            "id": "0x607F4C5BB672230e8672085532f7e901544a7375",
            "name": "iEx.ec Network Token",
            "releases": [],
            "symbol": "RLC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x617aeCB6137B5108D1E7D4918e3725C8cEbdB848",
            "name": "Synth sBNB",
            "releases": [],
            "symbol": "sBNB",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6345728B1ccE16E6f8C509950b5c84FFF88530d9",
            "name": "Synth iCOMP",
            "releases": [],
            "symbol": "iCOMP",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x64875Aaa68d1d5521666C67d692Ee0B926b08b2F",
            "name": "CelsiusX Wrapped ADA",
            "releases": [],
            "symbol": "cxADA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 9,
            "id": "0x64aa3364F17a4D01c6f1751Fd97C2BD3D7e7f1D5",
            "name": "Olympus",
            "releases": [],
            "symbol": "OHM",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x671a912C10bba0CFA74Cfc2d6Fba9BA1ed9530B2",
            "name": "LINK yVault 0.4.2",
            "releases": [SULU, ENCORE],
            "symbol": "yvLINK",
            "type": "yearn-vault-v2",
            "underlying": "0x514910771AF9Ca656af840dff83E8264EcF986CA",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0x674C6Ad92Fd080e4004b2312b45f796a192D27a0",
            "name": "Neutrino USD",
            "releases": [],
            "symbol": "USDN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x67B66C99D3Eb37Fa76Aa3Ed1ff33E8e39F0b9c7A",
            "name": "Interest Bearing ETH",
            "releases": [],
            "symbol": "ibETH",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x683923dB55Fead99A79Fa01A27EeC3cB19679cC3",
            "name": "Aave FEI",
            "releases": [],
            "symbol": "aFEI",
            "type": "aave-v2",
            "underlying": "0x956F47F50A910163D8BF957Cf5846D573E7f87CA",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x69af81e73A73B40adF4f3d4223Cd9b1ECE623074",
            "name": "Mask Network",
            "releases": [],
            "symbol": "MASK",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6A22e5e94388464181578Aa7A6B869e00fE27846",
            "name": "Synth sXAG",
            "releases": [],
            "symbol": "sXAG",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "name": "Dai Stablecoin",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "DAI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xAed0c38402a5d19df6E4c03F4E2DceD6e29c1ee9",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x6B3595068778DD592e39A122f4f5a5cF09C90fE2",
            "name": "SushiToken",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "SUSHI",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xe572CeF69f43c2E488b33924AF04BDacE19079cf",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x6BA5b4e438FA0aAf7C1bD179285aF65d13bD3D90",
            "name": "RAI3CRV",
            "pool": "0x618788357D0EBd8A37e763ADab3bc575D54c2C7d",
            "releases": [],
            "staking": [],
            "symbol": "RAI3CRV",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x03ab458634910AaD20eF5f1C8ee96F1D6ac54919",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            "name": "Curve.fi DAI/USDC/USDT",
            "pool": "0xbEbc44782C7dB0a1A60Cb6fe97d0b483032FF1C7",
            "releases": [SULU],
            "staking": [],
            "symbol": "3Crv",
            "template": "base",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x6B175474E89094C44Da98b954EedeAC495271d0F",
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
                "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x6C5024Cd4F8A59110119C56f8933403A539555EB",
            "name": "Aave SUSD",
            "releases": [],
            "symbol": "aSUSD",
            "type": "aave-v2",
            "underlying": "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6C8b0Dee9E90EA9F790DA5DaF6f5B20D23B39689",
            "name": "Uniswap ORN/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x0258F474786DdFd37ABCE6df6BBb1Dd5dfC4434a",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x6C8c6b02E7b2BE14d4fA6022Dfd6d75921D90E4E",
            "name": "Compound Basic Attention Token",
            "releases": [],
            "symbol": "cBAT",
            "type": "compound-v2",
            "underlying": "0x0D8775F648430679A709E98d2b0Cb6250d2887EF",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6d16cF3EC5F763d4d99cB0B0b110eefD93B11B56",
            "name": "Synth sOIL",
            "releases": [],
            "symbol": "sOIL",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6d57a53A45343187905aaD6AD8eD532D105697c1",
            "name": "Uniswap RLC/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x607F4C5BB672230e8672085532f7e901544a7375",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6F634c6135D2EBD550000ac92F494F9CB8183dAe",
            "name": "Aave DPI",
            "releases": [SULU],
            "symbol": "aDPI",
            "type": "aave-v2",
            "underlying": "0x1494CA1F11D487c2bBe4543E90080AeBa4BA3C2b",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x029849bbc0b1d93b85a8b6190e979fd38F5760E2",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x6FCE4A401B6B80ACe52baAefE4421Bd188e76F6f",
            "name": "Aave MANA v1",
            "releases": [],
            "symbol": "aMANA",
            "type": "aave-v2",
            "underlying": "0x0F5D2fB29fb7d3CFeE444a200298f468908cC942",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x70e36f6BF80a52b3B46b3aF8e106CC0ed743E8e4",
            "name": "Compound Collateral",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "cCOMP",
            "type": "compound-v2",
            "underlying": "0xc00e94Cb662C3520282E6f5717214004A7f26888",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0x72E158d38dbd50A483501c24f792bDAAA3e7D55C",
            "lp": "0xd632f22692FaC7611d2AA1C0D552930D43CAEd3B",
            "name": "Curve.fi FRAX3CRV-f Gauge Deposit",
            "pool": "0xd632f22692FaC7611d2AA1C0D552930D43CAEd3B",
            "releases": [SULU],
            "symbol": "FRAX3CRV-f-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x853d955aCEf822Db058eb8505911ED77F175b99e",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "id": "0x73A15FeD60Bf67631dC6cd7Bc5B6e8da8190aCF5",
            "name": "Usual USD",
            "symbol": "USD0",
            "decimals": 18,
            "releases": [SULU],
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x7e891DEbD8FA0A4Cf6BE58Ddff5a8ca174FebDCB",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x740BA8aa0052E07b925908B380248cb03f3DE5cB",
            "lp": "0xB30dA2376F63De30b42dC055C93fa474F31330A5",
            "name": "Curve.fi alUSDFRAXB3CRV-f Gauge Deposit",
            "pool": "0xB30dA2376F63De30b42dC055C93fa474F31330A5",
            "releases": [SULU],
            "symbol": "alUSDFRAXB3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xBC6DA0FE9aD5f3b0d58160288917AA56653660E9",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x7537AAe01f3B218DAE75e10d952473823F961B87",
            "name": "Synth sAAPL",
            "releases": [],
            "symbol": "sAAPL",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x757de3ac6B830a931eF178C6634c5C551773155c",
            "name": "Synth sNIKKEI",
            "releases": [],
            "symbol": "sNIKKEI",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x789A0F48Ef21AD1A255E06bae15cf11692d4E47E",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: BUSDFRAXBP Convex Deposit",
            "releases": [],
            "symbol": "stkcvxBUSDFRAXBP3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x79da1431150C9b82D2E5dfc1C68B33216846851e",
            "name": "Synth iLTC",
            "releases": [],
            "symbol": "iLTC",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x79dEC9a963dCCFbE2d4B85bBeC534e6C3C7b695D",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: TUSDFRAXBP Convex Deposit",
            "releases": [],
            "symbol": "stkcvxTUSDFRAXBP3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x7D1AfA7B718fb893dB30A3aBc0Cfc608AaCfeBB0",
            "name": "Matic Token",
            "releases": [SULU, ENCORE],
            "symbol": "MATIC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x7bAC85A8a13A4BcD8abb3eB7d6b4d632c5a57676",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x7Da96a3891Add058AdA2E826306D812C638D87a7",
            "name": "USDT yVault 0.3.5",
            "releases": [ENCORE],
            "symbol": "yvUSDT",
            "type": "yearn-vault-v2",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x7f04C6130F7226B502De00bB597f12F8E7Eaa520",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: GUSDFRAXBP Convex Deposit",
            "releases": [],
            "symbol": "stkcvxGUSDFRAXBP3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
            "name": "Wrapped liquid staked Ether 2.0",
            "releases": [SULU],
            "symbol": "wstETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK_LIKE_WSTETH",
                "aggregator": "0x92829C41115311cA43D5c9f722f0E9e7b9fcd30a",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x0B925eD163218f6662a35e0f0371Ac234f9E9371",
            "name": "Aave Ethereum wstETH",
            "releases": [SULU],
            "symbol": "aEthwstETH",
            "type": "aave-v3",
            "underlying": "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
            "price_feed": {
                "type": "DERIVATIVE_PEGGED_DERIVATIVES",
                "address": "0x86533352BDd201c89f184f7ebbFeBea3E31c8Bb3",
            },
        },
        {
            "decimals": 18,
            "id": "0x7Fc66500c84A76Ad7e9c93437bFc5Ac33E2DDaE9",
            "name": "Aave Token",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "AAVE",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x6Df09E975c830ECae5bd4eD9d90f3A95a4f88012",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0x80a2AE356fc9ef4305676f7a3E2Ed04e12C33946",
            "name": "Compound yearn.finance",
            "releases": [SULU, ENCORE],
            "symbol": "cYFI",
            "type": "compound-v2",
            "underlying": "0x0bc529c00C6401aEF6D220BE8C6Ea1667F6Ad93e",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8175362afBeeE32AfB22d05adc0bbD08dE32F5Ae",
            "name": "Uniswap ETH/DMG Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xEd91879919B71bB6905f23af0A68d231EcF87b14",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8207c1FfC5B6804F6024322CcF34F29c3541Ae26",
            "name": "OriginToken",
            "releases": [],
            "symbol": "OGN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x20157DBAbb84e3BBFE68C349d0d44E48AE7B5AD2",
            "name": "iBTC",
            "releases": [SULU],
            "symbol": "IBTC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xdeb288F737066589598e9214E782fa5A8eD689e8",
                "rate_asset": RateAsset.ETH,
                "pegged_to": "BTC",
                "non_standard": True,
            },
        },
        {
            "decimals": 18,
            "id": "0x845838DF265Dcd2c412A1Dc9e959c7d08537f8a2",
            "name": "Curve.fi cDAI/cUSDC",
            "pool": "0xA2B47E3D5c44877cca798226B7B8118F9BFb7A56",
            "releases": [SULU],
            "staking": [],
            "symbol": "cDAI+cUSDC",
            "template": "yearn",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x5d3a536E4D6DbD6114cc1Ead35777bAB948E3643",
                "0x39AA39c021dfbaE8faC545936693aC917d5E7563",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x848a5564158d84b8A8fb68ab5D004Fae11619A54",
            "name": "Balancer weETH/ezETH/rswETH",
            "releases": [SULU],
            "symbol": "weETH/ezETH/rswETH",
            "staking": [
                {"token": "0x253ED65fff980AEE7E94a0dC57BE304426048b35", "type": "gauge"}
            ],
            "pool_id": "0x848a5564158d84b8a8fb68ab5d004fae11619a5400000000000000000000066a",
            "pool_factory": "0xDB8d758BCb971e482B2C45f7F8a7740283A1bd3A",
            "pool_type": "composable-stable-v5",
            "underlyings": [
                "0x848a5564158d84b8A8fb68ab5D004Fae11619A54",
                "0xbf5495Efe5DB9ce00f80364C8B423567e58d2110",
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
                "0xFAe103DC9cf190eD75350761e95403b7b8aFa6c0",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_STABLE_POOL",
                "address": "0x438254D66e2bC576819A76A0ecB11FE41195D39F",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x84cA8bc7997272c7CfB4D0Cd3D55cd942B3c9419",
            "name": "DIAToken",
            "releases": [],
            "symbol": "DIA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x84e99CCC19da8290A754cb015cA188676d695f0A",
            "name": "Uniswap COVER/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x4688a8b1F292FDaB17E9a90c8Bc379dC1DBd8713",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x853d955aCEf822Db058eb8505911ED77F175b99e",
            "name": "Frax",
            "releases": [SULU],
            "symbol": "FRAX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xB9E1E3A9feFf48998E45Fa90847ed4D467E8BcfD",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x873fB544277FD7b977B196a826459a69E27eA4ea",
            "name": "RAI yVault 0.4.2",
            "releases": [ENCORE],
            "symbol": "yvRAI",
            "type": "yearn-vault-v2",
            "underlying": "0x03ab458634910AaD20eF5f1C8ee96F1D6ac54919",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x875773784Af8135eA0ef43b5a374AaD105c5D39e",
            "name": "Idle",
            "releases": [],
            "symbol": "IDLE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8878Df9E1A7c87dcBf6d3999D997f262C05D8C70",
            "name": "Uniswap LRC/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xBBbbCA6A901c926F240b89EacB641d8Aec7AEafD",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x88C8Cf3A212c0369698D13FE98Fcb76620389841",
            "name": "Synth sEOS",
            "releases": [],
            "symbol": "sEOS",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x88D97d199b9ED37C29D846d00D443De980832a22",
            "name": "Uniswap UMA/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x04Fa0d235C4abf4BcF4787aF4CF447DE572eF828",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x89597C252De07E986A285Dee2b4D24d254d90617",
            "name": "Enzyme Staked: Curve.fi HUSD/3Crv Convex Deposit",
            "releases": [],
            "symbol": "stkcvxhusd3CRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8979A3Ef9D540480342AC0F56e9D4c88807b1CBa",
            "name": "Uniswap REPv2/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x221657776846890989a759BA2973e427DfF5C9bB",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8A8079c7149B8A1611e5C5d978DCA3bE16545F83",
            "name": "Synth iADA",
            "releases": [],
            "symbol": "iADA",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8B189a4Ba919eF4C6299c88bF71CA8DfE36B1A40",
            "name": "Enzyme Staked: Curve.fi aDAI/aSUSD Convex Deposit",
            "releases": [],
            "symbol": "stkcvxsaCRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8Bd1661Da98EBDd3BD080F0bE4e6d9bE8cE9858c",
            "name": "Uniswap REN/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x408e41876cCCDC0F92210600ef50372656052a38",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8C81121B15197fA0eEaEE1DC75533419DcfD3151",
            "name": "IdleWBTC v4 [Best yield]",
            "releases": [ENCORE],
            "symbol": "idleWBTCYield",
            "type": "idle",
            "underlying": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8c9532a60E0E7C6BbD2B2c1303F63aCE1c3E9811",
            "name": "Renzo Restaked LST ",  # Trailing space is correct (on-chain
            "releases": [SULU],
            "symbol": "pzETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0x62967DC5140fBA7204CEF0d4b55B38D9109a7Fcb",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x8CE9137d39326AD0cD6491fb5CC0CbA0e089b6A9",
            "name": "Swipe",
            "releases": [ENCORE, PHOENIX],
            "symbol": "SXP",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8dAE6Cb04688C62d939ed9B68d32Bc62e49970b1",
            "name": "Aave CRV",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aCRV",
            "type": "aave-v2",
            "underlying": "0xD533a949740bb3306d119CC777fa900bA034cd52",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8a12Be339B0cD1829b91Adc01977caa5E9ac121e",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x7B95Ec873268a6BFC6427e7a28e396Db9D0ebc65",
            "name": "Aave Ethereum CRV",
            "releases": [SULU],
            "symbol": "aEthCRV",
            "type": "aave-v3",
            "underlying": "0xD533a949740bb3306d119CC777fa900bA034cd52",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8a12Be339B0cD1829b91Adc01977caa5E9ac121e",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x8deef89058090ac5655A99EEB451a4f9183D1678",
            "name": "Synth iXTZ",
            "releases": [],
            "symbol": "iXTZ",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8E870D67F660D95d5be530380D0eC0bd388289E1",
            "name": "Pax Dollar",
            "releases": [SULU],
            "symbol": "USDP",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x09023c0DA49Aaf8fc3fA3ADF34C6A7016D38D5e3",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x8fdb0bB9365a46B145Db80D0B1C5C5e979C84190",
            "name": "Curve.fi Factory USD Metapool: BUSDFRAXBP",
            "pool": "0x8fdb0bB9365a46B145Db80D0B1C5C5e979C84190",
            "releases": [],
            "staking": [
                {"token": "0xAeac6Dcd12CC0BE74c8f99EfE4bB5205a1f9A608", "type": "gauge"}
            ],
            "symbol": "BUSDFRAXBP3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x8FfC3C4403E427faaa69b211A55F34234dcF71F7",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: Binance USD Convex Deposit",
            "releases": [],
            "symbol": "stkcvxBUSD3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x90704Ac59E7E54632b0CC9d22573aeCD7eB094ad",
            "name": "Uniswap CRO/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xA0b73E1Ff0B80914AB6fe0444E65848C4C34450b",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x90Bb609649E0451E5aD952683D64BD2d1f245840",
            "lp": "0x194eBd173F6cDacE046C53eACcE9B953F28411d1",
            "name": "Curve.fi eursCRV Gauge Deposit",
            "pool": "0x0Ce6a5fF5217e38315f87032CF90686C96627CAA",
            "releases": [],
            "symbol": "eursCRV-gauge",
            "template": "base",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xdB25f211AB05b1c97D595516F45794528a807ad8",
                "0xD71eCFF9342A5Ced620049e616c5035F1dB98620",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x918dA91Ccbc32B7a6A0cc4eCd5987bbab6E31e6D",
            "name": "Synth sTSLA",
            "releases": [],
            "symbol": "sTSLA",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x956F47F50A910163D8BF957Cf5846D573E7f87CA",
            "name": "Fei USD",
            "releases": [],
            "symbol": "FEI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x9582C4ADACB3BCE56Fea3e590F05c3ca2fb9C477",
            "lp": "0x43b4FdFD4Ff969587185cDB6f0BD875c5Fc83f8c",
            "name": "Curve.fi alUSD3CRV-f Gauge Deposit",
            "pool": "0x43b4FdFD4Ff969587185cDB6f0BD875c5Fc83f8c",
            "releases": [SULU],
            "symbol": "alUSD3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xBC6DA0FE9aD5f3b0d58160288917AA56653660E9",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x95aD61b0a150d79219dCF64E1E6Cc01f0B64C4cE",
            "name": "SHIBA INU",
            "releases": [SULU],
            "symbol": "SHIB",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8dD1CD88F43aF196ae478e91b9F5E4Ac69A97C61",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0x95b4eF2869eBD94BEb4eEE400a99824BF5DC325b",
            "name": "Compound Maker",
            "releases": [SULU, ENCORE],
            "symbol": "cMKR",
            "type": "compound-v2",
            "underlying": "0x9f8F72aA9304c8B593d555F12eF6589cC3A579A2",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0x97E2768e8E73511cA874545DC5Ff8067eB19B787",
            "name": "Curve.fi USDK/3Crv",
            "pool": "0x3E01dD8a5E1fb3481F0F589056b428Fc308AF0Fb",
            "releases": [SULU],
            "staking": [],
            "symbol": "usdk3CRV",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x1c48f86ae57291F7686349F12601910BD8D470bb",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x97F097BBdb84e83B22ddFe78ccD2ae31Fc03ef18",
            "name": "Enzyme Staked: Curve.fi renBTC/wBTC Convex Deposit",
            "releases": [],
            "symbol": "stkcvxcrvRenWBTC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x97fe22E7341a0Cd8Db6F6C021A24Dc8f4DAD855F",
            "name": "Synth sGBP",
            "releases": [],
            "symbol": "sGBP",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x986b4AFF588a109c09B50A03f42E4110E29D353F",
            "name": "Curve sETH Pool yVault 0.3.2",
            "releases": [SULU],
            "symbol": "yvCurve-sETH",
            "type": "yearn-vault-v2",
            "underlying": "0xA3D87FffcE63B53E0d54fAa1cc983B7eB0b74A9c",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0x992058B7DB08F9734d84485bfbC243C4ee6954A7",
            "name": "Synth sYFI",
            "releases": [],
            "symbol": "sYFI",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x99D8a9C45b2ecA8864373A26D1459e3Dff1e17F3",
            "name": "Magic Internet Money",
            "releases": [SULU, ENCORE],
            "symbol": "MIM",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x7A364e8770418566e3eb2001A96116E6138Eb32F",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x9B533F1cEaa5ceb7e5b8994ef16499E47A66312D",
            "name": "Uniswap OXT/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x4575f41308EC1483f3d399aa9a2826d74Da13Deb",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x9Ba021B0a9b958B5E75cE9f6dff97C7eE52cb3E6",
            "name": "Autocompounding Pirex Ether",
            "releases": [SULU],
            "symbol": "apxETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0xc11a2312987F6aDb5D1ABfa89D488e8b806B699e",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x9B8519A9a00100720CCdC8a120fBeD319cA47a14",
            "lp": "0xEd279fDD11cA84bEef15AF5D39BB4d4bEE23F0cA",
            "name": "Curve.fi LUSD3CRV-f Gauge Deposit",
            "pool": "0xEd279fDD11cA84bEef15AF5D39BB4d4bEE23F0cA",
            "releases": [SULU],
            "symbol": "LUSD3CRV-f-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x5f98805A4E8be255a32880FDeC7F6728C6568bA0",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0x9CF7E61853ea30A41b02169391b393B901eac457",
            "name": "Synth sAMZN",
            "releases": [],
            "symbol": "sAMZN",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x9dEF9511fEc79f83AFCBFfe4776B1D817DC775aE",
            "name": "Uniswap ANT/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xa117000000f279D81A1D3cc75430fAA017FA5A2e",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x9D39A5DE30e57443BfF2A8307A4256c8797A3497",
            "name": "Staked USDe",
            "releases": [SULU],
            "symbol": "sUSDe",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_REDSTONE",
                "aggregator": "0xb99D174ED06c83588Af997c8859F93E83dD4733f",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xE24933aA6dFb66A32Df7eA897A1818ECAaBD54E1",
            "name": "ZeroLend Staked USDe",
            "releases": [SULU],
            "symbol": "z0sUSDe",
            "type": "zero-lend-rwa-stablecoins-aave-v3",
            "underlying": "0x9D39A5DE30e57443BfF2A8307A4256c8797A3497",
            "price_feed": {
                "type": "PRIMITIVE_REDSTONE",
                "aggregator": "0xb99D174ED06c83588Af997c8859F93E83dD4733f",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x9f8F72aA9304c8B593d555F12eF6589cC3A579A2",
            "name": "Maker",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "MKR",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x24551a8Fb2A7211A25a17B1481f043A8a8adC7f2",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x8A458A9dc9048e005d22849F470891b840296619",
            "name": "Aave Ethereum MKR",
            "releases": [SULU],
            "symbol": "aEthMKR",
            "type": "aave-v3",
            "underlying": "0x9f8F72aA9304c8B593d555F12eF6589cC3A579A2",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x24551a8Fb2A7211A25a17B1481f043A8a8adC7f2",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x9fC689CCaDa600B6DF723D9E47D84d76664a1F23",
            "name": "Curve.fi cDAI/cUSDC/USDT",
            "pool": "0x52EA46506B9CC5Ef470C5bf89f17Dc28bB35D85C",
            "releases": [SULU],
            "staking": [],
            "symbol": "cDAI+cUSDC+USDT",
            "template": "yearn",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x5d3a536E4D6DbD6114cc1Ead35777bAB948E3643",
                "0x39AA39c021dfbaE8faC545936693aC917d5E7563",
                "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 8,
            "id": "0x9ff58f4fFB29fA2266Ab25e75e2A8b3503311656",
            "name": "Aave WBTC",
            "releases": [SULU, ENCORE],
            "symbol": "aWBTC",
            "type": "aave-v2",
            "underlying": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xdeb288F737066589598e9214E782fa5A8eD689e8",  # TODO: update when Price Feed utils available, so we can create WBTC/USD, and WBTC/ETH price feeds
                "rate_asset": RateAsset.ETH,
                "pegged_to": "BTC",
            },
        },
        {
            "decimals": 8,
            "id": "0x5Ee5bf7ae06D1Be5997A1A72006FE6C607eC6DE8",
            "name": "Aave Ethereum WBTC",
            "releases": [SULU],
            "symbol": "aEthWBTC",
            "type": "aave-v3",
            "underlying": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xdeb288F737066589598e9214E782fa5A8eD689e8",  # TODO: update when Price Feed utils available, so we can create WBTC/USD, and WBTC/ETH price feeds
                "rate_asset": RateAsset.ETH,
                "pegged_to": "BTC",
            },
        },
        {
            "decimals": 18,
            "id": "0xa06bC25B5805d5F8d82847D191Cb4Af5A3e873E0",
            "name": "Aave LINK",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aLINK",
            "type": "aave-v2",
            "underlying": "0x514910771AF9Ca656af840dff83E8264EcF986CA",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xDC530D9457755926550b59e8ECcdaE7624181557",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x5E8C8A7243651DB1384C0dDfDbE39761E8e7E51a",
            "name": "Aave Ethereum LINK",
            "releases": [SULU],
            "symbol": "aEthLINK",
            "type": "aave-v3",
            "underlying": "0x514910771AF9Ca656af840dff83E8264EcF986CA",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xDC530D9457755926550b59e8ECcdaE7624181557",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xa0ABda1F980e03D7eADb78aed8fC1f2DD0fe83Dd",
            "name": "Uniswap BUSD/USDT Pool",
            "releases": [ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
                "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0xA0b73E1Ff0B80914AB6fe0444E65848C4C34450b",
            "name": "CRO",
            "releases": [],
            "symbol": "CRO",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "name": "USD Coin",
            "releases": [SULU, ENCORE],
            "symbol": "USDC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8fFfFfd4AfB6115b954Bd326cbe7B4BA576818f6",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xa117000000f279D81A1D3cc75430fAA017FA5A2e",
            "name": "Aragon Network Token",
            "releases": [],
            "symbol": "ANT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA1290d69c65A6Fe4DF752f95823fae25cB99e5A7",
            "name": "rsETH",
            "releases": [SULU],
            "symbol": "rsETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0xF387707bC4DF894607a93F83D58A835CAcD370f1",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xa14eA0E11121e6E951E87c66AFe460A00BCD6A16",
            "name": "IdleDAI v4 [Risk adjusted]",
            "releases": [ENCORE, PHOENIX],
            "symbol": "idleDAISafe",
            "type": "idle",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xa1faa113cbE53436Df28FF0aEe54275c13B40975",
            "name": "AlphaToken",
            "releases": [],
            "symbol": "ALPHA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xa2107FA5B38d9bbd2C461D6EDf11B11A50F6b974",
            "name": "Uniswap LINK/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x514910771AF9Ca656af840dff83E8264EcF986CA",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xa258C4606Ca8206D8aA700cE2143D7db854D168c",
            "name": "WETH yVault 0.4.2",
            "releases": [SULU, ENCORE],
            "symbol": "yvWETH",
            "type": "yearn-vault-v2",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0xa2B0fDe6D710e201d0d608e924A484d1A5fEd57c",
            "name": "Synth sXRP",
            "releases": [],
            "symbol": "sXRP",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA35b1B31Ce002FBF2058D22F30f95D405200A15b",
            "name": "ETHx",
            "releases": [SULU],
            "symbol": "ETHx",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK_LIKE_ETHX",
                "aggregator": "0x75c4Dc3201015C78a60dBe673FC7247549527C1b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 6,
            "id": "0xa354F35829Ae975e850e23e9615b11Da1B3dC4DE",
            "name": "USDC yVault 0.4.3",
            "releases": [SULU, ENCORE],
            "symbol": "yvUSDC",
            "type": "yearn-vault-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0xA361718326c15715591c299427c62086F69923D9",
            "name": "Aave BUSD",
            "releases": [ENCORE, PHOENIX],
            "symbol": "aBUSD",
            "type": "aave-v2",
            "underlying": "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA3D87FffcE63B53E0d54fAa1cc983B7eB0b74A9c",
            "name": "Curve.fi ETH/sETH",
            "pool": "0xc5424B857f758E906013F3555Dad202e4bdB4567",
            "releases": [SULU],
            "staking": [
                {"token": "0x3C0FFFF15EA30C35d7A85B85c0782D6c94e1d238", "type": "gauge"}
            ],
            "symbol": "eCRV",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0x5e74C9036fb86BD7eCdcb084a0673EFc32eA31cb",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0xA478c2975Ab1Ea89e8196811F51A7B7Ade33eB11",
            "name": "Uniswap DAI/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x6B175474E89094C44Da98b954EedeAC495271d0F",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xa47c8bf37f92aBed4A126BDA807A7b7498661acD",
            "name": "Wrapped UST Token",
            "releases": [],
            "symbol": "UST",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA5a5DF41883Cdc00c4cCC6E8097130535399d9a3",
            "name": "Synth iOIL",
            "releases": [],
            "symbol": "iOIL",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xa5cA62D95D24A4a350983D5B8ac4EB8638887396",
            "name": "sUSD yVault 0.3.3",
            "releases": [],
            "symbol": "yvsUSD",
            "type": "yearn-vault-v2",
            "underlying": "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xa685a61171bb30d4072B338c80Cb7b2c865c873E",
            "name": "Aave MANA v2",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aMANA",
            "type": "aave-v2",
            "underlying": "0x0F5D2fB29fb7d3CFeE444a200298f468908cC942",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x82A44D92D6c329826dc557c5E1Be6ebeC5D5FeB9",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0xA696a63cc78DfFa1a63E9E50587C197387FF6C7E",
            "name": "WBTC yVault 0.3.5",
            "releases": [SULU, ENCORE],
            "symbol": "yvWBTC",
            "type": "yearn-vault-v2",
            "underlying": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0xA70d458A4d9Bc0e6571565faee18a48dA5c0D593",
            "name": "Uniswap BAL/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xba100000625a3754423978a60c9317c58a424e3D",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xA9859874e1743A32409f75bB11549892138BBA1E",
            "name": "Synth iETH",
            "releases": [],
            "symbol": "iETH",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 4,
            "id": "0xaaAEBE6Fe48E54f431b0C390CfaF0b017d09D42d",
            "name": "Celsius",
            "releases": [],
            "symbol": "CEL",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xaC317d14738A454Ff20B191ba3504aA97173045b",
            "name": "Uniswap SXP/ETH Pool",
            "releases": [ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x8CE9137d39326AD0cD6491fb5CC0CbA0e089b6A9",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xaC6Df26a590F08dcC95D5a4705ae8abbc88509Ef",
            "name": "Aave ENJ",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aENJ",
            "type": "aave-v2",
            "underlying": "0xF629cBd94d3791C9250152BD8dfBDF380E2a3B9c",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x24D9aB51950F3d62E9144fdC2f3135DAA6Ce8D1B",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xADE00C28244d5CE17D72E40330B1c318cD12B7c3",
            "name": "AdEx Network",
            "releases": [],
            "symbol": "ADX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xAE461cA67B15dc8dc81CE7615e0320dA1A9aB8D5",
            "name": "Uniswap DAI/USDC Pool",
            "releases": [SULU, ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x6B175474E89094C44Da98b954EedeAC495271d0F",
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xae7ab96520DE3A18E5e111B5EaAb095312D7fE84",
            "name": "Liquid staked Ether 2.0",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "stETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x86392dC19c0b719886221c78AB11eb8Cf5c52812",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xae78736Cd615f374D3085123A210448E74Fc6393",
            "name": "Rocket Pool ETH",
            "releases": [SULU],
            "symbol": "rETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x536218f9E9Eb48863970252233c8F271f554C2d0",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xD33526068D116cE69F19A9ee46F0bd304F21A51f",
            "name": "Rocket Pool Protocol",
            "releases": [],
            "symbol": "RPL",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xCc9EE9483f662091a1de4795249E24aC0aC2630f",
            "name": "Aave Ethereum rETH",
            "releases": [SULU],
            "symbol": "aEthrETH",
            "type": "aave-v3",
            "underlying": "0xae78736Cd615f374D3085123A210448E74Fc6393",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x536218f9E9Eb48863970252233c8F271f554C2d0",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xAeac6Dcd12CC0BE74c8f99EfE4bB5205a1f9A608",
            "lp": "0x8fdb0bB9365a46B145Db80D0B1C5C5e979C84190",
            "name": "Curve.fi BUSDFRAXBP3CRV-f Gauge Deposit",
            "pool": "0x8fdb0bB9365a46B145Db80D0B1C5C5e979C84190",
            "releases": [],
            "symbol": "BUSDFRAXBP3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xAf5271F4c8055da8bD15ab4CcA3bB6E844EAC93C",
            "name": "Enzyme Staked: Curve.fi DAI/USDC/USDT/sUSD Convex Deposit",
            "releases": [],
            "symbol": "stkcvxcrvPlain3andSUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xaf596492e1E69093c39DF6ba442FCE4784D05Fd6",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: Alchemix USD Convex Deposit",
            "releases": [],
            "symbol": "stkcvxalUSD3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xAFD870F32CE54EfdBF677466B612bf8ad164454B",
            "name": "Synth iBNB",
            "releases": [],
            "symbol": "iBNB",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xb19059ebb43466C323583928285a49f558E572Fd",
            "name": "Curve.fi hBTC/wBTC",
            "pool": "0x4CA9b3063Ec5866A4B82E437059D2C43d1be596F",
            "releases": [SULU],
            "staking": [],
            "symbol": "hCRV",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x0316EB71485b0Ab14103307bf65a021042c6d380",
                "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            },
        },
        {
            "decimals": 18,
            "id": "0xB20bd5D04BE54f870D5C0d3cA85d82b34B836405",
            "name": "Uniswap DAI/USDT Pool",
            "releases": [SULU, ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x6B175474E89094C44Da98b954EedeAC495271d0F",
                "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xb2d5CB72A621493fe83C6885E4A776279be595bC",
            "name": "IdleFEI [Best yield]",
            "releases": [],
            "symbol": "idleFEIYield",
            "type": "idle",
            "underlying": "0x956F47F50A910163D8BF957Cf5846D573E7f87CA",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB30dA2376F63De30b42dC055C93fa474F31330A5",
            "name": "Curve.fi Factory USD Metapool: alUSDFRAXBP",
            "pool": "0xB30dA2376F63De30b42dC055C93fa474F31330A5",
            "releases": [SULU],
            "staking": [
                {"token": "0x740BA8aa0052E07b925908B380248cb03f3DE5cB", "type": "gauge"}
            ],
            "symbol": "alUSDFRAXB3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xBC6DA0FE9aD5f3b0d58160288917AA56653660E9",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 8,
            "id": "0xB3319f5D18Bc0D84dD1b4825Dcde5d5f7266d407",
            "name": "Compound 0x",
            "releases": [],
            "symbol": "cZRX",
            "type": "compound-v2",
            "underlying": "0xE41d2489571d322189246DaFA5ebDe1F4699F498",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xb4d0d9df2738abE81b87b66c80851292492D1404",
            "name": "Uniswap TUSD/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x0000000000085d4780B73119b644AE5ecd22b376",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB4e16d0168e52d35CaCD2c6185b44281Ec28C9Dc",
            "name": "Uniswap USDC/ETH Pool",
            "releases": [SULU, ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xB50721BCf8d664c30412Cfbc6cf7a15145234ad1",
            "name": "Arbitrum",
            "releases": [SULU],
            "symbol": "ARB",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x31697852a68433DbCc2Ff612c516d69E3D9bd08F",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xB6909B960DbbE7392D405429eB2b3649752b4838",
            "name": "Uniswap BAT/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x0D8775F648430679A709E98d2b0Cb6250d2887EF",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xb753428af26E81097e7fD17f40c88aaA3E04902c",
            "name": "Spice",
            "releases": [],
            "symbol": "SFI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB77CeD093f32e47ff5BeF2cA295585B5a1f5B6Cf",
            "name": "Enzyme Staked: Curve.fi USDK/3Crv Convex Deposit",
            "releases": [],
            "symbol": "stkcvxusdk3CRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB784CED6994c928170B417BBd052A096c6fB17E2",
            "name": "Uniswap NMR/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x1776e1F26f98b1A5dF9cD347953a26dd3Cb46671",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB8C3B7A2A618C552C23B1E4701109a9E756Bab67",
            "name": "1INCH yVault 0.3.2",
            "releases": [SULU, ENCORE],
            "symbol": "yv1INCH",
            "type": "yearn-vault-v2",
            "underlying": "0x111111111117dC0aa78b770fA6A738034120C302",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0xB8c77482e45F1F44dE1745F52C74426C631bDD52",
            "name": "BNB",
            "releases": [],
            "symbol": "BNB",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB9b752F7f4a4680eEb327ffe728f46666763A796",
            "name": "Uniswap BZRX/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x56d811088235F11C8920698a204A5010a788f4b3",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB9D7CB55f463405CDfBe4E90a6D2Df01C2B92BF1",
            "name": "Aave UNI",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aUNI",
            "type": "aave-v2",
            "underlying": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xD6aA3D25116d8dA79Ea0246c4826EB951872e02e",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xF6D2224916DDFbbab6e6bd0D1B7034f4Ae0CaB18",
            "name": "Aave Ethereum UNI",
            "releases": [SULU],
            "symbol": "aEthUNI",
            "type": "aave-v3",
            "underlying": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xD6aA3D25116d8dA79Ea0246c4826EB951872e02e",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xf1C9acDc66974dFB6dEcB12aA385b9cD01190E38",
            "name": "Staked ETH",
            "releases": [SULU],
            "symbol": "osETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0xCBfB161Cb44267390c7B9303E1B08Af75FFabd71",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xba100000625a3754423978a60c9317c58a424e3D",
            "name": "Balancer",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "BAL",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xC1438AA3823A6Ba0C159CfA8D98dF5A994bA120b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xBA11D00c5f74255f56a5E366F4F77f5A186d7f55",
            "name": "BandToken",
            "releases": [],
            "symbol": "BAND",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xBB0E17EF65F82Ab018d8EDd776e8DD940327B28b",
            "name": "Axie Infinity Shard",
            "releases": [],
            "symbol": "AXS",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xBb2b8038a1640196FbE3e38816F3e67Cba72D940",
            "name": "Uniswap WBTC/ETH Pool",
            "releases": [SULU, ENCORE],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xBBbbCA6A901c926F240b89EacB641d8Aec7AEafD",
            "name": "LoopringCoin V2",
            "releases": [],
            "symbol": "LRC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xbBC455cb4F1B9e4bFC4B73970d360c8f032EfEE6",
            "name": "Synth sLINK",
            "releases": [],
            "symbol": "sLINK",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xbC396689893D065F41bc2C6EcbeE5e0085233447",
            "name": "Perpetual",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "PERP",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3b41D5571468904D4e53b6a8d93A6BaC43f02dC9",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xBC6DA0FE9aD5f3b0d58160288917AA56653660E9",
            "name": "Alchemix USD",
            "releases": [],
            "symbol": "alUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0xBcca60bB61934080951369a648Fb03DF4F96263C",
            "name": "Aave USDC",
            "releases": [SULU, ENCORE],
            "symbol": "aUSDC",
            "type": "aave-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8fFfFfd4AfB6115b954Bd326cbe7B4BA576818f6",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 6,
            "id": "0x98C23E9d8f34FEFb1B7BD6a91B7FF122F4e16F5c",
            "name": "Aave Ethereum USDC",
            "releases": [SULU],
            "symbol": "aEthUSDC",
            "type": "aave-v3",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8fFfFfd4AfB6115b954Bd326cbe7B4BA576818f6",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xBe9895146f7AF43049ca1c1AE358B0541Ea49704",
            "name": "Coinbase Wrapped Staked ETH",
            "releases": [SULU],
            "symbol": "cbETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xF017fcB346A1885194689bA23Eff2fE6fA5C483b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x977b6fc5dE62598B08C85AC8Cf2b745874E8b78c",
            "name": "Aave Ethereum cbETH",
            "releases": [SULU],
            "symbol": "aEthcbETH",
            "type": "aave-v3",
            "underlying": "0xBe9895146f7AF43049ca1c1AE358B0541Ea49704",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xF017fcB346A1885194689bA23Eff2fE6fA5C483b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xc00e94Cb662C3520282E6f5717214004A7f26888",
            "name": "Compound",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "COMP",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x1B39Ee86Ec5979ba5C322b826B3ECb8C79991699",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xC011a73ee8576Fb46F5E1c5751cA3B9Fe0af2a6F",
            "name": "Synthetix Network Token",
            "releases": [SULU, ENCORE],
            "symbol": "SNX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x79291A9d692Df95334B1a0B3B4AE6bC606782f8c",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xC7B4c17861357B8ABB91F25581E7263E08DCB59c",
            "name": "Aave Ethereum SNX",
            "releases": [SULU],
            "symbol": "aEthSNX",
            "type": "aave-v3",
            "underlying": "0xC011a73ee8576Fb46F5E1c5751cA3B9Fe0af2a6F",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x79291A9d692Df95334B1a0B3B4AE6bC606782f8c",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "name": "Wrapped Ether",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "WETH",
            "type": "primitive",
            "price_feed": {
                "type": "WETH",
            },
        },
        {
            "decimals": 8,
            "id": "0xC11b1268C1A384e55C48c2391d8d480264A3A7F4",
            "name": "Compound Wrapped BTC",
            "releases": [],
            "symbol": "cWBTC",
            "type": "compound-v2",
            "underlying": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC14103C2141E842e228FBaC594579e798616ce7A",
            "name": "Synth sLTC",
            "releases": [],
            "symbol": "sLTC",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
            "name": "Ethereum Name Service",
            "releases": [SULU],
            "symbol": "ENS",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5C00128d4d1c2F4f652C267d7bcdD7aC99C16E16",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xC2565E08E6279FF6D746785A3ffbD598114309C8",
            "name": "Enzyme Staked: Curve.fi cDAI/cUSDC Convex Deposit",
            "releases": [],
            "symbol": "stkcvxcDAI+cUSDC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC25a3A3b969415c80451098fa907EC722572917F",
            "name": "Curve.fi DAI/USDC/USDT/sUSD",
            "pool": "0xA5407eAE9Ba41422680e2e00537571bcC53efBfD",
            "releases": [SULU],
            "staking": [],
            "symbol": "crvPlain3andSUSD",
            "template": "base",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x6B175474E89094C44Da98b954EedeAC495271d0F",
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
                "0xdAC17F958D2ee523a2206206994597C13D831ec7",
                "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xc278041fDD8249FE4c1Aad1193876857EEa3D68c",
            "name": "IdleTUSD v4 [Best yield]",
            "releases": [],
            "symbol": "idleTUSDYield",
            "type": "idle",
            "underlying": "0x0000000000085d4780B73119b644AE5ecd22b376",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC2aDdA861F89bBB333c90c492cB837741916A225",
            "name": "Uniswap MKR/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x9f8F72aA9304c8B593d555F12eF6589cC3A579A2",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xC5807183a9661A533CB08CbC297594a0B864dc12",
            "name": "Synth iTRX",
            "releases": [],
            "symbol": "iTRX",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0xC581b735A1688071A1746c968e0798D642EDE491",
            "name": "Euro Tether",
            "releases": [],
            "symbol": "EURT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC63B8ECCE56aB9C46184eC6aB85e4771fEa4c8AD",
            "name": "Synth sGOOG",
            "releases": [],
            "symbol": "sGOOG",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xc6F348dd3B91a56D117ec0071C1e9b83C0996De4",
            "name": "Uniswap ETH/ZRX Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xE41d2489571d322189246DaFA5ebDe1F4699F498",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xc713e5E149D5D0715DcD1c156a020976e7E56B88",
            "name": "Aave MKR",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aMKR",
            "type": "aave-v2",
            "underlying": "0x9f8F72aA9304c8B593d555F12eF6589cC3A579A2",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x24551a8Fb2A7211A25a17B1481f043A8a8adC7f2",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xC8E6CA6E96a326dC448307A5fDE90a0b21fd7f80",
            "name": "IdleWETH v4 [Best yield]",
            "releases": [ENCORE, PHOENIX],
            "symbol": "idleWETHYield",
            "type": "idle",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC859BF9d7B8C557bBd229565124c2C09269F3aEF",
            "name": "Balancer weETH/rETH Gauge Deposit",
            "releases": [SULU],
            "symbol": "weETH/rETH-gauge",
            "pool": "0x05ff47AFADa98a98982113758878F9A8B9FddA0a",
            "pool_type": "composable-stable-v5",
            "gauge_factory": "0xf1665E19bc105BE4EDD3739F88315cC699cc5b65",
            "underlyings": [
                "0x05ff47AFADa98a98982113758878F9A8B9FddA0a",
                "0xae78736Cd615f374D3085123A210448E74Fc6393",
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0xc944E90C64B2c07662A292be6244BDf05Cda44a7",
            "name": "Graph Token",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "GRT",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x17D054eCac33D91F7340645341eFB5DE9009F1C1",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xc9BC48c72154ef3e5425641a3c747242112a46AF",
            "name": "Aave RAI",
            "releases": [],
            "symbol": "aRAI",
            "type": "aave-v2",
            "underlying": "0x03ab458634910AaD20eF5f1C8ee96F1D6ac54919",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xCB98f42221b2C251A4E74A1609722eE09f0cc08E",
            "name": "Synth iDASH",
            "releases": [],
            "symbol": "iDASH",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xCC12AbE4ff81c9378D670De1b57F8e0Dd228D77a",
            "name": "Aave REN",
            "releases": [],
            "symbol": "aREN",
            "type": "aave-v2",
            "underlying": "0x408e41876cCCDC0F92210600ef50372656052a38",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xCC9C009d2e8A1ce476C89F0b04e60a7D40711224",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: Frax Convex Deposit",
            "releases": [],
            "symbol": "stkcvxFRAX3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0xccF4429DB6322D5C611ee964527D42E5d685DD6a",
            "name": "Compound Wrapped BTC",
            "releases": [SULU, ENCORE],
            "symbol": "cWBTC",
            "type": "compound-v2",
            "underlying": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0xcD39b5434a0A92cf47D1F567a7dF84bE356814F0",
            "name": "Synth s1INCH",
            "releases": [],
            "symbol": "s1INCH",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xce2Cc0513634CEf3a7C9C257E294EF5E3092f185",
            "name": "Uniswap OGN/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x8207c1FfC5B6804F6024322CcF34F29c3541Ae26",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "id": "0xCe3Ac66020555EdcE9b54dAD5EC1c35E0478B887",
            "name": "VaultCraft Lombard Staked Bitcoin Vault",
            "releases": [SULU],
            "symbol": "vc-LBTC",
            "decimals": 8,
            "type": "erc-4626",
            "protocol": "vaultcraft",
            "underlying": "0x8236a87084f8B84306f72007F36F2618A5634494",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
                "non_standard": True,
            },
        },
        {
            "decimals": 18,
            "id": "0xCE84867c3c02B05dc570d0135103d3fB9CC19433",
            "name": "Uniswap SUSHI/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x6B3595068778DD592e39A122f4f5a5cF09C90fE2",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xCFc25170633581Bf896CB6CDeE170e3E3Aa59503",
            "lp": "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            "name": "Curve.fi crvFRAX Gauge Deposit",
            "pool": "0xDcEF968d416a41Cdac0ED8702fAC8128A64241A2",
            "releases": [SULU],
            "symbol": "crvFRAX-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x853d955aCEf822Db058eb8505911ED77F175b99e",
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xCFfDdeD873554F362Ac02f8Fb1f02E5ada10516f",
            "name": "Uniswap COMP/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xc00e94Cb662C3520282E6f5717214004A7f26888",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xd26114cd6EE289AccF82350c8d8487fedB8A0C07",
            "name": "OMGToken",
            "releases": [],
            "symbol": "OMG",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xD291E7a03283640FDc51b121aC401383A46cC623",
            "name": "Rari Governance Token",
            "releases": [],
            "symbol": "RGT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xD2967f45c4f384DEEa880F807Be904762a3DeA07",
            "name": "Curve.fi GUSD/3Crv",
            "pool": "0x4f062658EaAF2C1ccf8C8e36D6824CDf41167956",
            "releases": [SULU],
            "staking": [],
            "symbol": "gusd3CRV",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x056Fd409E1d7A124BD7017459dFEa2F387b6d5Cd",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xd2dF355C19471c8bd7D8A3aa27Ff4e26A21b4076",
            "name": "Synth sAAVE",
            "releases": [],
            "symbol": "sAAVE",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xD31533E8d0f3DF62060e94B3F1318137bB6E3525",
            "name": "Synth sREN",
            "releases": [],
            "symbol": "sREN",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xD3772A963790feDE65646cFdae08734A17cd0f47",
            "name": "Uniswap ADX/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xADE00C28244d5CE17D72E40330B1c318cD12B7c3",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 2,
            "id": "0xD37EE7e4f452C6638c96536e68090De8cBcdb583",
            "name": "Aave GUSD",
            "releases": [],
            "symbol": "aGUSD",
            "type": "aave-v2",
            "underlying": "0x056Fd409E1d7A124BD7017459dFEa2F387b6d5Cd",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xD38aEb759891882e78E957c80656572503D8c1B1",
            "name": "Synth sCRV",
            "releases": [],
            "symbol": "sCRV",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xd3d2E2692501A5c9Ca623199D38826e513033a17",
            "name": "Uniswap UNI/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xd4937682df3C8aEF4FE912A96A74121C0829E664",
            "name": "Aave FRAX",
            "releases": [SULU],
            "symbol": "aFRAX",
            "type": "aave-v2",
            "underlying": "0x853d955aCEf822Db058eb8505911ED77F175b99e",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xB9E1E3A9feFf48998E45Fa90847ed4D467E8BcfD",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xd4B22fEdcA85E684919955061fDf353b9d38389b",
            "lp": "0x4807862AA8b2bF68830e4C8dc86D0e9A998e085a",
            "name": "Curve.fi BUSD3CRV-f Gauge Deposit",
            "pool": "0x4807862AA8b2bF68830e4C8dc86D0e9A998e085a",
            "releases": [],
            "symbol": "BUSD3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x4Fabb145d64652a948d72533023f6E7A623C7C53",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xd50c1746D835d2770dDA3703B69187bFfeB14126",
            "name": "Synth iETC",
            "releases": [],
            "symbol": "iETC",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xD533a949740bb3306d119CC777fa900bA034cd52",
            "name": "Curve DAO Token",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "CRV",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8a12Be339B0cD1829b91Adc01977caa5E9ac121e",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xD6014EA05BDe904448B743833dDF07c3C7837481",
            "name": "Synth iBTC",
            "releases": [],
            "symbol": "iBTC",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xd632f22692FaC7611d2AA1C0D552930D43CAEd3B",
            "name": "Curve.fi Factory USD Metapool: Frax",
            "pool": "0xd632f22692FaC7611d2AA1C0D552930D43CAEd3B",
            "releases": [SULU],
            "staking": [
                {"token": "0x72E158d38dbd50A483501c24f792bDAAA3e7D55C", "type": "gauge"}
            ],
            "symbol": "FRAX3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x853d955aCEf822Db058eb8505911ED77F175b99e",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xd662908ADA2Ea1916B3318327A97eB18aD588b5d",
            "lp": "0xFd2a8fA60Abd58Efe3EeE34dd494cD491dC14900",
            "name": "Curve.fi a3CRV Gauge Deposit",
            "pool": "0xDeBF20617708857ebe4F679508E7b7863a8A8EeE",
            "releases": [SULU, ENCORE],
            "symbol": "a3CRV-gauge",
            "template": "aave",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x028171bCA77440897B824Ca71D1c56caC55b68A3",
                "0xBcca60bB61934080951369a648Fb03DF4F96263C",
                "0x3Ed3B47Dd13EC9a98b44e6204A523E766B225811",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xD71eCFF9342A5Ced620049e616c5035F1dB98620",
            "name": "Synth sEUR",
            "releases": [],
            "symbol": "sEUR",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xd8b712d29381748dB89c36BCa0138d7c75866ddF",
            "lp": "0x5a6A4D54456819380173272A5E8E9B9904BdF41B",
            "name": "Curve.fi MIM-3LP3CRV-f Gauge Deposit",
            "pool": "0x5a6A4D54456819380173272A5E8E9B9904BdF41B",
            "releases": [SULU],
            "symbol": "MIM-3LP3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x99D8a9C45b2ecA8864373A26D1459e3Dff1e17F3",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xda7F9DD286577cC338047B040c289463743a474e",
            "lp": "0x4e43151b78b5fbb16298C1161fcbF7531d5F8D93",
            "name": "Curve.fi GUSDFRAXBP3CRV-f Gauge Deposit",
            "pool": "0x4e43151b78b5fbb16298C1161fcbF7531d5F8D93",
            "releases": [SULU],
            "symbol": "GUSDFRAXBP3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x056Fd409E1d7A124BD7017459dFEa2F387b6d5Cd",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xdA816459F1AB5631232FE5e97a05BBBb94970c95",
            "name": "DAI yVault 0.4.3",
            "releases": [SULU, ENCORE],
            "symbol": "yvDAI",
            "type": "yearn-vault-v2",
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 6,
            "id": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "name": "Tether USD",
            "releases": [SULU, ENCORE],
            "symbol": "USDT",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x3E7d1eAB13ad0104d2750B8863b489D65364e32D",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xDb0c0C9f6Dd47a1D29992f0e65b77C30C844521a",
            "name": "Enzyme Staked: Curve.fi aDAI/aUSDC/aUSDT Convex Deposit",
            "releases": [],
            "symbol": "stkcvxa3CRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xdb25cA703181E7484a155DD612b06f57E12Be5F0",
            "name": "YFI yVault 0.4.3",
            "releases": [SULU],
            "symbol": "yvYFI",
            "type": "yearn-vault-v2",
            "underlying": "0x0bc529c00C6401aEF6D220BE8C6Ea1667F6Ad93e",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 2,
            "id": "0xdB25f211AB05b1c97D595516F45794528a807ad8",
            "name": "STASIS EURS Token",
            "releases": [],
            "symbol": "EURS",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xdCD90C7f6324cfa40d7169ef80b12031770B4325",
            "name": "Curve stETH Pool yVault 0.3.0",
            "releases": [SULU],
            "symbol": "yvCurve-stETH",
            "type": "yearn-vault-v2",
            "underlying": "0x06325440D014e39736583c165C2963BA99fAf14E",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0xdd974D5C2e2928deA5F71b9825b8b646686BD200",
            "name": "Kyber Network Crystal Legacy",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "KNCL",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x656c0544eF4C98A6a98491833A89204Abb045d6b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xDe30da39c46104798bB5aA3fe8B9e0e1F348163F",
            "name": "Gitcoin",
            "releases": [],
            "symbol": "GTC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xdeFA4e8a7bcBA345F687a2f1456F5Edd9CE97202",
            "name": "Kyber Network Crystal v2",
            "releases": [SULU, ENCORE],
            "symbol": "KNC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x656c0544eF4C98A6a98491833A89204Abb045d6b",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0xdF574c24545E5FfEcb9a659c229253D4111d87e1",
            "name": "HUSD",
            "releases": [],
            "symbol": "HUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xDf7FF54aAcAcbFf42dfe29DD6144A69b629f8C9e",
            "name": "Aave ZRX",
            "releases": [],
            "symbol": "aZRX",
            "type": "aave-v2",
            "underlying": "0xE41d2489571d322189246DaFA5ebDe1F4699F498",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xDFC14d2Af169B0D36C4EFF567Ada9b2E0CAE044f",
            "name": "Uniswap AAVE/ETH Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x7Fc66500c84A76Ad7e9c93437bFc5Ac33E2DDaE9",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xDFe66B14D37C77F4E9b180cEb433d1b164f0281D",
            "name": "stakedETH",
            "releases": [],
            "symbol": "stETH",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xE12E854d588c555cb3C42AF50984083798F40E66",
            "name": "Enzyme Staked: Curve.fi Factory USD Metapool: Magic Internet Money 3Pool Convex Deposit",
            "releases": [],
            "symbol": "stkcvxMIM-3LP3CRV-f",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xE14d13d8B3b85aF791b2AADD661cDBd5E6097Db1",
            "name": "YFI yVault 0.3.2",
            "releases": [ENCORE],
            "symbol": "yvYFI",
            "type": "yearn-vault-v2",
            "underlying": "0x0bc529c00C6401aEF6D220BE8C6Ea1667F6Ad93e",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xe1aFe1Fd76Fd88f78cBf599ea1846231B8bA3B6B",
            "name": "Synth sDEFI",
            "releases": [],
            "symbol": "sDEFI",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xe28b3B32B6c345A34Ff64674606124Dd5Aceca30",
            "name": "Injective Token",
            "releases": [],
            "symbol": "INJ",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xe3c190c57b5959Ae62EfE3B6797058B76bA2f5eF",
            "name": "Curve.fi Factory USD Metapool: sUSDFRAXBP",
            "pool": "0xe3c190c57b5959Ae62EfE3B6797058B76bA2f5eF",
            "releases": [SULU],
            "staking": [
                {"token": "0xf6D7087D4Ae4dCf85956d743406E63cDA74D99AD", "type": "gauge"}
            ],
            "symbol": "SUSDFRAXBP3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xe2FFFF40D8C3ff7915bCE57d0FcDFd5769D4eDB0",
            "name": "Enzyme Staked: Curve.fi ETH/sETH Convex Deposit",
            "releases": [],
            "symbol": "stkcvxeCRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xe36E2D3c7c34281FA3bC737950a68571736880A1",
            "name": "Synth sADA",
            "releases": [],
            "symbol": "sADA",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xE41d2489571d322189246DaFA5ebDe1F4699F498",
            "name": "0x Protocol Token",
            "releases": [],
            "symbol": "ZRX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xE56c60B5f9f7B5FC70DE0eb79c6EE7d00eFa2625",
            "name": "Uniswap ETH/ENJ Pool",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xF629cBd94d3791C9250152BD8dfBDF380E2a3B9c",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 8,
            "id": "0xe65cdB6479BaC1e22340E4E755fAE7E509EcD06c",
            "name": "Compound Aave Token",
            "releases": [SULU, ENCORE],
            "symbol": "cAAVE",
            "type": "compound-v2",
            "underlying": "0x7Fc66500c84A76Ad7e9c93437bFc5Ac33E2DDaE9",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0xeABACD844A196D7Faf3CE596edeBF9900341B420",
            "name": "Synth sCEX",
            "releases": [],
            "symbol": "sCEX",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xEb029507d3e043DD6C87F2917C4E82B902c35618",
            "name": "Synth sCOMP",
            "releases": [],
            "symbol": "sCOMP",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0xEB4C2781e4ebA804CE9a9803C67d0893436bB27D",
            "name": "renBTC",
            "releases": [],
            "symbol": "renBTC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xEcd5e75AFb02eFa118AF914515D6521aaBd189F1",
            "name": "Curve.fi Factory USD Metapool: TrueUSD",
            "pool": "0xEcd5e75AFb02eFa118AF914515D6521aaBd189F1",
            "releases": [],
            "staking": [
                {"token": "0x359FD5d6417aE3D8D6497d9B2e7A890798262BA4", "type": "gauge"}
            ],
            "symbol": "TUSD3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x0000000000085d4780B73119b644AE5ecd22b376",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xec67005c4E498Ec7f55E092bd1d35cbC47C91892",
            "name": "Enzyme",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "MLN",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xDaeA8386611A157B08829ED4997A8A62B557014C",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xEd279fDD11cA84bEef15AF5D39BB4d4bEE23F0cA",
            "name": "Curve.fi Factory USD Metapool: Liquity",
            "pool": "0xEd279fDD11cA84bEef15AF5D39BB4d4bEE23F0cA",
            "releases": [SULU],
            "staking": [
                {"token": "0x9B8519A9a00100720CCdC8a120fBeD319cA47a14", "type": "gauge"}
            ],
            "symbol": "LUSD3CRV-f",
            "template": "meta",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x5f98805A4E8be255a32880FDeC7F6728C6568bA0",
                "0x6c3F90f043a72FA612cbac8115EE7e52BDe6E490",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xEd91879919B71bB6905f23af0A68d231EcF87b14",
            "name": "DMM: Governance",
            "releases": [],
            "symbol": "DMG",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF29AE508698bDeF169B89834F76704C3B205aedf",
            "name": "SNX yVault 0.3.5",
            "releases": [],
            "symbol": "yvSNX",
            "type": "yearn-vault-v2",
            "underlying": "0xC011a73ee8576Fb46F5E1c5751cA3B9Fe0af2a6F",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf2E08356588EC5cd9E437552Da87C0076b4970B0",
            "name": "Synth sTRX",
            "releases": [],
            "symbol": "sTRX",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF34842d05A1c888Ca02769A633DF37177415C2f8",
            "name": "IdleUSDT v4 [Best yield]",
            "releases": [ENCORE],
            "symbol": "idleUSDTYield",
            "type": "idle",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf421c3f2e695C2D4C0765379cCace8adE4a480D9",
            "name": "Uniswap BAND/ETH Pool",
            "releases": [],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xBA11D00c5f74255f56a5E366F4F77f5A186d7f55",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF48e200EAF9906362BB1442fca31e0835773b8B4",
            "name": "Synth sAUD",
            "releases": [],
            "symbol": "sAUD",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf49C43Ae0fAf37217bDcB00DF478cF793eDd6687",
            "name": "Uniswap ETH/KNCL Pool",
            "releases": [ENCORE, PHOENIX],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xdd974D5C2e2928deA5F71b9825b8b646686BD200",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF4EebDD0704021eF2a6Bbe993fdf93030Cd784b4",
            "name": "Synth iEOS",
            "releases": [],
            "symbol": "iEOS",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf50B5e535F62a56A9BD2d8e2434204E726c027Fa",
            "name": "Synth sFB",
            "releases": [],
            "symbol": "sFB",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF52CDcD458bf455aeD77751743180eC4A595Fd3F",
            "name": "IdleSUSD v4 [Best yield]",
            "releases": [],
            "symbol": "idleSUSDYield",
            "type": "idle",
            "underlying": "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF629cBd94d3791C9250152BD8dfBDF380E2a3B9c",
            "name": "Enjin Coin",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "ENJ",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x24D9aB51950F3d62E9144fdC2f3135DAA6Ce8D1B",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0xf650C3d88D12dB855b8bf7D11Be6C55A4e07dCC9",
            "name": "Compound USDT",
            "releases": [SULU, ENCORE],
            "symbol": "cUSDT",
            "type": "compound-v2",
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "DERIVATIVE_COMPOUND",
                "address": "0x6254e0538Abbb668eaC89d5e5BEe27a9D0E62bBE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF6b1C627e95BFc3c1b4c9B825a032Ff0fBf3e07d",
            "name": "Synth sJPY",
            "releases": [],
            "symbol": "sJPY",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf6D7087D4Ae4dCf85956d743406E63cDA74D99AD",
            "lp": "0xe3c190c57b5959Ae62EfE3B6797058B76bA2f5eF",
            "name": "Curve.fi SUSDFRAXBP3CRV-f Gauge Deposit",
            "pool": "0xe3c190c57b5959Ae62EfE3B6797058B76bA2f5eF",
            "releases": [SULU],
            "symbol": "SUSDFRAXBP3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xf6E9b246319ea30e8C2fA2d1540AAEBF6f9E1B89",
            "name": "Synth iBCH",
            "releases": [],
            "symbol": "iBCH",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf80758aB42C3B07dA84053Fd88804bCB6BAA4b5c",
            "name": "Uniswap sUSD/ETH Pool",
            "releases": [SULU],
            "symbol": "UNI-V2",
            "type": "uniswap-v2-pool",
            "underlyings": [
                "0x57Ab1ec28D129707052df4dF418D58a2D46d5f51",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_UNISWAP_V2_POOL",
                "address": "0xdbc1162eA1aB770f0BA5Fb494e0010e68351e3b0",
            },
        },
        {
            "decimals": 18,
            "id": "0xf865FDd6a5F307F398a94Dc40687995Cfaa77BC9",
            "lp": "0x33baeDa08b8afACc4d3d07cf31d49FC1F1f3E893",
            "name": "Curve.fi TUSDFRAXBP3CRV-f Gauge Deposit",
            "pool": "0x33baeDa08b8afACc4d3d07cf31d49FC1F1f3E893",
            "releases": [],
            "symbol": "TUSDFRAXBP3CRV-f-gauge",
            "template": "meta",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0x0000000000085d4780B73119b644AE5ecd22b376",
                "0x3175Df0976dFA876431C2E9eE6Bc45b65d3473CC",
            ],
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf9e293D5D793DDc1Ae4F778761e0b3E4aA7cF2dD",
            "name": "CelsiusX Wrapped DOGE",
            "releases": [],
            "symbol": "cxDOGE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf951E335afb289353dc249e82926178EaC7DEd78",
            "name": "swETH",
            "releases": [SULU],
            "symbol": "swETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0xEfcdDA24Cfe185621c7271D1f260C5bE5D4ebCF2",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xfaA2a0B71647FcC4a851503423AF6eb41c35d006",
            "name": "Enzyme Staked: Curve.fi ETH/stETH Convex Deposit",
            "releases": [],
            "symbol": "stkcvxsteCRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xFa325D1Aa0ad84b1513893F393D4c0CBE3435a20",
            "name": "Enzyme Staked: Curve.fi FRAX/USDC Convex Deposit",
            "releases": [],
            "symbol": "stkcvxcrvFRAX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xFAe103DC9cf190eD75350761e95403b7b8aFa6c0",
            "name": "rswETH",
            "releases": [SULU],
            "symbol": "rswETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0x189281321B51575d2FE5CE6b94642d4362f24013",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xFBEB78a723b8087fD2ea7Ef1afEc93d35E8Bed42",
            "name": "UNI yVault 0.3.5",
            "releases": [SULU, ENCORE],
            "symbol": "yvUNI",
            "type": "yearn-vault-v2",
            "underlying": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "price_feed": {
                "type": "DERIVATIVE_YEARN_VAULT_V2",
                "address": "0x3982e1CC26b99310747Df54f445063745C54A324",
            },
        },
        {
            "decimals": 18,
            "id": "0xFca59Cd816aB1eaD66534D82bc21E7515cE441CF",
            "name": "Rarible",
            "releases": [],
            "symbol": "RARI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xFd2a8fA60Abd58Efe3EeE34dd494cD491dC14900",
            "name": "Curve.fi aDAI/aUSDC/aUSDT",
            "pool": "0xDeBF20617708857ebe4F679508E7b7863a8A8EeE",
            "releases": [SULU, ENCORE],
            "staking": [
                {"token": "0xd662908ADA2Ea1916B3318327A97eB18aD588b5d", "type": "gauge"}
            ],
            "symbol": "a3CRV",
            "template": "aave",
            "type": "curve-pool-lp",
            "underlyings": [
                "0x028171bCA77440897B824Ca71D1c56caC55b68A3",
                "0xBcca60bB61934080951369a648Fb03DF4F96263C",
                "0x3Ed3B47Dd13EC9a98b44e6204A523E766B225811",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
            },
        },
        {
            "decimals": 18,
            "id": "0xfE18be6b3Bd88A2D2A7f928d00292E7a9963CfC6",
            "name": "Synth sBTC",
            "releases": [],
            "symbol": "sBTC",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xfE33ae95A9f0DA8A845aF33516EDc240DCD711d6",
            "name": "Synth sDASH",
            "releases": [],
            "symbol": "sDASH",
            "type": "synthetix",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xfF20817765cB7f73d4bde2e66e067E58D11095C2",
            "name": "Amp",
            "releases": [],
            "symbol": "AMP",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xFFC97d72E13E01096502Cb8Eb52dEe56f74DAD7B",
            "name": "Aave AAVE",
            "releases": [SULU, ENCORE, PHOENIX],
            "symbol": "aAAVE",
            "type": "aave-v2",
            "underlying": "0x7Fc66500c84A76Ad7e9c93437bFc5Ac33E2DDaE9",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x6Df09E975c830ECae5bd4eD9d90f3A95a4f88012",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xA700b4eB416Be35b2911fd5Dee80678ff64fF6C9",
            "name": "Aave Ethereum AAVE",
            "releases": [SULU],
            "symbol": "aEthAAVE",
            "type": "aave-v3",
            "underlying": "0x7Fc66500c84A76Ad7e9c93437bFc5Ac33E2DDaE9",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x6Df09E975c830ECae5bd4eD9d90f3A95a4f88012",
                "rate_asset": RateAsset.ETH,
            },
        },
        # TODO: order assets below by id
        {
            "decimals": 18,
            "id": "0xF57e7e7C23978C3cAEC3C3548E3D615c346e79fF",
            "name": "Immutable X",
            "releases": [SULU],
            "symbol": "IMX",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xBAEbEFc1D023c0feCcc047Bff42E75F15Ff213E6",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xFeBd6F15Df3B73DC4307B1d7E65D46413e710C27",
            "name": "Orthogonal Trading - USDC01",
            "releases": [],
            "symbol": "MPL-LP",
            "type": "maple-v1",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "rewards_contract": "0x7869D7a3B074b5fa484dc04798E254c9C06A5e90",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6F6c8013f639979C84b756C7FC1500eB5aF18Dc4",
            "name": "Maven 11 - USDC 01",
            "releases": [],
            "symbol": "MPL-LP",
            "type": "maple-v1",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "rewards_contract": "0x7C57bF654Bc16B0C9080F4F75FF62876f50B8259",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1A066b0109545455BC771E49e6EDef6303cb0A93",
            "name": "Maven 11 WETH Pool",
            "releases": [],
            "symbol": "MPL-LP",
            "type": "maple-v1",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "rewards_contract": "0x0a76C7913C94F2AF16958FbDF9b4CF0bBdb159d8",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1A4b46696b2bB4794Eb3D4c26f1c55F9170fa4C5",
            "name": "BitDAO",
            "releases": [],
            "symbol": "BIT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xa1fE1B5fC23c2DAb0C28d4CC09021014F30bE8F1",
            "name": "Celsius wETH Pool",
            "releases": [],
            "symbol": "MPL-LP",
            "type": "maple-v1",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "rewards_contract": "0x0000000000000000000000000000000000000000",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3e701d29fCB8747b5C3f88649397D88fff9bD3e9",
            "name": "Alameda Research - USDC",
            "releases": [],
            "symbol": "MPL-LP",
            "type": "maple-v1",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "rewards_contract": "0x5e804B9A61b3e5bF2718EA249DEb13366129b7dE",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xd618d93676762a8e3107554d9aDBFF7Dfd7FBF47",
            "name": "BlockTower Capital - USDC01",
            "releases": [],
            "symbol": "MPL-LP",
            "type": "maple-v1",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "rewards_contract": "0xd0123f5220a36E9eC6082D83B4a11F92aA48cCD0",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xD9A442856C234a39a81a089C06451EBAa4306a72",
            "name": "pufETH",
            "releases": [SULU],
            "symbol": "pufETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0x114e286b85AAcd4032A8b399CD288944fc5B7a90",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x767FE9EDC9E0dF98E07454847909b5E959D7ca0E",
            "name": "Illuvium",
            "releases": [],
            "symbol": "ILV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0x79400A2c9a5E2431419CaC98Bf46893c86E8bDd7",
            "pool_manager": "0xE10A065D15A6eCA69bb8A0063Fe57eDdb66999DF",
            "name": "Orthogonal Trading - USDC01",
            "releases": [],
            "symbol": "MPL-ocUSDC1",
            "type": "maple-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0xd3cd37a7299B963bbc69592e5Ba933388f70dc88",
            "pool_manager": "0x00d950A41a0d277ed91bF9fD366a5523FEF0371e",
            "name": "M11 Credit Maple Pool USDC2",
            "releases": [],
            "symbol": "MPL-mcUSDC2",
            "type": "maple-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xFfF9A1CAf78b2e5b0A49355a8637EA78b43fB6c3",
            "pool_manager": "0x833A5c9Fc016a87419D21B10B64e24082Bd1e49d",
            "name": "M11 Credit Maple Pool WETH1",
            "releases": [],
            "symbol": "MPL-mcWETH1",
            "type": "maple-v2",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0x137F2EA5cfB0fE59408BAb2779E33EE868F1810E",
            "pool_manager": "0xC0323b64eF95E5698B30fEbD6A54BFD66ca2210E",
            "name": "Icebreaker Maple Pool USDC1",
            "releases": [],
            "symbol": "MPL-ibUSDC1",
            "type": "maple-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x13947303F63b363876868D070F14dc865C36463b",
            "name": "weETH/WETH",
            "pool": "0x13947303F63b363876868D070F14dc865C36463b",
            "releases": [SULU],
            "staking": [
                {"token": "0x1CAC1a0Ed47E2e0A313c712b2dcF85994021a365", "type": "gauge"}
            ],
            "symbol": "weETH-WETH",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 6,
            "id": "0x00e0C1ea2085e30E5233E98CFA940ca8cbB1b0b7",
            "pool_manager": "0xE10A065D15A6eCA69bb8A0063Fe57eDdb66999DF",
            "name": "M11 Credit Maple Pool USDC1",
            "releases": [],
            "symbol": "MPL-mcUSDC1",
            "type": "maple-v2",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x33349B282065b0284d756F0577FB39c158F935e6",
            "name": "Maple Token",
            "releases": [],
            "symbol": "MPL",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x62B9c7356A2Dc64a1969e19C23e4f579F9810Aa7",
            "name": "Convex CRV",
            "releases": [],
            "symbol": "cvxCRV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xFEEf77d3f69374f66429C91d732A244f074bdf74",
            "name": "Convex FXS",
            "releases": [],
            "symbol": "cvxFXS",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x828b154032950C8ff7CF8085D841723Db2696056",
            "name": "Curve.fi Factory Plain Pool: stETH concentrated",
            "pool": "0x828b154032950C8ff7CF8085D841723Db2696056",
            "releases": [SULU],
            "staking": [
                {"token": "0xF668E6D326945d499e5B35E7CD2E82aCFbcFE6f0", "type": "gauge"}
            ],
            "symbol": "STETHETH_C-f",
            "template": "eth",
            "type": "curve-pool-lp",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xae7ab96520DE3A18E5e111B5EaAb095312D7fE84",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0xF668E6D326945d499e5B35E7CD2E82aCFbcFE6f0",
            "lp": "0x828b154032950C8ff7CF8085D841723Db2696056",
            "name": "Curve.fi STETHETH_C-f Gauge Deposit",
            "pool": "0x828b154032950C8ff7CF8085D841723Db2696056",
            "releases": [SULU],
            "symbol": "STETHETH_C-f-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
                "0xae7ab96520DE3A18E5e111B5EaAb095312D7fE84",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x6810e776880C02933D47DB1b9fc05908e5386b96",
            "name": "Gnosis Token",
            "releases": [],
            "symbol": "GNO",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2EBfF165CB363002C5f9cBcfd6803957BA0B7208",
            "name": "Geist.Finance Protocol Token",
            "releases": [],
            "symbol": "GEIST",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xdBdb4d16EdA451D0503b854CF79D55697F90c8DF",
            "name": "Alchemix",
            "releases": [],
            "symbol": "ALCX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3432B6A60D23Ca0dFCa7761B7ab56459D9C964D0",
            "name": "Frax Share",
            "releases": [SULU],
            "symbol": "FXS",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x6Ebc52C8C1089be9eB3945C4350B68B8E4C2233f",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xa3BeD4E1c75D00fa6f4E5E6922DB7261B5E9AcD2",
            "name": "Meta",
            "releases": [],
            "symbol": "MTA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xc7283b66Eb1EB5FB86327f08e1B5816b0720212B",
            "name": "Tribe",
            "releases": [],
            "symbol": "TRIBE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x31429d1856aD1377A8A0079410B297e1a9e214c2",
            "name": "ANGLE",
            "releases": [],
            "symbol": "ANGLE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6243d8CEA23066d098a15582d81a598b4e8391F4",
            "name": "Flex Ungovernance Token",
            "releases": [],
            "symbol": "FLX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xCdF7028ceAB81fA0C6971208e83fa7872994beE5",
            "name": "Threshold Network Token",
            "releases": [],
            "symbol": "T",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x3Ec8798B81485A254928B70CDA1cf0A2BB0B74D7",
            "name": "Gro DAO Token",
            "releases": [],
            "symbol": "GRO",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x41D5D79431A913C4aE7d69a668ecdfE5fF9DFB68",
            "name": "Inverse DAO",
            "releases": [],
            "symbol": "INV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xB620Be8a1949AA9532e6a3510132864EF9Bc3F82",
            "name": "LendFlare DAO Token",
            "releases": [],
            "symbol": "LFT",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x01BA67AAC7f75f647D94220Cc98FB30FCc5105Bf",
            "name": "Lyra Token",
            "releases": [],
            "symbol": "LYRA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xE80C0cd204D654CEbe8dd64A4857cAb6Be8345a3",
            "name": "JPEG’d Governance Token",
            "releases": [],
            "symbol": "JPEG",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xAf5191B0De278C7286d6C7CC6ab6BB8A73bA2Cd6",
            "name": "StargateToken",
            "releases": [],
            "symbol": "STG",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4C0d9e35AD2C952bCd58A6d255C9Dc2784AC6f08",
            "name": "Melon Premium Token",
            "releases": [],
            "symbol": "PTKN_MLN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4c9EDD5852cd905f086C759E8383e09bff1E68B3",
            "name": "USDe",
            "releases": [SULU],
            "symbol": "USDe",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_REDSTONE",
                "aggregator": "0xbC5FBcf58CeAEa19D523aBc76515b9AEFb5cfd58",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x455e53CBB86018Ac2B8092FdCd39d8444aFFC3F6",
            "name": "Polygon Ecosystem Token",
            "releases": [SULU],
            "symbol": "POL",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x7bAC85A8a13A4BcD8abb3eB7d6b4d632c5a57676",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x45804880De22913dAFE09f4980848ECE6EcbAf78",
            "name": "Paxos Gold",
            "releases": [],
            "symbol": "PAXG",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 9,
            "id": "0xD31a59c85aE9D8edEFeC411D448f90841571b89c",
            "name": "Wrapped SOL",
            "releases": [SULU],
            "symbol": "SOL",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x4ffC43a60e009B551865A93d232E33Fce9f01507",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x6DEA81C8171D0bA574754EF6F8b412F2Ed88c54D",
            "name": "LQTY",
            "releases": [],
            "symbol": "LQTY",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x967da4048cD07aB37855c090aAF366e4ce1b9F48",
            "name": "Ocean Token",
            "releases": [],
            "symbol": "OCEAN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6a445E9F40e0b97c92d0b8a3366cEF1d67F700BF",
            "name": "Fidu",
            "releases": [],
            "symbol": "FIDU",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x4332f8A38f14BD3D8D1553aF27D7c7Ac6C27278D",
            "name": "Ape Finance",
            "releases": [],
            "symbol": "APEFI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0C10bF8FcB7Bf5412187A595ab97a3609160b5c6",
            "name": "Decentralized USD",
            "releases": [],
            "symbol": "USDD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5c6Ee304399DBdB9C8Ef030aB642B10820DB8F56",
            "name": "Balancer 80 BAL 20 WETH",
            "releases": [SULU],
            "symbol": "B-80BAL-20WETH",
            "staking": [],
            "pool_id": "0x5c6ee304399dbdb9c8ef030ab642b10820db8f56000200000000000000000014",
            "pool_factory": "0xA5bf2ddF098bb0Ef6d120C98217dD6B141c74EE0",
            "pool_type": "weighted",
            "underlyings": [
                "0xba100000625a3754423978a60c9317c58a424e3D",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x083B8F465BbA2BB274E48387e3f9C56323341286",
            },
        },
        {
            "decimals": 18,
            "id": "0xc45D42f801105e861e86658648e3678aD7aa70f9",
            "name": "Balancer 50OHM-25DAI-25WETH",
            "releases": [],
            "symbol": "50OHM-25DAI-25WETH",
            "staking": [
                {"token": "0x852CF729dEF9beB9De2f18c97a0ea6bf93a7dF8B", "type": "gauge"}
            ],
            "pool_id": "0xc45d42f801105e861e86658648e3678ad7aa70f900010000000000000000011e",
            "pool_factory": "0x8E9aa87E45e92bad84D5F8DD1bff34Fb92637dE9",
            "pool_type": "weighted",
            "underlyings": [
                "0x64aa3364F17a4D01c6f1751Fd97C2BD3D7e7f1D5",
                "0x6B175474E89094C44Da98b954EedeAC495271d0F",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x852CF729dEF9beB9De2f18c97a0ea6bf93a7dF8B",
            "name": "Balancer 50OHM-25DAI-25WETH Gauge Deposit",
            "releases": [],
            "symbol": "50OHM-25DAI-25WETH-gauge",
            "pool": "0xc45D42f801105e861e86658648e3678aD7aa70f9",
            "pool_type": "weighted",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0x64aa3364F17a4D01c6f1751Fd97C2BD3D7e7f1D5",
                "0x6B175474E89094C44Da98b954EedeAC495271d0F",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xF4C0DD9B82DA36C07605df83c8a416F11724d88b",
            "name": "Balancer 80 GNO 20 WETH",
            "releases": [],
            "symbol": "B-80GNO-20WETH",
            "staking": [
                {
                    "token": "0xCB664132622f29943f67FA56CCfD1e24CC8B4995",
                    "type": "gauge",
                },
            ],
            "pool_id": "0xf4c0dd9b82da36c07605df83c8a416f11724d88b000200000000000000000026",
            "pool_factory": "0xA5bf2ddF098bb0Ef6d120C98217dD6B141c74EE0",
            "pool_type": "weighted",
            "underlyings": [
                "0x6810e776880C02933D47DB1b9fc05908e5386b96",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xCB664132622f29943f67FA56CCfD1e24CC8B4995",
            "name": "Balancer B-80GNO-20WETH Gauge Deposit",
            "releases": [],
            "symbol": "B-80GNO-20WETH-gauge",
            "pool": "0xF4C0DD9B82DA36C07605df83c8a416F11724d88b",
            "pool_type": "weighted",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0x6810e776880C02933D47DB1b9fc05908e5386b96",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA6F548DF93de924d73be7D25dC02554c6bD66dB5",
            "name": "Balancer 50 WBTC 50 WETH",
            "releases": [SULU],
            "symbol": "B-50WBTC-50WETH",
            "staking": [
                {"token": "0x4E3c048BE671852277Ad6ce29Fd5207aA12fabff", "type": "gauge"}
            ],
            "pool_id": "0xa6f548df93de924d73be7d25dc02554c6bd66db500020000000000000000000e",
            "pool_factory": "0xA5bf2ddF098bb0Ef6d120C98217dD6B141c74EE0",
            "pool_type": "weighted",
            "underlyings": [
                "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x083B8F465BbA2BB274E48387e3f9C56323341286",
            },
        },
        {
            "decimals": 18,
            "id": "0x4E3c048BE671852277Ad6ce29Fd5207aA12fabff",
            "name": "Balancer B-50WBTC-50WETH Gauge Deposit",
            "releases": [SULU],
            "symbol": "B-50WBTC-50WETH-gauge",
            "pool": "0xA6F548DF93de924d73be7D25dC02554c6bD66dB5",
            "pool_type": "weighted",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0xc632ad74220bf2FAC44299343b9Ca107e7036330",
            "name": "Enzyme Staked: Balancer 50 WBTC 50 WETH Aura Deposit",
            "releases": [],
            "symbol": "stkauraB-50WBTC-50WETH",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x96646936b91d6B9D7D0c47C496AfBF3D6ec7B6f8",
            "name": "Balancer 50 USDC 50 WETH",
            "releases": [SULU],
            "symbol": "B-50USDC-50WETH",
            "staking": [
                {"token": "0x9AB7B0C7b154f626451c9e8a68dC04f58fb6e5Ce", "type": "gauge"}
            ],
            "pool_id": "0x96646936b91d6b9d7d0c47c496afbf3d6ec7b6f8000200000000000000000019",
            "pool_factory": "0xA5bf2ddF098bb0Ef6d120C98217dD6B141c74EE0",
            "pool_type": "weighted",
            "underlyings": [
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x083B8F465BbA2BB274E48387e3f9C56323341286",
            },
        },
        {
            "decimals": 18,
            "id": "0x9AB7B0C7b154f626451c9e8a68dC04f58fb6e5Ce",
            "name": "Balancer B-50USDC-50WETH Gauge Deposit",
            "releases": [SULU],
            "symbol": "B-50USDC-50WETH-gauge",
            "pool": "0x96646936b91d6B9D7D0c47C496AfBF3D6ec7B6f8",
            "pool_type": "weighted",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0x9A44fd41566876A39655f74971a3A6eA0a17a454",
            "name": "Aave Ethereum LDO",
            "releases": [SULU],
            "symbol": "aEthLDO",
            "type": "aave-v3",
            "underlying": "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x4e844125952D32AcdF339BE976c98E22F6F318dB",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x162c925Bb021603A6812e86953a8E2420025b4Be",
            "name": "Enzyme Staked: Balancer 50 USDC 50 WETH Aura Deposit",
            "releases": [],
            "symbol": "stkauraB-50USDC-50WETH",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6a5EaD5433a50472642Cd268E584dafa5a394490",
            "name": "Balancer 50wstETH-50LDO",
            "releases": [],
            "symbol": "50WSTETH-50LDO",
            "staking": [
                {"token": "0xc2c2304E163e1aB53De2eEB08820a0B592bec20B", "type": "gauge"}
            ],
            "pool_id": "0x6a5ead5433a50472642cd268e584dafa5a394490000200000000000000000366",
            "pool_factory": "0xcC508a455F5b0073973107Db6a878DdBDab957bC",
            "pool_type": "weighted",
            "underlyings": [
                "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
                "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xc2c2304E163e1aB53De2eEB08820a0B592bec20B",
            "name": "Balancer 50WSTETH-50LDO Gauge Deposit",
            "releases": [],
            "symbol": "50WSTETH-50LDO-gauge",
            "pool": "0x6a5EaD5433a50472642Cd268E584dafa5a394490",
            "pool_type": "weighted",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
                "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x5f1f4E50ba51D723F12385a8a9606afc3A0555f5",
            "name": "Balancer 50wstETH-LDO",
            "releases": [SULU],
            "symbol": "50wstETH-50LDO",
            "staking": [
                {"token": "0x95201B61EF19C867dA0D093DF20021e1a559452c", "type": "gauge"}
            ],
            "pool_id": "0x5f1f4e50ba51d723f12385a8a9606afc3a0555f5000200000000000000000465",
            "pool_factory": "0x5Dd94Da3644DDD055fcf6B3E1aa310Bb7801EB8b",
            "pool_type": "weighted",
            "underlyings": [
                "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
                "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x083B8F465BbA2BB274E48387e3f9C56323341286",
            },
        },
        {
            "decimals": 18,
            "id": "0x95201B61EF19C867dA0D093DF20021e1a559452c",
            "name": "Balancer 50wstETH-50LDO Gauge Deposit",
            "releases": [SULU],
            "symbol": "50wstETH-50LDO-gauge",
            "pool": "0x5f1f4E50ba51D723F12385a8a9606afc3A0555f5",
            "pool_type": "weighted",
            "gauge_factory": "0xf1665E19bc105BE4EDD3739F88315cC699cc5b65",
            "underlyings": [
                "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
                "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0xdeb03A6e34e6BEB2600b4036667d31440A0a726c",
            "name": "Enzyme Staked: Balancer 50wstETH-LDO Aura Deposit",
            "releases": [],
            "symbol": "stkaura50wstETH-50LDO",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xBF96189Eee9357a95C7719f4F5047F76bdE804E5",
            "name": "Balancer 80 LDO 20 WETH",
            "releases": [SULU],
            "symbol": "B-80LDO-20WETH",
            "staking": [
                {"token": "0x942CB1Ed80D3FF8028B3DD726e0E2A9671bc6202", "type": "gauge"}
            ],
            "pool_id": "0xbf96189eee9357a95c7719f4f5047f76bde804e5000200000000000000000087",
            "pool_factory": "0xA5bf2ddF098bb0Ef6d120C98217dD6B141c74EE0",
            "pool_type": "weighted",
            "underlyings": [
                "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x083B8F465BbA2BB274E48387e3f9C56323341286",
            },
        },
        {
            "decimals": 18,
            "id": "0x942CB1Ed80D3FF8028B3DD726e0E2A9671bc6202",
            "name": "Balancer B-80LDO-20WETH Gauge Deposit",
            "releases": [SULU],
            "symbol": "B-80LDO-20WETH-gauge",
            "pool": "0xBF96189Eee9357a95C7719f4F5047F76bdE804E5",
            "pool_type": "weighted",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0x5A98FcBEA516Cf06857215779Fd812CA3beF1B32",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0x2a8080641a256dD61003289859fCf50d48901e63",
            "name": "Enzyme Staked: Balancer 80 LDO 20 WETH Aura Deposit",
            "releases": [],
            "symbol": "stkauraB-80LDO-20WETH",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xaac98EE71D4F8A156B6abaa6844Cdb7789d086CE",
            "name": "Balancer 60 MKR 40 WETH",
            "releases": [SULU],
            "symbol": "B-60MKR-40WETH",
            "staking": [],
            "pool_id": "0xaac98ee71d4f8a156b6abaa6844cdb7789d086ce00020000000000000000001b",
            "pool_factory": "0xA5bf2ddF098bb0Ef6d120C98217dD6B141c74EE0",
            "pool_type": "weighted",
            "underlyings": [
                "0x9f8F72aA9304c8B593d555F12eF6589cC3A579A2",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_WEIGHTED_POOL",
                "address": "0x083B8F465BbA2BB274E48387e3f9C56323341286",
            },
        },
        {
            "decimals": 18,
            "id": "0x0BF37157d30dFe6f56757DCadff01AEd83b08cD6",
            "name": "80NATION-20WETH",
            "releases": [],
            "symbol": "80NATION-20WETH",
            "staking": [],
            "pool_id": "0x0bf37157d30dfe6f56757dcadff01aed83b08cd600020000000000000000019a",
            "pool_factory": "0x8E9aa87E45e92bad84D5F8DD1bff34Fb92637dE9",
            "pool_type": "weighted",
            "underlyings": [
                "0x333A4823466879eeF910A04D473505da62142069",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x0Bfb387B87e8Bf173a10A7DCf786B0b7875F6771",
            "lp": "0x278cfB6f06B1EFc09d34fC7127d6060C61d629Db",
            "name": "Curve.fi weeTH/rswE Gauge Deposit",
            "pool": "0x278cfB6f06B1EFc09d34fC7127d6060C61d629Db",
            "releases": [SULU],
            "symbol": "weeTH/rswE-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
                "0xFAe103DC9cf190eD75350761e95403b7b8aFa6c0",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x333A4823466879eeF910A04D473505da62142069",
            "name": "Nation3",
            "releases": [],
            "symbol": "NATION",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x32296969Ef14EB0c6d29669C550D4a0449130230",
            "name": "Balancer stETH Stable Pool",
            "releases": [SULU],
            "symbol": "B-stETH-STABLE",
            "staking": [
                {"token": "0xcD4722B7c24C29e0413BDCd9e51404B4539D14aE", "type": "gauge"}
            ],
            "pool_id": "0x32296969ef14eb0c6d29669c550d4a0449130230000200000000000000000080",
            "pool_factory": "0x67d27634E44793fE63c467035E31ea8635117cd4",
            "pool_type": "meta-stable",
            "underlyings": [
                "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_STABLE_POOL",
                "address": "0x438254D66e2bC576819A76A0ecB11FE41195D39F",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0xcD4722B7c24C29e0413BDCd9e51404B4539D14aE",
            "name": "Balancer B-stETH-STABLE Gauge Deposit",
            "releases": [SULU],
            "symbol": "B-stETH-STABLE-gauge",
            "pool": "0x32296969Ef14EB0c6d29669C550D4a0449130230",
            "pool_type": "meta-stable",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0x7f39C581F595B53c5cb19bD0b3f8dA6c935E2Ca0",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
            "name": "Wrapped eETH",
            "releases": [SULU],
            "symbol": "weETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0xCa289456c31392074a804A7Db0AAc918fB36cf36",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xb4228d8126420A13C18eB6BdB641414820c13C90",
            "name": "Enzyme Staked: Balancer stETH Stable Pool Aura Deposit",
            "releases": [],
            "symbol": "stkauraB-stETH-STABLE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x1CAC1a0Ed47E2e0A313c712b2dcF85994021a365",
            "lp": "0x13947303F63b363876868D070F14dc865C36463b",
            "name": "Curve.fi weETH-WETH Gauge Deposit",
            "pool": "0x13947303F63b363876868D070F14dc865C36463b",
            "releases": [SULU],
            "symbol": "weETH-WETH-gauge",
            "template": "eth",
            "type": "curve-pool-gauge",
            "underlyings": [
                "0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "price_feed": {
                "type": "DERIVATIVE_CURVE",
                "address": "0x7e6130e497035a34A08E0F18B7A9B0fa06ed013E",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x1E19CF2D73a72Ef1332C882F20534B6519Be0276",
            "name": "Balancer rETH Stable Pool",
            "releases": [SULU],
            "symbol": "B-rETH-STABLE",
            "staking": [
                {"token": "0x79eF6103A513951a3b25743DB509E267685726B7", "type": "gauge"}
            ],
            "pool_id": "0x1e19cf2d73a72ef1332c882f20534b6519be0276000200000000000000000112",
            "pool_factory": "0x67d27634E44793fE63c467035E31ea8635117cd4",
            "pool_type": "meta-stable",
            "underlyings": [
                "0xae78736Cd615f374D3085123A210448E74Fc6393",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_STABLE_POOL",
                "address": "0x438254D66e2bC576819A76A0ecB11FE41195D39F",
                "ipa": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            },
        },
        {
            "decimals": 18,
            "id": "0x79eF6103A513951a3b25743DB509E267685726B7",
            "name": "Balancer B-rETH-STABLE Gauge Deposit",
            "releases": [SULU],
            "symbol": "B-rETH-STABLE-gauge",
            "pool": "0x1E19CF2D73a72Ef1332C882F20534B6519Be0276",
            "pool_type": "meta-stable",
            "gauge_factory": "0x4E7bBd911cf1EFa442BC1b2e9Ea01ffE785412EC",
            "underlyings": [
                "0xae78736Cd615f374D3085123A210448E74Fc6393",
                "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            ],
            "type": "balancer-pool-gauge",
            "price_feed": {
                "type": "DERIVATIVE_BALANCER_V2_GAUGE_TOKEN",
                "address": "0x312Ce4bDE393Ff246b27c890b97ADe37fEdaA348",
            },
        },
        {
            "decimals": 18,
            "id": "0x095d3F1Bb143A626867e0DFC97968ed561311CB2",
            "name": "Enzyme Staked: Balancer rETH Stable Pool Aura Deposit",
            "releases": [],
            "symbol": "stkauraB-rETH-STABLE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x09db87A538BD693E9d08544577d5cCfAA6373A48",
            "name": "ynETH",
            "releases": [SULU],
            "symbol": "ynETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK_LIKE_YNETH",
                "aggregator": "0xa8f6033cE40FaB29C228f32Ef44d38cB3043c5Bc",
                "rate_asset": RateAsset.ETH,
                "non_standard": True,
            },
        },
        {
            "decimals": 18,
            "id": "0x72953a5C32413614d24C29c84a66AE4B59581Bbf",
            "name": "CLever Token",
            "releases": [],
            "symbol": "CLEV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC0c293ce456fF0ED870ADd98a0828Dd4d2903DBF",
            "name": "Aura",
            "releases": [],
            "symbol": "AURA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x9aE380F0272E2162340a5bB646c354271c0F5cFC",
            "name": "Conic Finance Token",
            "releases": [],
            "symbol": "CNC",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xC128a9954e6c874eA3d62ce62B468bA073093F25",
            "name": "Vote Escrowed Balancer BPT",
            "releases": [],
            "symbol": "veBAL",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x616e8BfA43F920657B3497DBf40D6b1A02D4608d",
            "name": "Aura BAL",
            "releases": [],
            "symbol": "auraBAL",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0xc3d688B66703497DAA19211EEdff47f25384cdc3",
            "name": "Compound USDC",
            "releases": [SULU],
            "symbol": "cUSDCv3",
            "type": "compound-v3",
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8fFfFfd4AfB6115b954Bd326cbe7B4BA576818f6",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xA17581A9E3356d9A858b789D68B4d866e593aE94",
            "name": "Compound WETH",
            "releases": [SULU],
            "symbol": "cWETHv3",
            "type": "compound-v3",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA0d69E286B938e21CBf7E51D71F6A4c8918f482F",
            "name": "Electronic Dollar",
            "releases": [],
            "symbol": "eUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA17581A9E3356d9A858b789D68B4d866e593aE94",
            "name": "Compound WETH",
            "releases": [SULU],
            "symbol": "cWETHv3",
            "type": "compound-v3",
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x5f4eC3Df9cbd43714FE2740f5E3616155c5b8419",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x402F878BDd1f5C66FdAF0fabaBcF74741B68ac36",
            "name": "Stake DAO FXS",
            "releases": [],
            "symbol": "sdFXS",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xA1f82E14bc09A1b42710dF1A8a999B62f294e592",
            "name": "ethereum Conflux",
            "releases": [],
            "symbol": "eCFX",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x9c354503C38481a7A7a51629142963F98eCC12D0",
            "name": "Origin DeFi Governance",
            "releases": [],
            "symbol": "OGV",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xa2E3356610840701BDf5611a53974510Ae27E2e1",
            "name": "Wrapped Binance Beacon ETH",
            "releases": [],
            "symbol": "wBETH",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x2Ebd53d035150f328bd754D6DC66B99B0eDB89aa",
            "name": "Metronome2",
            "releases": [],
            "symbol": "MET",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x15f74458aE0bFdAA1a96CA1aa779D715Cc1Eefe4",
            "name": "Gravita Debt Token",
            "releases": [],
            "symbol": "GRAI",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xBFAbdE619ed5C4311811cF422562709710DB587d",
            "name": "Diva Token",
            "releases": [],
            "symbol": "DIVA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xdA47862a83dac0c112BA89c6abC2159b95afd71C",
            "name": "Prisma Governance Token",
            "releases": [],
            "symbol": "PRISMA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x34635280737b5BFe6c7DC2FC3065D60d66e78185",
            "name": "Convex Prisma",
            "releases": [],
            "symbol": "cvxPrisma",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xe063F04f280c60aECa68b38341C2eEcBeC703ae2",
            "name": "Leveraged ETH",
            "releases": [],
            "symbol": "xETH",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 6,
            "id": "0x6c3ea9036406852006290770BEdFcAbA0e23A0e8",
            "name": "PayPal USD",
            "releases": [SULU],
            "symbol": "PYUSD",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x8f1dF6D7F2db73eECE86a18b4381F4707b918FB1",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x4591DBfF62656E7859Afe5e45f6f47D3669fBB28",
            "name": "Prisma mkUSD",
            "releases": [],
            "symbol": "mkUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xbf5495Efe5DB9ce00f80364C8B423567e58d2110",
            "name": "Renzo Restaked ETH",
            "releases": [SULU],
            "symbol": "ezETH",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_NON_STANDARD_PRECISION",
                "aggregator": "0xC7e813d31de68C012Caf8Ea1DF323FDAc97e2Fd0",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xf939E0A03FB07F59A73314E73794Be0E57ac1b4E",
            "name": "Curve.Fi USD Stablecoin",
            "releases": [],
            "symbol": "crvUSD",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xc55126051B22eBb829D00368f4B12Bde432de5Da",
            "name": "BTRFLY",
            "releases": [],
            "symbol": "BTRFLY",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x365AccFCa291e7D3914637ABf1F7635dB165Bb09",
            "name": "FXN Token",
            "releases": [],
            "symbol": "FXN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 8,
            "id": "0x961dD84059505D59f82cE4fb87D3c09bec65301d",
            "name": "TenX Community JAPAN",
            "releases": [],
            "symbol": "TXJP",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xf091867EC603A6628eD83D274E835539D82e9cc8",
            "name": "Zeta",
            "releases": [],
            "symbol": "ZETA",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x808507121B80c02388fAd14726482e061B8da827",
            "name": "Pendle",
            "releases": [],
            "symbol": "PENDLE",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6b5204B0Be36771253Cc38e88012E02B752f0f36",
            "name": "Zunami Token",
            "releases": [],
            "symbol": "ZUN",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0x6DF0E641FC9847c0c6Fde39bE6253045440c14d3",
            "name": "Dinero Governance Token",
            "releases": [],
            "symbol": "DINERO",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "decimals": 18,
            "id": "0xdC035D45d973E3EC169d2276DDab16f1e407384F",
            "name": "USDS Stablecoin",
            "releases": [SULU],
            "symbol": "USDS",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xfF30586cD0F29eD462364C7e81375FC0C71219b1",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0xa3931d71877C0E7a3148CB7Eb4463524FEc27fbD",
            "name": "Savings USDS",
            "releases": [SULU],
            "symbol": "sUSDS",
            "type": "erc-4626",
            "underlying": "0xdC035D45d973E3EC169d2276DDab16f1e407384F",
            "protocol": "sky",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "decimals": 18,
            "id": "0xec53bF9167f50cDEB3Ae105f56099aaaB9061F83",
            "name": "Eigen",
            "symbol": "EIGEN",
            "releases": [SULU],
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0xf2917e602C2dCa458937fad715bb1E465305A4A1",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "symbol": "gtUSDCcore",
            "name": "Gauntlet USDC Core",
            "id": "0x8eB67A509616cd6A7c1B3c8C21D48FF57df3d458",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "gtUSDAcore",
            "name": "Gauntlet USDA Core",
            "id": "0x125D41A6e5dbf455cD9Df8F80BCC6fd172D52Cc6",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x0000206329b97DB379d5E1Bf586BbDB969C63274",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
                "non_standard": True,
            },
        },
        {
            "symbol": "gtDAIcore",
            "name": "Gauntlet DAI Core",
            "id": "0x500331c9fF24D9d11aee6B07734Aa72343EA74a5",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "Re7FRAX",
            "name": "Re7 FRAX",
            "id": "0xBE40491F3261Fd42724F1AEb465796eb11c06ddF",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x853d955aCEf822Db058eb8505911ED77F175b99e",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "Re7USDA",
            "name": "Re7 USDA",
            "id": "0x89D80f5e9BC88d8021b352064ae73F0eAf79EBd8",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x0000206329b97DB379d5E1Bf586BbDB969C63274",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
                "non_standard": True,
            },
        },
        {
            "symbol": "gtWETH",
            "name": "Gauntlet WETH Prime",
            "id": "0x2371e134e3455e0593363cBF89d3b6cf53740618",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "bbETH",
            "name": "Flagship ETH",
            "id": "0x38989BBA00BDF8181F4082995b3DEAe96163aC5D",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "gtLRTcore",
            "name": "Gauntlet LRT Core",
            "id": "0x4881Ef0BF6d2365D3dd6499ccd7532bcdBCE0658",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "Re7WETH",
            "name": "Re7 WETH",
            "id": "0x78Fc2c2eD1A4cDb5402365934aE5648aDAd094d0",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "MCwETH",
            "name": "MEV Capital wETH",
            "id": "0x9a8bC3B04b7f3D87cfC09ba407dCED575f2d61D8",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xC02aaA39b223FE8D0A0e5C4F27eAD9083C756Cc2",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "USUALUSDC+",
            "name": " Usual Boosted USDC",  # Initial space is correct (on-chain
            "id": "0xd63070114470f685b75B74D60EEc7c1113d33a3D",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "steakUSDC",
            "name": "Steakhouse USDC",
            "id": "0xBEEF01735c132Ada46AA9aA4c54623cAA92A64CB",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "gtUSDC",
            "name": "Gauntlet USDC Prime",
            "id": "0xdd0f28e19C1780eb6396170735D45153D261490d",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "steakUSDT",
            "name": "Steakhouse USDT",
            "id": "0xbEef047a543E45807105E51A8BBEFCc5950fcfBa",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "bbUSDT",
            "name": "Flagship USDT",
            "id": "0x2C25f6C25770fFEC5959D34B94Bf898865e5D6b1",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "gtUSDT",
            "name": "Gauntlet USDT Prime",
            "id": "0x8CB3649114051cA5119141a34C200D65dc0Faa73",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "USDC RWA",
            "name": "LeadBlock USDC RWA",
            "id": "0x4cA0E178c94f039d7F202E09d8d1a655Ed3fb6b6",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "Re7USDT",
            "name": "Re7 USDT",
            "id": "0x95EeF579155cd2C5510F312c8fA39208c3Be01a8",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "reUSDC",
            "name": "Relend USDC",
            "id": "0x0F359FD18BDa75e9c49bC027E7da59a4b01BF32a",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "fxUSDC",
            "name": "f(x  Protocol Morpho USDC",
            "id": "0x4F460bb11cf958606C69A963B4A17f9DaEEea8b6",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "sbMorphoUSDC",
            "name": "SwissBorg Morpho USDC",
            "id": "0x4Ff4186188f8406917293A9e01A1ca16d3cf9E59",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "MC.eUSDC",
            "name": "MEV Capital Elixir USDC",
            "id": "0x1265a81d42d513Df40d0031f8f2e1346954d665a",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "apUSDC",
            "name": "Apostro USDC",
            "id": "0xF2eFEBE45180C8c04edFdBfF3d88e58C9D61a03E",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "bbUSDC",
            "name": "Flagship USDC",
            "id": "0x186514400e52270cef3D80e1c6F8d10A75d47344",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "Re7USDC",
            "name": "Re7 USDC",
            "id": "0x60d715515d4411f7F43e4206dc5d4a3677f0eC78",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "steakPYUSD",
            "name": "Steakhouse PYUSD",
            "id": "0xbEEF02e5E13584ab96848af90261f0C8Ee04722a",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x6c3ea9036406852006290770BEdFcAbA0e23A0e8",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "steakUSDS",
            "name": "Steakhouse USDS",
            "id": "0xBeEfDA19BC6114633FC17e6d074A6A2b472C756f",
            "type": "erc-4626",
            "protocol": "morpho",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0xdC035D45d973E3EC169d2276DDab16f1e407384F",
            "price_feed": {
                "type": "DERIVATIVE_ERC4626",
                "address": "0x66aA5b2FdFB453F8A27f9BD1d9124947Ef3886BB",
            },
        },
        {
            "symbol": "SolvBTC",
            "name": "Solv BTC",
            "id": "0x7A56E1C57C7475CCf742a1832B028F0456652F97",
            "type": "primitive",
            "releases": [SULU],
            "decimals": 18,
            "price_feed": {
                "type": "PRIMITIVE_REDSTONE",
                "aggregator": "0x24c8964338Deb5204B096039147B8e8C3AEa42Cc",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "symbol": "SolvBTC.BBN",
            "name": "SolvBTC Babylon",
            "id": "0xd9D920AA40f578ab794426F5C90F6C731D159DEf",
            "type": "primitive",
            "releases": [SULU],
            "decimals": 18,
            "price_feed": {
                "type": "PRIMITIVE_REDSTONE",
                "aggregator": "0x24c8964338Deb5204B096039147B8e8C3AEa42Cc",
                "rate_asset": RateAsset.USD,
                "pegged_to": "SolvBTC",
                "non_standard": True,
            },
        },
        {
            "symbol": "PT-LBTC-27MAR2025",
            "name": "PT Lombard LBTC 27MAR2025",
            "id": "0xEc5a52C685CC3Ad79a6a347aBACe330d69e0b1eD",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 8,
            "underlying": "0x8236a87084f8B84306f72007F36F2618A5634494",
            "markets": ["0x70B70Ac0445C3eF04E314DFdA6caafd825428221"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x83a017b13540A85DBFC056b66Eb0B35BF72c09E3",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0x813ff1cf08b381632D0087Cc6D9E17fF73A7afC8",
            "name": "ZeroLend PT Lombard LBTC 27MAR2025",
            "releases": [SULU],
            "symbol": "z0PT-LBTC-27MAR2025",
            "type": "zero-lend-lrt-btc-aave-v3",
            "underlying": "0xEc5a52C685CC3Ad79a6a347aBACe330d69e0b1eD",
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x83a017b13540A85DBFC056b66Eb0B35BF72c09E3",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "PT-sUSDE-27MAR2025",
            "name": "PT Ethena sUSDE 27MAR2025",
            "id": "0xE00bd3Df25fb187d6ABBB620b3dfd19839947b81",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x9D39A5DE30e57443BfF2A8307A4256c8797A3497",
            "markets": ["0xcDd26Eb5EB2Ce0f203a84553853667aE69Ca29Ce"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x9f0D27b5dF260736f49C023504Ae7c2A50cEBC61",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0xB73CA924Bf3e1C2C5ac4D7718700650d706aAd73",
            "name": "ZeroLend PT Ethena sUSDE 27MAR2025",
            "releases": [SULU],
            "symbol": "z0PT-sUSDE-27MAR2025",
            "type": "zero-lend-rwa-stablecoins-aave-v3",
            "underlying": "0xE00bd3Df25fb187d6ABBB620b3dfd19839947b81",
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x9f0D27b5dF260736f49C023504Ae7c2A50cEBC61",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "PT-sUSDE-29MAY2025",
            "name": "PT Ethena sUSDE 29MAY2025",
            "id": "0xb7de5dFCb74d25c2f21841fbd6230355C50d9308",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x9D39A5DE30e57443BfF2A8307A4256c8797A3497",
            "markets": ["0xB162B764044697cf03617C2EFbcB1f42e31E4766"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x52325958f2Da217886E3c49E3cDbdbCf1C058A9c",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "PT-USDe-27MAR2025",
            "name": "PT Ethena USDe 27MAR2025",
            "id": "0x8A47b431A7D947c6a3ED6E42d501803615a97EAa",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x4c9EDD5852cd905f086C759E8383e09bff1E68B3",
            "markets": ["0xB451A36c8B6b2EAc77AD0737BA732818143A0E25"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0xE0fa7b4Fd6D05d166982f62F258Ff5efA7C2692B",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 18,
            "id": "0x691aD41906e3FE78c3fE1328eCddC9BD7c0e5eb8",
            "name": "ZeroLend PT Ethena USDe 27MAR2025",
            "releases": [SULU],
            "symbol": "z0PT-USDe-27MAR2025",
            "type": "zero-lend-rwa-stablecoins-aave-v3",
            "underlying": "0x8A47b431A7D947c6a3ED6E42d501803615a97EAa",
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0xE0fa7b4Fd6D05d166982f62F258Ff5efA7C2692B",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "PT-corn-SolvBTC.BBN-26DEC2024",
            "name": "PT Corn SolvBTC Babylon 26DEC2024",
            "id": "0x23e479ddcda990E8523494895759bD98cD2fDBF6",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 8,
            "markets": ["0xEb4d3057738b9Ed930F451Be473C1CCC42988384"],
            "underlying": "0xd9D920AA40f578ab794426F5C90F6C731D159DEf",
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x65427eE55ab33C00d467923af340B8fb3e73a0cd",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "symbol": "PT-corn-eBTC-27MAR2025",
            "name": "PT Corn ether.fi eBTC 27MAR2025",
            "id": "0x44A7876cA99460ef3218bf08b5f52E2dbE199566",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 8,
            "underlying": "0x657e8C867D8B37dCC18fA4Caead9C45EB088C642",
            "markets": ["0x2C71Ead7ac9AE53D05F8664e77031d4F9ebA064B"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x56579251C109537c239B783558792598E619CF2f",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "z0PT-corn-eBTC-27MAR2025",
            "name": "ZeroLend PT Corn ether.fi eBTC 27MAR2025",
            "id": "0xe2E3075C8962010E0d0B3A945c4671cc652ad5B7",
            "type": "zero-lend-lrt-btc-aave-v3",
            "releases": [SULU],
            "decimals": 8,
            "underlying": "0x44A7876cA99460ef3218bf08b5f52E2dbE199566",
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x56579251C109537c239B783558792598E619CF2f",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0x657e8C867D8B37dCC18fA4Caead9C45EB088C642",
            "name": "ether.fi BTC",
            "releases": [SULU],
            "symbol": "eBTC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_REDSTONE_QUOTED",
                "aggregator": "0xb04f255f21bC7a45eF4790deB007926E01b1f1f5",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "LP-sUSDE-29MAY2025",
            "name": "LP Ethena sUSDE 29MAY2025",
            "id": "0xB162B764044697cf03617C2EFbcB1f42e31E4766",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x9D39A5DE30e57443BfF2A8307A4256c8797A3497",
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x0998A52dBF3851C8B97012cfC2ACbA234a413E86",
                "rate_asset": RateAsset.USD,
            },
        },
        {
            "decimals": 18,
            "id": "0x626E8036dEB333b408Be468F951bdB42433cBF18",
            "name": "AIOZ Network",
            "releases": [],
            "symbol": "AIOZ",
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "id": "0x58D97B57BB95320F9a05dC918Aef65434969c2B2",
            "name": "Morpho Token",
            "symbol": "MORPHO",
            "decimals": 18,
            "releases": [],
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
        {
            "id": "0xde17a000BA631c5d7c2Bd9FB692EFeA52D90DEE2",
            "name": "Ultimate Synthetic Delta Neutral",
            "symbol": "USDN",
            "decimals": 18,
            "releases": [SULU],
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_CHAINLINK",
                "aggregator": "0x9579f735d0C93B5eef064Fe312CA3509BD695206",
                "rate_asset": RateAsset.ETH,
                "non_standard": True,
                "pegged_to": "USD",
            },
        },
        {
            "symbol": "PT-sUSDE-27MAR2025",
            "name": "PT Ethena sUSDE 27MAR2025",
            "id": "0xE00bd3Df25fb187d6ABBB620b3dfd19839947b81",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x9D39A5DE30e57443BfF2A8307A4256c8797A3497",
            "markets": ["0xcDd26Eb5EB2Ce0f203a84553853667aE69Ca29Ce"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x9f0D27b5dF260736f49C023504Ae7c2A50cEBC61",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "PT-sUSDE-29MAY2025",
            "name": "PT Ethena sUSDE 29MAY2025",
            "id": "0xb7de5dFCb74d25c2f21841fbd6230355C50d9308",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x9D39A5DE30e57443BfF2A8307A4256c8797A3497",
            "markets": ["0xB162B764044697cf03617C2EFbcB1f42e31E4766"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x52325958f2Da217886E3c49E3cDbdbCf1C058A9c",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "PT-USDe-27MAR2025",
            "name": "PT Ethena USDe 27MAR2025",
            "id": "0x8A47b431A7D947c6a3ED6E42d501803615a97EAa",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 18,
            "underlying": "0x4c9EDD5852cd905f086C759E8383e09bff1E68B3",
            "markets": ["0xB451A36c8B6b2EAc77AD0737BA732818143A0E25"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0xE0fa7b4Fd6D05d166982f62F258Ff5efA7C2692B",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "symbol": "PT-corn-eBTC-27MAR2025",
            "name": "PT Corn ether.fi eBTC 27MAR2025",
            "id": "0x44A7876cA99460ef3218bf08b5f52E2dbE199566",
            "type": "pendle-v2-pt",
            "releases": [SULU],
            "decimals": 8,
            "underlying": "0x657e8C867D8B37dCC18fA4Caead9C45EB088C642",
            "markets": ["0x2C71Ead7ac9AE53D05F8664e77031d4F9ebA064B"],
            "price_feed": {
                "type": "PRIMITIVE_PENDLE_V2",
                "aggregator": "0x56579251C109537c239B783558792598E619CF2f",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "decimals": 8,
            "id": "0x657e8C867D8B37dCC18fA4Caead9C45EB088C642",
            "name": "ether.fi BTC",
            "releases": [SULU],
            "symbol": "eBTC",
            "type": "primitive",
            "price_feed": {
                "type": "PRIMITIVE_REDSTONE_QUOTED",
                "aggregator": "0xb04f255f21bC7a45eF4790deB007926E01b1f1f5",
                "rate_asset": RateAsset.ETH,
            },
        },
        {
            "id": "0xFe0c30065B384F05761f15d0CC899D4F9F9Cc0eB",
            "name": "ether.fi governance token",
            "symbol": "ETHFI",
            "decimals": 18,
            "releases": [],
            "type": "primitive",
            "price_feed": {
                "type": "NONE",
            },
        },
    ],
)
